CREATE TABLE tbt_incident (
  user_company_id DECIMAL(15) NOT NULL,
  incident_no DECIMAL(15) NOT NULL,
  project_id DECIMAL(15) NOT NULL,
  incident_type VARCHAR(255) NULL,
  incident_title VARCHAR(255) NULL,
  tanto_staff_cd VARCHAR(255) NULL,
  irai_staff_cd VARCHAR(255) NULL,
  correspondence_time VARCHAR(255) NULL,
  correspondence_minute VARCHAR(255) NULL,
  incident_text TEXT NULL,
  incident_file_id DECIMAL(15) NULL,
  incident_biko TEXT NULL,
  mail_option VARCHAR(255) NULL,
  del_flg VARCHAR(1) NULL DEFAULT '0',
  add_date timestamp NOT NULL,
  upd_date timestamp NULL,
  add_pgid VARCHAR(255) NULL,
  upd_pgid VARCHAR(255) NULL,
  add_user_cd VARCHAR(255) NULL,
  upd_user_cd VARCHAR(255) NULL,
  PRIMARY KEY (user_company_id, incident_no)
) with (FILLFACTOR=90);

CREATE TABLE tbt_incident_date (
  user_company_id DECIMAL(15) NOT NULL,
  incident_no DECIMAL(15) NOT NULL,
  date_kb VARCHAR(32) NOT NULL,
  date VARCHAR(255) NULL,
  del_flg VARCHAR(1) NULL DEFAULT '0',
  add_date timestamp NULL,
  upd_date timestamp NOT NULL,
  add_pgid VARCHAR(255) NULL,
  upd_pgid VARCHAR(255) NULL,
  add_user_cd VARCHAR(255) NULL,
  upd_user_cd VARCHAR(255) NULL,
  PRIMARY KEY (user_company_id, incident_no, date_kb)
) with (FILLFACTOR=90);

CREATE TABLE tbt_incident_answer (
  user_company_id DECIMAL(15) NOT NULL,
  incident_no DECIMAL(15) NOT NULL,
  answer_id DECIMAL(15) NOT NULL,
  answer_text TEXT NULL,
  del_flg VARCHAR(1) NULL DEFAULT '0',
  add_date timestamp NOT NULL,
  upd_date timestamp NULL,
  add_pgid VARCHAR(255) NULL,
  upd_pgid VARCHAR(255) NULL,
  add_user_cd VARCHAR(255) NULL,
  upd_user_cd VARCHAR(255) NULL,
  PRIMARY KEY (user_company_id, incident_no, answer_id)
) with (FILLFACTOR=90);

CREATE TABLE tbt_incident_status (
  user_company_id DECIMAL(15) NOT NULL,
  incident_no DECIMAL(15) NOT NULL,
  status_kb VARCHAR(32) NOT NULL,
  status_id DECIMAL(15) NOT NULL,
  answer_id DECIMAL(15) NULL,
  status VARCHAR(255) NULL,
  del_flg VARCHAR(1) NULL DEFAULT '0',
  add_date timestamp NOT NULL,
  upd_date timestamp NULL,
  add_pgid VARCHAR(255) NULL,
  upd_pgid VARCHAR(255) NULL,
  add_user_cd VARCHAR(255) NULL,
  upd_user_cd VARCHAR(255) NULL,
  PRIMARY KEY (user_company_id, incident_no, status_kb, status_id)
) with (FILLFACTOR=90);

CREATE TABLE tbt_incident_relation (
  user_company_id DECIMAL(15) NOT NULL,
  incident_no DECIMAL(15) NOT NULL,
  relation_incident_no DECIMAL(15) NOT NULL,
  del_flg VARCHAR(1) NULL DEFAULT '0',
  add_date timestamp NOT NULL,
  upd_date timestamp NULL,
  add_pgid VARCHAR(255) NULL,
  upd_pgid VARCHAR(255) NULL,
  add_user_cd VARCHAR(255) NULL,
  upd_user_cd VARCHAR(255) NULL,
  PRIMARY KEY (user_company_id, incident_no, relation_incident_no)
) with (FILLFACTOR=90);

CREATE TABLE tbt_opm_file (
  user_company_id DECIMAL(15) NOT NULL,
  file_id DECIMAL(15) NOT NULL,
  file_nm VARCHAR(255) NULL,
  file_path VARCHAR(255) NULL,
  del_flg VARCHAR(1) NULL DEFAULT '0',
  add_date timestamp NOT NULL,
  upd_date timestamp NULL,
  add_pgid VARCHAR(255) NULL,
  upd_pgid VARCHAR(255) NULL,
  add_user_cd VARCHAR(255) NULL,
  upd_user_cd VARCHAR(255) NULL,
  PRIMARY KEY (user_company_id, file_id)
) with (FILLFACTOR=90);

CREATE TABLE tbt_problem (
  user_company_id DECIMAL(15) NOT NULL,
  problem_no DECIMAL(15) NOT NULL,
  project_id DECIMAL(15) NOT NULL,
  problem_type VARCHAR(255) NULL,
  problem_title VARCHAR(255) NULL,
  tanto_staff_cd VARCHAR(255) NULL,
  irai_staff_cd VARCHAR(255) NULL,
  correspondence_time VARCHAR(255) NULL,
  correspondence_minute VARCHAR(255) NULL,
  problem_text TEXT NULL,
  problem_file_id DECIMAL(15) NULL,
  problem_biko TEXT NULL,
  mail_option VARCHAR(255) NULL,
  del_flg VARCHAR(1) NULL DEFAULT '0',
  add_date timestamp NOT NULL,
  upd_date timestamp NULL,
  add_pgid VARCHAR(255) NULL,
  upd_pgid VARCHAR(255) NULL,
  add_user_cd VARCHAR(255) NULL,
  upd_user_cd VARCHAR(255) NULL,
  PRIMARY KEY(user_company_id, problem_no)
) with (FILLFACTOR=90);

CREATE TABLE tbt_problem_relevance (
  user_company_id DECIMAL(15) NOT NULL,
  problem_no DECIMAL(15) NOT NULL,
  relevance_incident_no DECIMAL(15) NOT NULL,
  del_flg VARCHAR(1) NULL DEFAULT '0',
  add_date timestamp NOT NULL,
  upd_date timestamp NULL,
  add_pgid VARCHAR(255) NULL,
  upd_pgid VARCHAR(255) NULL,
  add_user_cd VARCHAR(255) NULL,
  upd_user_cd VARCHAR(255) NULL,
  PRIMARY KEY (user_company_id, problem_no, relevance_incident_no)
) with (FILLFACTOR=90);

CREATE TABLE tbt_problem_date (
  user_company_id DECIMAL(15) NOT NULL,
  problem_no DECIMAL(15) NOT NULL,
  date_kb VARCHAR(32) NOT NULL,
  date VARCHAR(255) NULL,
  del_flg VARCHAR(1) NULL DEFAULT '0',
  add_date timestamp NOT NULL,
  upd_date timestamp NULL,
  add_pgid VARCHAR(255) NULL,
  upd_pgid VARCHAR(255) NULL,
  add_user_cd VARCHAR(255) NULL,
  upd_user_cd VARCHAR(255) NULL,
  PRIMARY KEY (user_company_id, problem_no, date_kb)
) with (FILLFACTOR=90);

CREATE TABLE tbt_problem_answer (
  user_company_id DECIMAL(15) NOT NULL,
  problem_no DECIMAL(15) NOT NULL,
  answer_id DECIMAL(15) NOT NULL,
  answer_text TEXT NULL,
  del_flg VARCHAR(1) NULL DEFAULT '0',
  add_date timestamp NOT NULL,
  upd_date timestamp NULL,
  add_pgid VARCHAR(255) NULL,
  upd_pgid VARCHAR(255) NULL,
  add_user_cd VARCHAR(255) NULL,
  upd_user_cd VARCHAR(255) NULL,
  PRIMARY KEY (user_company_id, problem_no, answer_id)
) with (FILLFACTOR=90);

CREATE TABLE tbt_problem_status (
  user_company_id DECIMAL(15) NOT NULL,
  problem_no DECIMAL(15) NOT NULL,
  status_kb VARCHAR(32) NOT NULL,
  status_id DECIMAL(15) NOT NULL,
  answer_id DECIMAL(15) NULL,
  status VARCHAR(255) NULL,
  del_flg VARCHAR(1) NULL DEFAULT '0',
  add_date timestamp NOT NULL,
  upd_date timestamp NULL,
  add_pgid VARCHAR(255) NULL,
  upd_pgid VARCHAR(255) NULL,
  add_user_cd VARCHAR(255) NULL,
  upd_user_cd VARCHAR(255) NULL,
  PRIMARY KEY (user_company_id, problem_no, status_kb, status_id)
) with (FILLFACTOR=90);

CREATE TABLE tbm_project (
  user_company_id DECIMAL(15) NOT NULL,
  project_id DECIMAL(15) NOT NULL,
  bunrui_kb VARCHAR(32) NOT NULL,
  bunrui_id DECIMAL(15) NOT NULL,
  maillinglist_addr VARCHAR(255) NOT NULL,
  del_flg VARCHAR(1) NULL DEFAULT '0',
  add_date timestamp NOT NULL,
  upd_date timestamp NULL,
  add_pgid VARCHAR(255) NULL,
  upd_pgid VARCHAR(255) NULL,
  add_user_cd VARCHAR(255) NULL,
  upd_user_cd VARCHAR(255) NULL,
  PRIMARY KEY (user_company_id, project_id)
) with (FILLFACTOR=90);

