--
-- view structure for view tmp_kou_order_list_0
--
-- ステータステーブルを発注依頼番号・発注番号・出金番号でグループ
--
create view tmp_kou_order_list_0 as 
select
    sta.user_company_id as user_company_id,
    sta.order_irai_no as order_irai_no,
    sta.order_no as order_no,
    sta.syukkin_no as syukkin_no,
    min(sta.sts_kb) as sts_kb
from
    tbt_kou_status sta 
where
    sta.del_flg = '0'
group by
    sta.user_company_id,
    sta.order_irai_no,
    sta.order_no,
    sta.syukkin_no;
-- ------------------------------------------------------

--
-- view structure for view tmp_kou_order_list_1
--
-- ステータステーブルを発注依頼番号・発注番号でグループ化し、
-- 出金番号が入っている場合には、最大となる出金日を取得。
-- （一覧での検索用）
--
create view tmp_kou_order_list_1 as 
select
    a.user_company_id as user_company_id,
    a.order_irai_no as order_irai_no,
    a.order_no as order_no,
    min(a.sts_kb) as sts_kb,
    max(b.syukkin_dt) as syukkin_dt
from
    tmp_kou_order_list_0 a 
    left outer join tbt_kou_syukkin b 
    on(a.user_company_id = b.user_company_id and a.syukkin_no = b.syukkin_no and b.del_flg = '0')
group by
    a.user_company_id,
    a.order_irai_no,
    a.order_no;

-- ------------------------------------------------------

--
-- view structure for view tmp_kou_order_list_2
--
-- 発注番号ごとでの明細件数および、発注金額を取得
--
create view tmp_kou_order_list_2 as
select
    a.user_company_id,
    a.order_no,
    count(*) as kensu,
    sum(kin) as goukei
from
    tbt_kou_order_detail a
where
    a.del_flg = '0'
group by
    a.user_company_id,
    a.order_no;
-- ------------------------------------------------------

--
-- view structure for view tbv_kou_order_list
--
-- 受注ヘッダの為の情報
--
create view tbv_kou_order_list as
select
    sts.sts_kb,
    h.code_nm as sts_kb_nm,
    sts.syukkin_dt,
    hed.user_company_id,	
    hed.order_no,
    hed.order_dt,
    hed.order_prt_dt,
    hed.toroku_staff_cd,
    f.toroku_staff_nm,
    hed.toroku_organization_id,
    i.bunrui_nm as toroku_organization,
    hed.tanto_staff_cd,
    e.tanto_staff_nm,
    hed.tanto_organization_id,
    j.bunrui_nm as tanto_organization,
    hed.order_irai_no,
    hed.siire_id,
    d.siire_cd_nm as siire_nm,
    cast('' as varchar) as company_url,
    hed.nouki_dt,
    hed.order_title,
    dtl.kensu,
    dtl.goukei
from
    tmp_kou_order_list_1 sts
    join tbt_kou_order hed
         on(sts.user_company_id = hed.user_company_id and sts.order_no = hed.order_no and hed.del_flg = '0')
    join tmp_kou_order_list_2 dtl
         on(hed.user_company_id = dtl.user_company_id and hed.order_no = dtl.order_no)
    left outer join tbv_siire d
         on(hed.user_company_id = d.user_company_id and hed.siire_id = d.siire_id)
    left outer join tbv_kou_order_tanto e
         on(hed.user_company_id = e.user_company_id and hed.tanto_staff_cd = e.tanto_staff_cd)
    left outer join tbv_kou_order_regist_user f
         on(hed.user_company_id = f.user_company_id and hed.toroku_staff_cd = f.toroku_staff_cd)
    left outer join tbm_code h
         on(sts.user_company_id = h.user_company_id and sts.sts_kb = h.code and h.code_kb = '21' and h.del_flg = '0')
    left outer join tbm_bunrui i
         on(hed.user_company_id = i.user_company_id and i.bunrui_kb = '6' and hed.toroku_organization_id = i.bunrui_id and i.del_flg = '0')
    left outer join tbm_bunrui j
         on(hed.user_company_id = j.user_company_id and j.bunrui_kb = '6' and hed.tanto_organization_id = j.bunrui_id  and j.del_flg = '0')
where
    sts.sts_kb >= '060';

-- ------------------------------------------------------

--
-- view structure for view tmp_kou_order_detail_list0
--
-- 受注ヘッダと明細を紐付けたもの（主が明細）
-- ※明細の削除フラグは現状考えない。（明細は物理削除の為）
--
create view tmp_kou_order_detail_list0 as
select 
    hed.user_company_id,
    hed.order_no,
    hed.order_irai_no,
    dtl.order_edano,
    hed.order_dt,
    hed.order_prt_dt,
    hed.toroku_staff_cd,
    hed.toroku_organization_id,
    i.bunrui_nm as toroku_organization,
    hed.tanto_staff_cd,
    hed.tanto_organization_id,
    j.bunrui_nm as tanto_organization,
    hed.siire_id,
    hed.nouki_dt,
    hed.order_title,
    dtl.item_id,
    dtl.product_nm,
    dtl.product_kikaku,
    dtl.syubetu,
    dtl.su,
    dtl.tani_nm,
    dtl.tanka,
    dtl.kin,
    dtl.biko    
from 
    tbt_kou_order hed
    join tbt_kou_order_detail dtl
         on (hed.user_company_id = dtl.user_company_id and hed.order_no = dtl.order_no and dtl.del_flg = '0')
    left outer join tbm_bunrui i
         on(hed.user_company_id = i.user_company_id and i.bunrui_kb = '6' and hed.toroku_organization_id = i.bunrui_id and i.del_flg = '0')
    left outer join tbm_bunrui j
         on(hed.user_company_id = j.user_company_id and j.bunrui_kb = '6' and hed.tanto_organization_id = j.bunrui_id  and j.del_flg = '0')
where
    hed.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_kou_order_detail_list
--
-- 画面にて使用する明細情報用
-- 明細が主となる受注情報とステータステーブルの紐付け
--
create view tbv_kou_order_detail_list as
select
    ord.user_company_id,
    ord.order_no,
    ord.order_edano,
    sts.sts_kb,
    cdm.code_nm as sts_kb_nm,
    ord.item_id,
    item.item_cd,
    ord.product_nm,
    ord.product_kikaku,
    ord.syubetu,
    ord.su,
    cdm2.code_nm as tani_nm,
    item.standard_tnk as teika,
    ord.tanka,
    ord.kin,
    ord.biko    
from
    tmp_kou_order_detail_list0 ord
    join tbm_item item
         on(ord.user_company_id = item.user_company_id and ord.item_id = item.item_id and item.del_flg='0')
    join tbt_kou_status sts
         on(ord.user_company_id = sts.user_company_id and ord.order_no = sts.order_no and ord.order_edano = sts.order_edano and     sts.del_flg = '0' and sts.sts_kb >= '060')
    left outer join tbm_code cdm
         on(sts.user_company_id = cdm.user_company_id and sts.sts_kb = cdm.code and cdm.code_kb = '21' and cdm.del_flg = '0')
    left outer join tbm_code cdm2
         on (ord.user_company_id = cdm2.user_company_id and ord.tani_nm = cdm2.code and cdm2.code_kb = '2' and cdm2.del_flg = '0');

-- ------------------------------------------------------

--
-- view structure for view tmp_kou_order_print_list_0
--
-- 発注明細の合計金額を算出
--
create view tmp_kou_order_print_list_0 as
select
    a.user_company_id,
    a.order_no,
    sum(a.kin) as sum_kin
from
    tbt_kou_order_detail a
group by
    a.user_company_id,
    a.order_no,
    a.del_flg = '0';

-- ------------------------------------------------------

--
-- view structure for view tbv_kou_order_print_list
--
-- 
-- ※印刷用view
--
create view tbv_kou_order_print_list as
select
    a.user_company_id,
    a.order_no,
    a.order_irai_no,
    a.order_edano,
    b.sts_kb,
    c.code_nm as sts_kb_nm,
    a.order_dt,
    a.order_prt_dt,
    g.jisya_nm,
    g.tel as jisya_tel,
    g.fax as jisya_fax,
    g.zipcode as jisya_zipcode,
    g.address1 as jisya_address1,
    g.address2 as jisya_address2,
    g.address3 as jisya_address3,
    g.address4 as jisya_address4,
    a.toroku_staff_cd,
    a.toroku_organization_id,
    i.bunrui_nm as toroku_organization,
    a.tanto_staff_cd,
    f.personal_nm as tanto_staff_nm,
    a.tanto_organization_id,
    j.bunrui_nm as tanto_organization,
    a.siire_id,
    d.siire_cd_nm as siire_nm,
    d.zipcode,
    d.address1,
    d.address2,
    d.address3,
    d.address4,
    a.nouki_dt,
    a.order_title,
    a.item_id,
    e.item_cd,
    a.product_nm,
    a.product_kikaku,
    a.syubetu,
    a.su,
    (case when b.sts_kb < '110' then a.su else 0 end) as zan_su,
    a.tani_nm,
    a.tanka,
    a.kin,
    h.sum_kin,
    (case when b.sts_kb < '110' then a.kin else 0 end) as zan_kin,    
    a.biko,
    e.item_nm as item_nm,
    e.item_kikaku
from
    tmp_kou_order_detail_list0 a
    join tbt_kou_status b
         on(a.user_company_id = b.user_company_id and a.order_no = b.order_no and a.order_edano = b.order_edano and b.del_flg = '0')
    left outer join tbm_code c
         on(b.user_company_id = c.user_company_id and b.sts_kb = c.code and c.code_kb = '21' and c.del_flg = '0')
    left outer join tbv_siire d
         on(a.user_company_id = d.user_company_id and a.siire_id = d.siire_id)
    left outer join tbv_item e
         on(a.user_company_id = e.user_company_id and a.item_id = e.item_id)
    left outer join tbv_syain f
         on(a.user_company_id = f.user_company_id and a.tanto_staff_cd = f.staff_cd)
    left outer join tbm_bunrui i
         on(a.user_company_id = i.user_company_id and i.bunrui_kb = '6' and a.toroku_organization_id = i.bunrui_id and i.del_flg = '0')
    left outer join tbm_bunrui j
         on(a.user_company_id = j.user_company_id and j.bunrui_kb = '6' and a.tanto_organization_id = j.bunrui_id  and j.del_flg = '0')
    left outer join tbv_jisya g
         on(a.user_company_id = g.user_company_id)
    join tmp_kou_order_print_list_0 h
         on(a.user_company_id = h.user_company_id and a.order_no = h.order_no)
where
    b.sts_kb >= '060';
