--
-- view structure for view tmp_nyuka_list_0
--
--  発注番号・入荷検品番号・ステータス毎にグループ化

create view tmp_nyuka_list_0 as
select distinct
       a.user_company_id,
       a.order_no,
       a.nyuka_kenpin_no,
       a.sts_kb
from tbt_kou_status a
where  a.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tmp_nyuka_list_1
--
-- １発注番号中に複数のステータスが入っている発注番号レコードは対象外

create view tmp_nyuka_list_1 as
select a.user_company_id,
       a.order_no,
       a.nyuka_kenpin_no,
       max(a.sts_kb) as sts_kb,
       count(*) as kensu
from tmp_nyuka_list_0 a
group by
       a.user_company_id,
       a.order_no,
       a.nyuka_kenpin_no
having count(*) <=1;
-- ------------------------------------------------------

--
-- view structure for view tmp_nyuka_list_2
--
-- １発注番号の発注数合計を取得

create view tmp_nyuka_list_2 as
select a.user_company_id,
       a.order_no,
       sum(b.su) as hachu_su
from tmp_nyuka_list_1 a
     left outer join tbt_kou_order_detail b
     on a.user_company_id = b.user_company_id and a.order_no = b.order_no
where
     b.del_flg = '0'
group by 
     a.user_company_id,
     a.order_no;
-- ------------------------------------------------------

--
-- view structure for view tmp_nyuka_list_3
--
-- １発注番号の検収数合計を取得

create view tmp_nyuka_list_3 as
select a.user_company_id,
       a.order_no,
       max(b.nyuka_dt) as nyuka_dt,
       sum(b.su) as nyuka_su
from tmp_nyuka_list_1 a
     left outer join tbt_kou_nyuka_detail b
     on a.user_company_id = b.user_company_id and a.order_no = b.order_no
where b.del_flg = '0'
group by 
     a.user_company_id,
     a.order_no;
-- ------------------------------------------------------

--
-- view structure for view tbv_nyuka_list
--

create view tbv_nyuka_list as
select a.user_company_id,
       a.order_no,
       a.nyuka_kenpin_no,
       a.sts_kb,
       b.order_dt,
       b.toroku_staff_cd        as toroku_staff_cd,
       c.personal_nm            as toroku_staff_nm,
       b.toroku_organization_id as toroku_organization_id,
       i.bunrui_nm as toroku_organization,
       b.tanto_staff_cd         as tanto_staff_cd,
       d.personal_nm            as tanto_staff_nm,
       b.tanto_organization_id  as tanto_organization_id,
       j.bunrui_nm as tanto_organization,
       b.siire_id               as siire_id,
       e.siire_cd_nm            as siire_nm,
       ''                       as siire_url,
       b.nouki_dt,
       b.order_title,
       f.hachu_su,
       g.nyuka_dt,
       cast(substr(g.nyuka_dt,1,4) as varchar) as nyuka_dt_yy,
       cast(substr(g.nyuka_dt,5,2) as varchar) as nyuka_dt_mm,
       cast(substr(g.nyuka_dt,7,2) as varchar) as nyuka_dt_dd,
       g.nyuka_su
from tmp_nyuka_list_1 a
     join tbt_kou_order b
          on (a.user_company_id = b.user_company_id and a.order_no = b.order_no and b.del_flg = '0')
     left outer join tbv_syain c
          on (b.user_company_id = c.user_company_id and b.toroku_staff_cd = c.staff_cd)
     left outer join tbv_syain d
          on (b.user_company_id = d.user_company_id and b.tanto_staff_cd = d.staff_cd)
     left outer join tbv_siire e
          on (b.user_company_id = e.user_company_id and b.siire_id = e.siire_id)
     left outer join tmp_nyuka_list_2 f
          on (a.user_company_id = f.user_company_id and a.order_no = f.order_no)
     left outer join tmp_nyuka_list_3 g
          on (a.user_company_id = g.user_company_id and a.order_no = g.order_no)
     left outer join tbm_bunrui i
          on(b.user_company_id = i.user_company_id and i.bunrui_kb = '6' and b.toroku_organization_id = i.bunrui_id and i.del_flg = '0')
     left outer join tbm_bunrui j
          on(b.user_company_id = j.user_company_id and j.bunrui_kb = '6' and b.tanto_organization_id = j.bunrui_id  and j.del_flg = '0')
;
-- ------------------------------------------------------

--
-- view structure for view tmp_nyuka_detail_list_0
--

create view tmp_nyuka_detail_list_0 as
select distinct
       a.user_company_id,
       a.order_no,
       a.order_edano,
       a.nyuka_kenpin_no,
       a.nyuka_kenpin_edano,
       a.sts_kb
from tbt_kou_status a
where a.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_nyuka_detail_list
--

create view tbv_nyuka_detail_list as
select a.user_company_id,
       a.order_no,
       a.order_edano,
       a.nyuka_kenpin_no,
       a.nyuka_kenpin_edano,
       a.sts_kb,
       b.order_dt,
       b.toroku_staff_cd        as toroku_staff_cd,
       c.personal_nm            as toroku_staff_nm,
       b.toroku_organization_id as toroku_organization_id,
       i.bunrui_nm as toroku_organization,
       b.tanto_staff_cd         as tanto_staff_cd,
       d.personal_nm            as tanto_staff_nm,
       b.tanto_organization_id  as tanto_organization_id,
       j.bunrui_nm as tanto_organization,
       b.siire_id               as siire_id,
       e.siire_cd_nm            as siire_nm,
       ''                       as siire_url,
       b.nouki_dt,
       b.order_title,
       f.su as hachu_su,
       f.tani_nm,
       f.product_nm,
       f.product_kikaku,
       g.nyuka_dt,
       g.su as nyuka_su
from tmp_nyuka_detail_list_0 a
     join tbt_kou_order b
          on a.user_company_id = b.user_company_id and a.order_no = b.order_no
     left outer join tbv_syain c
          on b.user_company_id = c.user_company_id and b.toroku_staff_cd = c.staff_cd
     left outer join tbv_syain d
          on b.user_company_id = d.user_company_id and b.tanto_staff_cd = d.staff_cd
     left outer join tbv_siire e
          on b.user_company_id = e.user_company_id and b.siire_id = e.siire_id
     left outer join tbt_kou_order_detail f
          on a.user_company_id = f.user_company_id and a.order_no = f.order_no and a.order_edano = f.order_edano and f.del_flg = '0'
     left outer join tbt_kou_nyuka_detail g
          on (a.user_company_id = g.user_company_id and a.nyuka_kenpin_no = g.nyuka_kenpin_no and a.nyuka_kenpin_edano = g.nyuka_kenpin_edano and g.del_flg = '0')
     left outer join tbm_bunrui i
          on(b.user_company_id = i.user_company_id and i.bunrui_kb = '6' and b.toroku_organization_id = i.bunrui_id and i.del_flg = '0')
     left outer join tbm_bunrui j
          on(b.user_company_id = j.user_company_id and j.bunrui_kb = '6' and b.tanto_organization_id = j.bunrui_id  and j.del_flg = '0')
;
-- ------------------------------------------------------

--
-- view structure for view tmp_nyuka_kenpin_list_0
--

create view tmp_nyuka_kenpin_list_0 as
select
      a.user_company_id,
      a.nyuka_kenpin_no,
      a.nyuka_kenpin_edano,
      min(b.kin) as kin
from  tbt_kou_status a
      left outer join tbt_kou_nyuka_detail b
      on a.user_company_id = b.user_company_id and a.nyuka_kenpin_no = b.nyuka_kenpin_no and a.nyuka_kenpin_edano = b.nyuka_kenpin_edano
where a.del_flg = '0'
and   a.nyuka_kenpin_no is not null
and   b.del_flg = '0'
group by 
      a.user_company_id,
      a.nyuka_kenpin_no,
      a.nyuka_kenpin_edano;
-- ------------------------------------------------------

--
-- view structure for view tbv_nyuka_kenpin_list
--

create view tbv_nyuka_kenpin_list as
select
      a.user_company_id,
      a.nyuka_kenpin_no,
      sum(a.kin) as sum_kin,
      b.siire_id,
      c.siire_cd_nm as siire_nm,
      '' as siire_url
from  tmp_nyuka_kenpin_list_0 a
      join tbt_kou_nyuka b
      on a.user_company_id = b.user_company_id and a.nyuka_kenpin_no = b.nyuka_kenpin_no
      left outer join tbv_siire c
      on b.user_company_id = c.user_company_id and b.siire_id = c.siire_id
where
     b.del_flg = '0'
group by 
      a.user_company_id,
      a.nyuka_kenpin_no,
      b.siire_id,
      c.siire_cd_nm;
-- ------------------------------------------------------

--
-- view structure for view tmp_nyuka_kenpin_detail_list_0
--

create view tmp_nyuka_kenpin_detail_list_0 as
select
      a.user_company_id,
      a.nyuka_kenpin_no,
      a.nyuka_kenpin_edano,
      min(a.order_no) as order_no,
      min(a.order_edano) as order_edano,
      min(a.sts_kb) as sts_kb
from  tbt_kou_status a
where a.del_flg = '0'
and   a.nyuka_kenpin_no is not null
group by 
      a.user_company_id,
      a.nyuka_kenpin_no,
      a.nyuka_kenpin_edano;
-- ------------------------------------------------------

--
-- view structure for view tbv_nyuka_kenpin_detail_list
--

create view tbv_nyuka_kenpin_detail_list as
select
      a.user_company_id,
      a.nyuka_kenpin_no,
      a.nyuka_kenpin_edano,
      a.order_no,
      a.order_edano,
      a.sts_kb,
      min(b.product_nm) as product_nm,
      min(b.product_kikaku) as product_kikaku,
      min(b.su) as su,
      min(b.tani_nm) as tani_cd,
      min(d.code_nm) as tani_nm,
      min(b.tanka) as tanka,
      min(b.kin) as kin,
      c.code_nm as jyokyo_nm
from  tmp_nyuka_kenpin_detail_list_0 a
      left outer join tbt_kou_nyuka_detail b
           on a.user_company_id = b.user_company_id and a.nyuka_kenpin_no = b.nyuka_kenpin_no and a.nyuka_kenpin_edano = b.nyuka_kenpin_edano
      left outer join tbm_code d
           on b.user_company_id = d.user_company_id and b.tani_nm = d.code and d.code_kb = '2' and d.del_flg='0'
      left outer join tbm_code c 
           on a.user_company_id = c.user_company_id and a.sts_kb = c.code and c.code_kb = '21' and c.del_flg='0'
group by 
      a.user_company_id,
      a.nyuka_kenpin_no,
      a.nyuka_kenpin_edano,
      a.order_no,
      a.order_edano,
      a.sts_kb,
      c.code_nm;
