--
-- view structure for view tbv_kou_mitu_tanto
-- 見積担当者の一覧を見積テーブルから抽出
--
create view tbv_kou_mitu_tanto as
select
    distinct
    a.user_company_id,
    a.tanto_staff_cd,
    b.personal_nm                -- 担当者名
from
    tbt_kou_mitu a
   left outer join tbv_syain b
         on(a.user_company_id = b.user_company_id and a.tanto_staff_cd = b.staff_cd)
where a.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_kou_mitu_regist_user
--
create view tbv_kou_mitu_regist_user as
select
    distinct
    a.user_company_id,
    a.toroku_staff_cd,
    b.personal_nm                -- 担当者名
from
    tbt_kou_mitu a
   left outer join tbv_syain b
         on(a.user_company_id = b.user_company_id and a.tanto_staff_cd = b.staff_cd)
where a.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tmp_kou_mitu_list_0
--
-- ステータステーブルを見積番号・発注番号・出金番号でグループ
--
create view tmp_kou_mistu_list_0 as
select
    sta.user_company_id as user_company_id,
    sta.mitu_no as mitu_no,
    sta.order_no as order_no,
    sta.syukkin_no as syukkin_no,
    min(sta.sts_kb) as sts_kb
from
    tbt_kou_status sta
where
    sta.del_flg = '0'
group by
    sta.user_company_id,
    sta.mitu_no,
    sta.order_no,
    sta.syukkin_no;
-- ------------------------------------------------------

--
-- view structure for view tmp_kou_mistu_list_1
--
-- ステータステーブルを見積番号・発注番号でグループ化し、
-- 出金番号が入っている場合には、最大となる出金日を取得。
-- （一覧での検索用）
--
create view tmp_kou_mitu_list_1 as
select
    a.user_company_id as user_company_id,
    a.mitu_no as mitu_no,
    a.order_no as order_no,
    min(a.sts_kb) as sts_kb,
    max(b.syukkin_dt) as syukkin_dt
from
    tmp_kou_mistu_list_0 a
    left outer join tbt_kou_syukkin b
    on(a.user_company_id = b.user_company_id and a.syukkin_no = b.syukkin_no and b.del_flg = '0')
group by
    a.user_company_id,
    a.mitu_no,
    a.order_no;
-- ------------------------------------------------------

--
-- view structure for view tmp_kou_mitu_list_2
--
-- 見積番号ごとでの明細件数および、見積金額を取得
--
create view tmp_kou_mitu_list_2 as
select
    a.user_company_id,
    a.mitu_no,
    count(*) as kensu,
    sum(kin) as goukei
from
    tbt_kou_mitu_detail a
where
    a.del_flg = '0'
group by
    a.user_company_id,
    a.mitu_no;
-- ------------------------------------------------------

--
-- view structure for view tbv_kou_mitu_list
--
-- 見積ヘッダの為の情報
--
create view tbv_kou_mitu_list as
select
    sts.sts_kb,
    h.code_nm,
    sts.syukkin_dt,
    hed.user_company_id,
    hed.mitu_no,
    hed.mitu_dt,
    hed.hako_dt,
    hed.toroku_staff_cd,                    -- 登録者スタッフコード
    f.personal_nm as toroku_personal_nm,    -- 登録者名
    hed.toroku_organization_id,             -- 登録者部署
    i.bunrui_nm as toroku_organization,
    e.tanto_staff_cd,                       -- 担当者スタッフコード
    e.personal_nm as tanto_personal_nm,     -- 担当者名
    hed.tanto_organization_id,              -- 担当者部署
    j.bunrui_nm as tanto_organization,
    hed.siire_id,
    d.siire_cd_nm as siire_nm,
    '' as siire_url,                      -- 仕入先URL
    hed.kaitonouki_dt,
    hed.mitu_title,
    dtl.kensu,
    dtl.goukei
from
    tmp_kou_mitu_list_1 sts
    join tbt_kou_mitu hed
         on(sts.user_company_id = hed.user_company_id and sts.mitu_no = hed.mitu_no and hed.del_flg = '0')
    join tmp_kou_mitu_list_2 dtl
         on(hed.user_company_id = dtl.user_company_id and hed.mitu_no = dtl.mitu_no)
    left outer join tbv_siire d
         on(sts.user_company_id = d.user_company_id and hed.siire_id = d.siire_id)
    left outer join tbv_kou_mitu_tanto e
         on(hed.user_company_id = e.user_company_id and hed.tanto_staff_cd = e.tanto_staff_cd)
    left outer join tbv_kou_mitu_regist_user f
         on(hed.user_company_id = f.user_company_id and hed.toroku_staff_cd = f.toroku_staff_cd)
    left outer join tbv_siire g
         on(hed.user_company_id = d.user_company_id and hed.siire_id = d.siire_id)
    left outer join tbm_code h
         on(sts.user_company_id = h.user_company_id and sts.sts_kb = h.code and h.code_kb = '21' and h.del_flg = '0')
    left outer join tbm_bunrui i
         on(hed.user_company_id = i.user_company_id and i.bunrui_kb = '6' and hed.toroku_organization_id = i.bunrui_id and i.del_flg = '0')
    left outer join tbm_bunrui j
         on(hed.user_company_id = j.user_company_id and j.bunrui_kb = '6' and hed.tanto_organization_id = j.bunrui_id  and j.del_flg = '0')
where
    sts.sts_kb >= '050';
-- ------------------------------------------------------

--
-- view structure for view tmp_kou_mitu_detail_list0
--
-- 見積ヘッダと明細を紐付けたもの（主が明細）
-- ※明細の削除フラグは現状考えない。（明細は物理削除の為）
--
create view tmp_kou_mitu_detail_list0 as
select
    hed.user_company_id,
    hed.mitu_no,
    dtl.mitu_edano,
    hed.hako_dt,
    hed.toroku_staff_cd,                    -- 登録者スタッフコード
    f.personal_nm as toroku_personal_nm,    -- 登録者名
    hed.toroku_organization_id,             -- 登録者部署
    i.bunrui_nm as toroku_organization,
    e.tanto_staff_cd,                       -- 担当者スタッフコード
    e.personal_nm as tanto_personal_nm,     -- 担当者名
    hed.tanto_organization_id,              -- 担当者部署
    j.bunrui_nm as tanto_organization,
    hed.siire_id,
    hed.kaitonouki_dt,
    hed.mitu_title,
    dtl.item_id,
    dtl.product_nm,
    dtl.product_kikaku,
    dtl.syubetu,
    dtl.su,
    dtl.tani_nm,
    dtl.tanka,
    dtl.kin,
    dtl.biko
from
    tbt_kou_mitu hed
    join tbt_kou_mitu_detail dtl
         on(hed.user_company_id = dtl.user_company_id and hed.mitu_no = dtl.mitu_no)
    left outer join tbv_kou_mitu_tanto e
         on(hed.user_company_id = e.user_company_id and hed.tanto_staff_cd = e.tanto_staff_cd)
    left outer join tbv_kou_mitu_regist_user f
         on(hed.user_company_id = f.user_company_id and hed.toroku_staff_cd = f.toroku_staff_cd)
    left outer join tbm_bunrui i
         on(hed.user_company_id = i.user_company_id and i.bunrui_kb = '6' and hed.toroku_organization_id = i.bunrui_id and i.del_flg = '0')
    left outer join tbm_bunrui j
         on(hed.user_company_id = j.user_company_id and j.bunrui_kb = '6' and hed.tanto_organization_id = j.bunrui_id  and j.del_flg = '0')
where
    hed.del_flg ='0';
-- ------------------------------------------------------

--
-- view structure for view tbv_kou_mitu_detail_list
--
-- 画面にて使用する明細情報用
-- 明細が主となる見積情報とステータステーブルの紐付け
--
create view tbv_kou_mitu_detail_list as
select
    ord.user_company_id,
    ord.mitu_no,
    ord.mitu_edano,
    sts.sts_kb,
    cdm.code_nm,
    ord.item_id,
    ord.product_nm,
    ord.product_kikaku,
    ord.syubetu,
    ord.su,
    ord.tani_nm,
    ord.tanka,
    ord.kin,
    ord.biko
from
    tmp_kou_mitu_detail_list0 ord
    join tbt_kou_status sts
         on(ord.user_company_id = sts.user_company_id and ord.mitu_no = sts.mitu_no and ord.mitu_edano = sts.mitu_edano and sts.del_flg = '0' and sts.sts_kb >= '050')
    left outer join tbm_code cdm
         on(sts.user_company_id = cdm.user_company_id and sts.sts_kb = cdm.code and cdm.code_kb = '21' and cdm.del_flg = '0');
