--
-- view structure for view tbv_han_mitu_tanto
-- 見積担当者の一覧を見積テーブルから抽出
--
create view tbv_han_mitu_tanto as
select
    distinct
    a.user_company_id,
    a.tanto_staff_cd,
    b.personal_nm
from
    tbt_han_mitu a
    left outer join tbv_syain b
         on a.user_company_id = b.user_company_id and a.tanto_staff_cd = b.staff_cd
where a.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_han_mitu_regist_user
--
create view tbv_han_mitu_regist_user as
select
    distinct
    a.user_company_id,
    a.toroku_staff_cd,
    b.personal_nm
from
    tbt_han_mitu a
    left outer join tbv_syain b
         on a.user_company_id = b.user_company_id and a.toroku_staff_cd = b.staff_cd
where a.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tmp_han_mitu_list_0
--
-- ステータステーブルを見積番号・受注番号・入金番号でグループ
--
create view tmp_han_mitu_list_0 as 
select
    sta.user_company_id as user_company_id,
    sta.mitu_no as mitu_no,
    sta.order_no as order_no,
    sta.nyukin_no as nyukin_no,
    min(sta.sts_kb) as sts_kb
from
    tbt_han_status sta 
where
    sta.del_flg = '0'
group by
    sta.user_company_id,
    sta.mitu_no,
    sta.order_no,
    sta.nyukin_no;
-- ------------------------------------------------------

--
-- view structure for view tmp_han_mitu_list_1
--
-- ステータステーブルを見積番号・受注番号でグループ化し、
-- 入金番号が入っている場合には、最大となる入金日を取得。
-- （一覧での検索用）
--
create view tmp_han_mitu_list_1 as 
select
    a.user_company_id as user_company_id,
    a.mitu_no as mitu_no,
    a.order_no as order_no,
    min(a.sts_kb) as sts_kb,
    max(b.nyukin_dt) as nyukin_dt
from
    tmp_han_order_list_0 a 
    left outer join tbt_han_nyukin b 
    on(a.user_company_id = b.user_company_id and a.nyukin_no = b.nyukin_no and b.del_flg = '0')
group by
    a.user_company_id,
    a.mitu_no,
    a.order_no;
-- ------------------------------------------------------

--
-- view structure for view tmp_han_mitu_list_2
--
-- 見積番号ごとでの明細件数および、見積金額を取得
--
create view tmp_han_mitu_list_2 as
select
    a.user_company_id,
    a.mitu_no,
    count(*) as kensu,
    sum(kin) as goukei
from
    tbt_han_mitu_detail a
where
    a.del_flg = '0'
group by
    a.user_company_id,
    a.mitu_no;
-- ------------------------------------------------------

--
-- view structure for view tbv_han_mitu_list
--
-- 見積ヘッダの為の情報
--
create view tbv_han_mitu_list as
select
    sts.sts_kb,
    h.code_nm,
    sts.nyukin_dt,
    sts.order_no,
    hed.user_company_id,	
    hed.mitu_no,
    hed.mitu_dt,
    hed.hako_dt,
    hed.toroku_staff_cd,
    f.personal_nm as toroku_staff_nm,
    hed.toroku_organization_id,
    k.bunrui_nm as toroku_organization,
    hed.tanto_staff_cd,
    e.personal_nm as tanto_staff_nm,
    hed.tanto_organization_id,
    l.bunrui_nm as tanto_organization,
    hed.tokui_id,
    d.tokui_cd_nm as tokui_nm,
    cast('' as varchar) as company_url,
    hed.kaitonouki_dt,
    hed.mitu_title,
    hed.syonin_rireki_id,
    hed.syonin_dt,
    i.syonin_id as last_syonin_auth_group_id,
    j.route_id as final_syonin_auth_group_id,
    dtl.kensu,
    dtl.goukei
from
    tmp_han_mitu_list_1 sts
    join tbt_han_mitu hed
         on(sts.user_company_id = hed.user_company_id and sts.mitu_no = hed.mitu_no and hed.del_flg = '0')
    join tmp_han_mitu_list_2 dtl
         on(hed.user_company_id = dtl.user_company_id and hed.mitu_no = dtl.mitu_no)
    left outer join tbv_tokui d
         on(hed.user_company_id = d.user_company_id and hed.tokui_id = d.tokui_id)
    left outer join tbv_han_mitu_tanto e
         on(hed.user_company_id = e.user_company_id and hed.tanto_staff_cd = e.tanto_staff_cd)
    left outer join tbv_han_mitu_regist_user f
         on(hed.user_company_id = f.user_company_id and hed.toroku_staff_cd = f.toroku_staff_cd)
    left outer join tbv_tokui g
         on(hed.user_company_id = g.user_company_id and hed.tokui_id = g.tokui_id)
    left outer join tbm_code h
         on(sts.user_company_id = h.user_company_id and sts.sts_kb = h.code and h.code_kb = '24' and h.del_flg = '0')
    left outer join tbt_syonin_rireki i
         on(hed.user_company_id = i.user_company_id and hed.syonin_rireki_id = i.syonin_rireki_id and i.del_flg = '0')
    left outer join tbm_route j
         on(hed.user_company_id = hed.user_company_id and j.route_kb = '6' and j.route_cd = '2' and j.del_flg = '0' and j.up_route_id is null )
    left outer join tbm_bunrui k
         on(hed.user_company_id = k.user_company_id and k.bunrui_kb = '6' and hed.toroku_organization_id = k.bunrui_id  and k.del_flg = '0')
    left outer join tbm_bunrui l
         on(hed.user_company_id = l.user_company_id and l.bunrui_kb = '6' and hed.tanto_organization_id = l.bunrui_id  and l.del_flg = '0')
where
    sts.sts_kb >= '040';
-- ------------------------------------------------------

--
-- view structure for view tmp_han_mitu_detail_list0
--
-- 見積ヘッダと明細を紐付けたもの（主が明細）
-- ※明細の削除フラグは現状考えない。（明細は物理削除の為）
--
create view tmp_han_mitu_detail_list0 as
select 
    hed.user_company_id,
    hed.mitu_no,
    dtl.mitu_edano,
    hed.hako_dt,
    hed.toroku_staff_cd,
    hed.toroku_organization_id,
    k.bunrui_nm as toroku_organization,
    hed.tanto_staff_cd,
    hed.tanto_organization_id,
    l.bunrui_nm as tanto_organization,
    hed.tokui_id,
    hed.kaitonouki_dt,
    hed.mitu_title,
    dtl.item_id,
    dtl.product_nm,
    dtl.product_kikaku,
    dtl.syubetu,
    dtl.su,
    dtl.tani_nm,
    dtl.tanka,
    dtl.kin,
    dtl.biko    
from 
    tbt_han_mitu hed
    join tbt_han_mitu_detail dtl
         on(hed.user_company_id = dtl.user_company_id and hed.mitu_no = dtl.mitu_no)
    left outer join tbm_bunrui k
         on(hed.user_company_id = k.user_company_id and k.bunrui_kb = '6' and hed.toroku_organization_id = k.bunrui_id  and k.del_flg = '0')
    left outer join tbm_bunrui l
         on(hed.user_company_id = l.user_company_id and l.bunrui_kb = '6' and hed.tanto_organization_id = l.bunrui_id  and l.del_flg = '0')
where
    hed.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_han_mitu_detail_list
--
-- 画面にて使用する明細情報用
-- 明細が主となる見積情報とステータステーブルの紐付け
--
CREATE VIEW tbv_han_mitu_detail_list AS 
 SELECT ord.user_company_id, ord.mitu_no, ord.mitu_edano, sts.sts_kb, cdm.code_nm, ord.item_id, a.item_cd, ord.product_nm, ord.product_kikaku, ord.syubetu, ord.su, ord.tani_nm, ord.tanka, ord.kin, ord.biko
   FROM tmp_han_mitu_detail_list0 ord
   JOIN tbt_han_status sts ON ord.user_company_id = sts.user_company_id AND ord.mitu_no = sts.mitu_no AND ord.mitu_edano = sts.mitu_edano
   LEFT JOIN tbm_code cdm ON sts.user_company_id = cdm.user_company_id AND sts.sts_kb::text = cdm.code::text AND cdm.code_kb::text = '24'::text AND cdm.del_flg::text = '0'::text
   LEFT JOIN tbm_item a ON ord.user_company_id = a.user_company_id AND ord.item_id = a.item_id AND a.del_flg::text = '0'::text
  WHERE sts.del_flg::text = '0'::text AND sts.sts_kb::text >= '040'::text;
