--
-- view structure for view tbv_maker
--
create view tbv_maker as
select
    a.user_company_id,
    a.company_id,
    a.maker_id,
    a.maker_cd,
    b.company_nm as maker_nm,
    b.company_kn as maker_kn,
    c.tel,
    c.fax,
    b.mail,
    c.zipcode,
    c.address1,
    c.address2,
    c.address3,
    c.address4
from
    tbm_maker a,
    tbm_company_base b,
    tbm_company_address c
where     a.user_company_id = b.user_company_id
    and   a.company_id      = b.company_id
    and   a.user_company_id = c.user_company_id
    and   a.company_id      = c.company_id
    and   a.del_flg = '0'
    and   b.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_tanto
--
create view tbv_tanto as
select
    f.user_company_id,
    f.tanto_id,
    f.personal_id,
    a.personal_nm,
    a.personal_kn,
    a.birthday,
    cast(substr(a.birthday,1,4) as varchar) as birthday_yy,
    cast(substr(a.birthday,5,2) as varchar) as birthday_mm,
    cast(substr(a.birthday,7,2) as varchar) as birthday_dd,
    a.company_id,
    a.company_nm,
    a.organization_id,
    i.bunrui_nm as organization,
    a.official_id,
    a.official_nm,
    a.tel_in,
    a.mobile,
    a.office_mail as mail,
    a.personal_zipcode  as zipcode,
    a.personal_address1 as address1,
    a.personal_address2 as address2,
    a.personal_address3 as address3,
    a.personal_address4 as address4
from
    tbm_tanto f,
    tbv_personal_info a
    left outer join tbm_bunrui i
         on(a.user_company_id = i.user_company_id and i.bunrui_kb = '6' and a.organization_id = i.bunrui_id and i.del_flg = '0')
where     f.user_company_id   =   a.user_company_id
    and   f.personal_id       =   a.personal_id
    and   f.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_syain
--
create view tbv_syain as
select
    a.user_company_id,
    a.personal_id,
    b.staff_cd,
    a.personal_nm as personal_real_nm,
    case when b.retire_dt is null then a.personal_nm else  '【退職者】' || a.personal_nm end as personal_nm,
    a.personal_kn,
    a.birthday,
    b.organization_id,
    i.bunrui_nm as organization,
    b.official_id,
    d.official_nm,
    b.tel_in,
    b.mobile,
    b.mail,
    b.enter_dt,
    b.retire_dt,
    c.zipcode,
    c.address1,
    c.address2,
    c.address3,
    c.address4,
    a.ical_file,
    j.user_cd,
    j.password,
    j.auth_group_id
from
    tbm_personal_base a
    join tbm_employee_property b
--         on (a.user_company_id=b.user_company_id and a.personal_id=b.personal_id and b.user_company_id = b.company_id and b.staff_cd <> '')
         on (a.user_company_id=b.user_company_id and a.personal_id=b.personal_id and b.user_company_id = b.company_id and b.del_flg='0')
    join tbm_personal_address c
         on (a.user_company_id=c.user_company_id and a.personal_id=c.personal_id)
    left outer join tbm_official_title d
         on (a.user_company_id=d.user_company_id and b.official_id=d.official_id and d.del_flg='0')
    left outer join tbm_bunrui i
         on(b.user_company_id = i.user_company_id and i.bunrui_kb = '6' and b.organization_id = i.bunrui_id and i.del_flg = '0')
    left outer join tbm_user_info j
         on(a.user_company_id = j.user_company_id and a.personal_id=j.personal_id  and j.del_flg = '0')
where a.del_flg = '0';
-- ------------------------------------------------------
--

-- view structure for view tbv_tokui
--
create view tbv_tokui as
select
    a.user_company_id,
    a.company_id,
    a.tokui_id,
    a.tokui_cd,
    case when a.tokui_cd is null then b.company_nm else a.tokui_cd || ' ' || b.company_nm end as tokui_cd_nm,
    b.company_nm as tokui_nm,
    b.company_kn as tokui_kn,
    b.branch_nm,
    b.branch_kn,
    b.president,
    c.tel,
    c.fax,
    b.mail,
    c.zipcode,
    c.address1,
    c.address2,
    c.address3,
    c.address4,
    a.seikyu_id,
    e.tokui_cd as seikyu_cd,
    a.zei_kb,
    a.seikyu_kb,
    a.seikyu_style_kb,
    a.simebi,
    a.zatu_kb,
    a.zei_keisan_kb,
    a.zei_hasuu_kb,
    a.sight,
    a.kaisyu_hou1_kb,
    a.kaisyu_hou2_kb,
    a.kaisyu_hani_kin,
    a.seikyu_bu_su,
--    a.bank_id,
--    a.jisya_tanto_id,
--    d.personal_nm,
    d.staff_cd as tanto_staff_cd,
    d.personal_nm as tanto_staff_nm,
    d.organization_id,
    i.bunrui_nm as organization,
    a.haisou_id,
    a.okuri_cd,
    e.seikyu_kb       as sei_seikyu_kb,                        -- 請求先の請求区分（1:都度 2:締）
    e.seikyu_style_kb as sei_seikyu_style_kb,                  -- 請求スタイル区分 (1:繰越 2:繰り越さない)
    e.zei_kb          as sei_zei_kb,                           -- 税区分           (1:内税 2:外税 3:非課税)
    e.zei_keisan_kb   as sei_zei_keisan_kb,                    -- 税計算区分       (1:請求毎 2:納品伝票毎 3:明細毎)
    e.zei_hasuu_kb    as sei_zei_hasuu_kb,                     -- 消費税端数処理   (1:切捨て 2:四捨五入 3:切り上げ)
    f.code_nm  || '　' ||  g.code_nm    || '　' ||  h.code_nm  as detail_zei,
    b.logo_image_path,
    b.yosin_kin,
    b.start_dt,
    b.end_dt
from
    tbm_tokui a
    inner join tbm_company_base b
         on(a.user_company_id = b.user_company_id and a.company_id = b.company_id and b.del_flg='0')
    inner join tbm_company_address c
         on(a.user_company_id = c.user_company_id and a.company_id = c.company_id)
    left outer join tbv_syain d
         on (a.user_company_id = d.user_company_id and a.tanto_staff_cd = d.staff_cd)
    left outer join tbm_tokui e
         on (a.user_company_id = e.user_company_id and a.seikyu_id = e.tokui_id and e.del_flg = '0')
    left outer join tbm_code f
          on (a.zei_kb = f.code and f.code_kb = '4' and f.del_flg = '0')
    left outer join tbm_code g
          on (a.zei_keisan_kb = g.code and g.code_kb = '5' and g.del_flg = '0')
    left outer join tbm_code h
          on (a.zei_hasuu_kb = h.code and h.code_kb = '20' and h.del_flg = '0')
    left outer join tbm_bunrui i
         on(d.user_company_id = i.user_company_id and i.bunrui_kb = '6' and d.organization_id = i.bunrui_id and i.del_flg = '0')
where a.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_siire
--
create view tbv_siire as
select
    a.user_company_id,
    a.company_id,
    a.siire_id,
    a.siire_cd,
    case when a.siire_cd is null then b.company_nm else a.siire_cd || ' ' || b.company_nm end as siire_cd_nm,
    b.company_nm as siire_nm,
    b.company_kn as siire_kn,
    b.branch_nm,
    b.branch_kn,
    c.tel,
    c.fax,
    b.mail,
    c.zipcode,
    c.address1,
    c.address2,
    c.address3,
    c.address4,
    a.siharai_id,
    e.siire_cd as siharai_cd,
    a.zatu_kb,
    a.siharai_kb,
    a.siharai_style_kb,
    a.simebi,
    a.zei_kb,
    a.zei_keisan_kb,
    a.zei_hasuu_kb,
    a.sight,
    a.siharai_hou1_kb,
    a.siharai_hou2_kb,
    a.siharai_hani_kin,
--    a.bank_id,
    e.siharai_kb       as si_siharai_kb,                    -- 支払先の支払区分（1:都度 2:締）
    e.siharai_style_kb as si_siharai_style_kb,              -- 支払スタイル区分 (1:繰越 2:繰り越さない)
    e.zei_kb          as sei_zei_kb,                           -- 税区分           (1:内税 2:外税 3:非課税)
    e.zei_keisan_kb   as sei_zei_keisan_kb,                    -- 税計算区分       (1:請求毎 2:納品伝票毎 3:明細毎)
    e.zei_hasuu_kb    as sei_zei_hasuu_kb,                     -- 消費税端数処理   (1:切捨て 2:四捨五入 3:切り上げ)
    f.code_nm  || '　' ||  g.code_nm    || '　' ||  h.code_nm  as detail_zei,
    b.logo_image_path,
    b.yosin_kin,
    b.start_dt,
    b.end_dt
from
    tbm_siire a
    inner join tbm_company_base b
         on(a.user_company_id = b.user_company_id and a.company_id = b.company_id and b.del_flg = '0')
    inner join tbm_company_address c
         on(a.user_company_id = c.user_company_id and a.company_id = c.company_id)
--    left outer join tbv_syain d
--         on (a.user_company_id = d.user_company_id and a.jisya_tanto_id = d.staff_cd)
    left outer join tbm_siire e
         on (a.user_company_id = e.user_company_id and a.siharai_id = e.siire_id and e.del_flg = '0')
    left outer join tbm_code f
          on (a.zei_kb = f.code and f.code_kb = '4' and f.del_flg = '0')
    left outer join tbm_code g
          on (a.zei_keisan_kb = g.code and g.code_kb = '5' and g.del_flg = '0')
    left outer join tbm_code h
          on (a.zei_hasuu_kb = h.code and h.code_kb = '20' and h.del_flg = '0')
where a.del_flg = '0';
-- ------------------------------------------------------

-- 20060508shimizu追加
--
-- view structure for view tbv_code
--
create view tbv_code as
select
    a.user_company_id,
    a.code_kb,
    a.code,
    a.code_nm
from
    tbm_code a
where
    a.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tmp_feature_0
--
create view tmp_feature_0 as
select
    count(a.user_company_id) as item_su,
    a.user_company_id,
    a.feature_cd
from
    tbm_item a
where
    a.del_flg = '0'
    and a.feature_cd <> ''
    and a.feature_cd is not null
group by
    a.user_company_id,
    a.feature_cd;
-- ------------------------------------------------------

-- 20060515shimizu追加
--
-- view structure for view tbv_feature
--
create view tbv_feature as
select
    a.user_company_id,
    a.feature_cd,
    a.feature_nm,
    case when b.item_su is null then 0 else b.item_su end as item_su
from
    tbm_feature a
    left outer join tmp_feature_0 b
         on(a.user_company_id = b.user_company_id and a.feature_cd = b.feature_cd)
where
    a.del_flg = '0';
-- ------------------------------------------------------

-- 20060515shimizu追加
--
-- view structure for view tbv_feature_detail
--
create view tbv_feature_detail as
select
    a.user_company_id ,
    a.feature_cd,
    a.feature_eda,
    a.feature_detail_nm,
    case when b.item_su is null then 0 else b.item_su end as item_su
from
    tbm_feature_detail a
    left outer join tmp_feature_0 b
         on(a.user_company_id = b.user_company_id and a.feature_cd = b.feature_cd)
where
    a.del_flg = '0';
-- ------------------------------------------------------

-- 20060515 追加 S.Tajima
--
-- view structure for view tbv_official_title
--
create view tbv_official_title as
select
    a.user_company_id ,
    a.official_id,
    a.orderno,
    a.official_nm
from
    tbm_official_title a
where
    a.del_flg = '0';
-- ------------------------------------------------------

-- 20060515 追加 S.Tajima
-- 20070417 修正 Y.Kato
--
-- view structure for view tbv_personal_export
--
create view tbv_personal_export as
select
    a.user_company_id,
    a.personal_id,
    a.personal_nm,
    a.personal_kn,
    a.birthday,
    a.personal_zipcode,
    a.personal_address1,
    a.personal_address2,
    a.personal_address3,
    a.personal_address4,
    a.personal_fax,
    a.company_kn,
    a.company_nm,
    a.company_url,
    a.mobile as company_mobile,
    a.company_mail,
    a.company_zipcode,
    a.company_address1,
    a.company_address2,
    a.company_address3,
    a.company_address4,
    a.organization_id,
    i.bunrui_nm as organization,
    a.official_nm,
    a.company_tel,
    a.company_fax,
    a.tel_in,
    a.parent_zipcode,
    a.parent_address1,
    a.parent_address2,
    a.parent_address3,
    a.parent_address4,
    a.parent_fax,
    a.etc
from
    tbv_personal_info a
--    2008/06/19 del akiyama
--    left outer join tbv_company_info  b
--        on (a.user_company_id = b.user_company_id and a.company_id = b.company_id)
    left outer join tbm_bunrui i
        on (a.user_company_id = i.user_company_id and i.bunrui_kb = '6' and a.organization_id = i.bunrui_id and i.del_flg = '0');
-- ------------------------------------------------------

-- 20060515shimizu追加
--
-- view structure for view tbv_bunrui
--
create view tbv_bunrui as
select
    a.user_company_id ,
    a.bunrui_kb,
    a.bunrui_id,
    case when c.bunrui_id is null and b.bunrui_id is null then 1 else
        case when c.bunrui_id is null and b.bunrui_id is not null then 2 else
        case when c.bunrui_id is not null and b.bunrui_id is not null then 3 end end end as bunrui_kaiso,
    case when c.bunrui_id is null and b.bunrui_id is null then cast(lpad(cast(a.bunrui_id as varchar),4,'0')||'00000000' as decimal(15))else
        case when c.bunrui_id is null and b.bunrui_id is not null then cast(lpad(cast(b.bunrui_id as varchar),4,'0')||lpad(cast(a.bunrui_id as varchar),4,'0')||'0000'  as decimal(15))else
        case when c.bunrui_id is not null and b.bunrui_id is not null then cast(lpad(cast(c.bunrui_id as varchar),4,'0')||lpad(cast(b.bunrui_id as varchar),4,'0')||lpad(cast(a.bunrui_id as varchar),4,'0')  as decimal(15)) end end end as bunrui_kanri_cd,
    a.up_bunrui_id,
    a.bunrui_cd,
    a.bunrui_nm,
    a.orderno,
    case when c.bunrui_id is null and b.bunrui_id is null then a.bunrui_id else
        case when c.bunrui_id is null and b.bunrui_id is not null then b.bunrui_id else
        case when c.bunrui_id is not null and b.bunrui_id is not null then c.bunrui_id end end end as bunrui1_id,
    case when c.bunrui_id is null and b.bunrui_id is null then a.bunrui_nm else
        case when c.bunrui_id is null and b.bunrui_id is not null then b.bunrui_nm else
        case when c.bunrui_id is not null and b.bunrui_id is not null then c.bunrui_nm end end end as bunrui1_nm,
    case when c.bunrui_id is null and b.bunrui_id is null then null else
        case when c.bunrui_id is null and b.bunrui_id is not null then a.bunrui_id else
        case when c.bunrui_id is not null and b.bunrui_id is not null then b.bunrui_id end end end as bunrui2_id,
    case when c.bunrui_id is null and b.bunrui_id is null then null else
        case when c.bunrui_id is null and b.bunrui_id is not null then a.bunrui_nm else
        case when c.bunrui_id is not null and b.bunrui_id is not null then b.bunrui_nm end end end as bunrui2_nm,
    case when c.bunrui_id is null and b.bunrui_id is null then null else
        case when c.bunrui_id is null and b.bunrui_id is not null then null else
        case when c.bunrui_id is not null and b.bunrui_id is not null then a.bunrui_id end end end as bunrui3_id,
    case when c.bunrui_id is null and b.bunrui_id is null then null else
        case when c.bunrui_id is null and b.bunrui_id is not null then null else
        case when c.bunrui_id is not null and b.bunrui_id is not null then a.bunrui_nm end end end as bunrui3_nm,
    case when c.bunrui_id is null and b.bunrui_id is null then case when a.orderno is null then 999999999999999 else a.orderno end else
        case when c.bunrui_id is null and b.bunrui_id is not null then case when b.orderno is null then 999999999999999 else b.orderno end else
        case when c.bunrui_id is not null and b.bunrui_id is not null then case when c.orderno is null then 999999999999999 else c.orderno end end end end as bunrui1_order,
    case when c.bunrui_id is null and b.bunrui_id is null then null else
        case when c.bunrui_id is null and b.bunrui_id is not null then case when a.orderno is null then 999999999999999 else a.orderno end else
        case when c.bunrui_id is not null and b.bunrui_id is not null then case when b.orderno is null then 999999999999999 else b.orderno end end end end as bunrui2_order,
    case when c.bunrui_id is null and b.bunrui_id is null then null else
        case when c.bunrui_id is null and b.bunrui_id is not null then null else
        case when c.bunrui_id is not null and b.bunrui_id is not null then case when a.orderno is null then 999999999999999 else a.orderno end end end end as bunrui3_order
from tbm_bunrui a
     left outer join tbm_bunrui b
           on (a.user_company_id = b.user_company_id and a.bunrui_kb = b.bunrui_kb and a.up_bunrui_id = b.bunrui_id and b.del_flg = '0')
     left outer join tbm_bunrui c
           on (b.user_company_id = c.user_company_id and b.bunrui_kb = c.bunrui_kb and b.up_bunrui_id = c.bunrui_id and c.del_flg = '0')
where a.del_flg = '0';
-- ------------------------------------------------------

--
--
-- view structure for view tbv_item
--
create view tbv_item as
select
    a.user_company_id as user_company_id,
    a.item_id as item_id,
    a.item_cd as item_cd,
    a.jan_cd as jan_cd,
    a.item_nm as item_nm,
    case when a.item_cd is null then a.item_nm else a.item_cd || ' ' || a.item_nm end as item_cd_nm,
    a.item_kb,
    a.item_kikaku as item_kikaku,
    a.syubetu as syubetu,
    a.maker_id as maker_id,
--    2008/06/19 rep akiyama
--    b.bunrui_id as bunrui1_id,
--    b.bunrui_nm as bunrui1_nm,
--    c.bunrui_id as bunrui2_id,
--    c.bunrui_nm as bunrui2_nm,
--    d.bunrui_id as bunrui3_id,
--    d.bunrui_nm as bunrui3_nm,
    e.bunrui1_id as bunrui1_id,
    e.bunrui1_nm as bunrui1_nm,
    e.bunrui2_id as bunrui2_id,
    e.bunrui2_nm as bunrui2_nm,
    e.bunrui3_id as bunrui3_id,
    e.bunrui3_nm as bunrui3_nm,
    a.minimum_su as minimum_su,
    a.standard_tnk as standard_tnk,
    a.standardcost_tnk as standardcost_tnk,
    a.item_bikou as item_bikou,
    a.itf_cd as itf_cd,
    a.size as size,
    a.color as color,
    a.irisu as irisu,
    a.tani_cd as tani_cd,
    a.group_cd as group_cd,
    a.pos_cd as pos_cd,
    a.aite_item_cd as aite_item_cd,
    a.start_dt as start_dt,
    substr(a.start_dt, 1,4) as start_dt_yy,
    substr(a.start_dt, 5,2)   as start_dt_mm,
    substr(a.start_dt, 7,2)   as start_dt_dd,
    a.end_dt as end_dt,
    substr(a.end_dt, 1,4) as end_dt_yy,
    substr(a.end_dt, 5,2)   as end_dt_mm,
    substr(a.end_dt, 7,2)   as end_dt_dd,
    a.item_path,
    a.feature_cd,
    a.featuresyo1_dt,
    a.featuresyo2_dt,
    a.featuresyo3_dt,
    a.featuresyo4_dt,
    a.featuresyo5_dt,
    a.featuresyo6_dt,
    a.featuresyo7_dt,
    a.featuresyo8_dt,
    a.featuresyo9_dt,
    a.featuresyo10_dt,
    a.tax_kb
from
    tbm_item a
    left outer join tbv_bunrui e
         on (a.user_company_id=e.user_company_id and a.bunrui_kb=e.bunrui_kb and a.bunrui_id=e.bunrui_id)
--    2008/06/19 del akiyama
--    left outer join tbv_bunrui b
--         on (e.user_company_id=b.user_company_id and e.bunrui_kb=b.bunrui_kb and e.bunrui1_id=b.bunrui_id)
--    left outer join tbv_bunrui c
--         on (e.user_company_id=c.user_company_id and e.bunrui_kb=c.bunrui_kb and e.bunrui2_id=c.bunrui_id)
--    left outer join tbv_bunrui d
--         on (e.user_company_id=d.user_company_id and e.bunrui_kb=d.bunrui_kb and e.bunrui3_id=d.bunrui_id)
where a.del_flg = '0';
-- ------------------------------------------------------

-- 20060530tajima追加
--
-- view structure for view tbv_saiban
--
create view tbv_saiban as
select
    a.user_company_id,
    a.saiban_cd,
    a.saiban_nm,
    a.start_no,
    a.end_no,
    a.genzai_no,
    a.prefix_cd,
    case   when a.prefix_cd = '1' then '無し' else
      case when a.prefix_cd = '2' then '年4桁(yyyy)' else
      case when a.prefix_cd = '3' then '西暦8桁(yyyymmdd)' end end end as prefix_nm,   --prefixNm
    case   when a.prefix_cd = '1' then a.start_no else
      case when a.prefix_cd = '2' then to_number(to_char(current_date, 'yyyy'),'0000')*1000000 + a.start_no else
      case when a.prefix_cd = '3' then to_number(to_char(current_date, 'yyyymmdd'),'00000000')*1000000 + a.start_no end end end as prefix_start_no,
    case   when a.prefix_cd = '1' then a.end_no else
      case when a.prefix_cd = '2' then to_number(to_char(current_date, 'yyyy'),'0000')*1000000 + a.end_no else
      case when a.prefix_cd = '3' then to_number(to_char(current_date, 'yyyymmdd'),'00000000')*1000000 + a.end_no end end end as prefix_end_no,
    case   when a.prefix_cd = '1' then a.genzai_no else
      case when a.prefix_cd = '2' then to_number(to_char(current_date, 'yyyy'),'0000')*1000000 + a.genzai_no else
      case when a.prefix_cd = '3' then to_number(to_char(current_date, 'yyyymmdd'),'00000000')*1000000 + a.genzai_no end end end as prefix_genzai_no
from tbm_saiban a
where a.del_flg = '0';
-- ------------------------------------------------------

-- 20060606shimizu追加
--
-- view structure for view tbv_sisetubi
--
create view tbv_sisetubi as
select
    a.user_company_id,
    a.sisetubi_id,
    a.sisetubi_cd,
    a.sisetubi_kb,
    a.sisetubi_nm,
    a.sisetubi_user_cd,
    c.personal_nm as sisetubi_user_nm,
    a.syuyo_su,
    a.sisetubi_bk,
    b.code_nm as code_syubetu_nm
from tbm_sisetubi a
     left outer join tbm_code b
        on (a.sisetubi_kb = b.code and b.code_kb = '61' and b.del_flg = '0')
     left outer join tbv_personal_info c
        on (a.user_company_id = c.user_company_id and a.sisetubi_user_cd = c.staff_cd)
where a.del_flg = '0';
-- ------------------------------------------------------

-- 20061226shimizu口座マスター追加のため修正
-- 20060705shimizu追加
--
-- view structure for view tbv_bank
--
create view tbv_bank as
select
    a.user_company_id,
    a.bank_id,
    a.in_bank_cd,
    a.bank_kn,
    a.bank_nm,
    a.branch_nm,
    a.branch_kn,
    a.bank1_cd,
    a.bank2_cd
from
    tbm_bank a
where
    a.del_flg = '0';
-- ------------------------------------------------------

-- 20060705shimizu追加
--
-- view structure for view tbv_tax
--
create view tbv_tax as
select
    a.user_company_id,
    a.tax_id,
    a.tax_kb,
    a.tax_yuko_start_dt,
    a.old_tax_rt,
    a.new_tax_rt
from
    tbm_tax a
where
    a.del_flg = '0';
-- ------------------------------------------------------

-- 20060705shimizu追加
--
-- view structure for view tbv_nyukin_jyoken
--
create view tbv_nyukin_jyoken as
select
    a.user_company_id,
    a.tokui_id,
    a.nyukin_jyoken_id,
    a.range_kin,
    a.tegata_rt,
    a.tegata_month_dt,
    a.tegata_day_dt,
    a.tegata_kin,
    a.cash_rt,
    a.cash_month_dt,
    a.cash_day_dt,
    a.cash_kin
from
    tbm_nyukin_jyoken a
where
    a.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_tanka
--

create view tbv_item_tanka as
select
    a.user_company_id,
    a.tanka_id,
    a.item_id,
    b.item_cd,
    b.item_nm,
    b.jan_cd,
    a.tokui_id,
    c.tokui_nm,
    a.siire_id,
    d.siire_nm,
    a.tanka_kb,
    a.tanka,
    a.kari_tanka_kb,
    e.code_nm as kari_tanka_kb_nm,
    a.tanka_yuko_start_dt,
    a.tanka_yuko_end_dt
from
    tbm_item_tanka a
    inner join tbv_item b
      on (a.user_company_id = b.user_company_id  and a.item_id = b.item_id)
    left outer join tbv_tokui c
      on (a.user_company_id = c.user_company_id  and a.tokui_id = c.tokui_id)
    left outer join tbv_siire d
      on (a.user_company_id = d.user_company_id  and a.siire_id = d.siire_id)
    left outer join tbm_code e
      on (a.kari_tanka_kb = e.code and e.code_kb = '11' and e.del_flg = '0')
where 
    a.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_tanka_yuko_max
--

create view tbv_tanka_yuko_max as
select
    a.user_company_id,
    a.tanka_id,
    a.item_id,
    d.item_cd,
    d.item_nm,
    d.jan_cd,
    a.tokui_id,
    a.siire_id,
    a.tanka_kb,
    a.tanka,
    a.kari_tanka_kb,
    a.tanka_yuko_start_dt,
    a.tanka_yuko_end_dt,
    max(b.tanka_yuko_start_dt) as max_yuko_start_dt
from tbm_item_tanka a,
     tbm_item_tanka b,
     tbv_item d
where a.user_company_id = d.user_company_id
    and   a.item_id = d.item_id
    and   a.user_company_id = b.user_company_id
    and   a.item_id = b.item_id
    and   a.del_flg = '0'
    and   b.del_flg = '0'
group by
    a.user_company_id,
    a.tanka_id,
    a.item_id,
    d.item_cd,
    d.item_nm,
    d.jan_cd,
    a.tokui_id,
    a.siire_id,
    a.tanka_kb,
    a.tanka,
    a.kari_tanka_kb,
    a.tanka_yuko_start_dt,
    a.tanka_yuko_end_dt
having
    a.tanka_yuko_start_dt = max(b.tanka_yuko_start_dt);
-- ------------------------------------------------------

--
-- view structure for view tbv_su_tanka
--

create view tbv_su_tanka as
select
    a.user_company_id,
    a.tanka_id,
    a.item_id,
    a.tanka_kb,
    b.ika_su,
    b.su_rank_tnk,
    b.su_rank_kari_tanka_kb,
    c.code_nm
from tbm_item_tanka a,
     tbm_su_rank_tanka b,
     tbm_code c
where a.user_company_id = b.user_company_id
    and   a.tanka_id = b.tanka_id
    and   c.code_kb = '11'
    and   b.user_company_id = c.user_company_id
    and   b.su_rank_kari_tanka_kb = c.code
    and   a.del_flg = '0'
    and   b.del_flg = '0'
    and   c.del_flg = '0';
-- ------------------------------------------------------

-- 20060804 追加 T.Ohishi
-- 20080503 更新 Y.Kato a.okuri_nm → a.okuri_cd
--
-- view structure for view tbv_haisou
--
create view tbv_haisou as
select
    a.user_company_id,
    a.company_id,
    a.haisou_id,
    a.haisou_cd,
    --a.okuri_cd,
    b.company_nm as haisou_nm,
    b.company_kn as haisou_kn,
    c.tel,
    c.fax,
    b.mail,
    c.zipcode,
    c.address1,
    c.address2,
    c.address3,
    c.address4
from
    tbm_haisou a,
    tbm_company_base b,
    tbm_company_address c
where a.user_company_id = b.user_company_id
    and   a.company_id      = b.company_id
    and   a.user_company_id = c.user_company_id
    and   a.company_id      = c.company_id
    and   a.del_flg = '0'
    and   b.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_jisya
--
create view tbv_jisya as
select
    a.user_company_id,
    a.company_id,
    a.jisya_id,
    a.jisya_cd,
    b.company_nm as jisya_nm,
    b.company_kn as jisya_kn,
    c.tel,
    c.fax,
    b.mail,
    c.zipcode,
    c.address1,
    c.address2,
    c.address3,
    c.address4,
    a.zatu_kb,
    a.siharai_kb,
    a.siharai_style_kb,
    a.simebi,
    a.zei_kb,
    a.zei_keisan_kb,
    a.zei_hasuu_kb,
    a.sight,
    a.siharai_hou1_kb,
    a.siharai_hou2_kb,
    a.siharai_hani_kin,
--    a.bank_id,
    a.kisyu
from
    tbm_jisya a,
    tbm_company_base b,
    tbm_company_address c
where a.user_company_id = b.user_company_id
    and   a.company_id      = b.company_id
    and   a.user_company_id = c.user_company_id
    and   a.company_id      = c.company_id
    and   a.del_flg = '0'
    and   b.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tmp_seikyu_0
--
create view tmp_seikyu_0 as
select
    *
from
    tbm_tokui a
where a.del_flg = '0'
    and   a.tokui_id = a.seikyu_id
;
-- ------------------------------------------------------

--
-- view structure for view tbv_seikyu
--
create view tbv_seikyu as
select
    distinct
    a.user_company_id,
    a.company_id,
    a.seikyu_id as tokui_id,
    a.tokui_cd,
    case when a.tokui_cd is null then b.company_nm else a.tokui_cd || ' ' || b.company_nm end as tokui_cd_nm,
    b.company_nm as tokui_nm,
    b.company_kn as tokui_kn,
    b.branch_nm,
    b.branch_kn,
    b.president,
    c.tel,
    c.fax,
    b.mail,
    c.zipcode,
    c.address1,
    c.address2,
    c.address3,
    c.address4,
    a.zei_kb,
    a.seikyu_kb,
    a.seikyu_style_kb,
    a.simebi,
    a.zatu_kb,
    a.zei_keisan_kb,
    a.zei_hasuu_kb,
    a.sight,
    a.kaisyu_hou1_kb,
    a.kaisyu_hou2_kb,
    a.kaisyu_hani_kin,
    a.seikyu_bu_su,
--    a.bank_id,
    a.tanto_staff_cd,
    d.personal_nm,
    d.organization_id,
    i.bunrui_nm as organization,
    a.haisou_id,
    a.okuri_cd
from
    tmp_seikyu_0 a
    left outer join tbm_company_base b
         on (a.user_company_id = b.user_company_id and a.company_id = b.company_id and b.del_flg = '0')
    left outer join tbm_company_address c
         on (a.user_company_id = c.user_company_id and a.company_id = c.company_id)
    left outer join tbv_syain d
         on (a.user_company_id = d.user_company_id and a.tanto_staff_cd = d.staff_cd)
    left outer join tbm_bunrui i
         on(d.user_company_id = i.user_company_id and i.bunrui_kb = '6' and d.organization_id = i.bunrui_id and i.del_flg = '0')
where a.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_siharai
--
create view tbv_siharai as
select
    distinct
    a.user_company_id,
    a.company_id,
    a.siharai_id as siire_id,
    a.siire_cd,
    case when a.siire_cd is null then b.company_nm else a.siire_cd || ' ' || b.company_nm end as siire_cd_nm,
    b.company_nm as siire_nm,
    b.company_kn as siire_kn,
    b.branch_nm,
    b.branch_kn,
    c.tel,
    c.fax,
    b.mail,
    c.zipcode,
    c.address1,
    c.address2,
    c.address3,
    c.address4,
    a.zatu_kb,
    a.siharai_kb,
    a.siharai_style_kb,
    a.simebi,
    a.zei_kb,
    a.zei_keisan_kb,
    a.zei_hasuu_kb,
    a.sight,
    a.siharai_hou1_kb,
    a.siharai_hou2_kb,
    a.siharai_hani_kin
--    a.bank_id
from
    tbm_siire a,
    tbm_company_base b,
    tbm_company_address c
where a.user_company_id = b.user_company_id
    and   a.company_id      = b.company_id
    and   a.user_company_id = c.user_company_id
    and   a.company_id      = c.company_id
    and   a.del_flg = '0'
    and   b.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tmp_tbv_torihikisaki_koza_jisya
--
create view tmp_tbv_torihikisaki_koza_jisya as
select
    a.user_company_id ,
    a.torihikisaki_koza_id ,
    a.torihikisaki_kb ,
    a.torihikisaki_id ,
    a.bank_id ,
    a.order_no ,
    a.yokin_kb ,
    a.account_cd ,
    a.koza_meigi_nm ,
    a.biko ,
    b.jisya_nm as torihikisaki_nm,
    c.bank_nm,
    c.branch_nm
from
    tbm_torihikisaki_koza a
    join tbv_jisya b
        on (a.user_company_id = b.user_company_id and a.torihikisaki_id::numeric = b.jisya_id)
    join tbv_bank c
        on (a.user_company_id = c.user_company_id and a.bank_id = c.bank_id)
where a.del_flg = '0'
    and   a.torihikisaki_kb = '0';
-- ------------------------------------------------------

--
-- view structure for view tmp_tbv_torihikisaki_koza_tokui
--
create view tmp_tbv_torihikisaki_koza_tokui as
select
    a.user_company_id ,
    a.torihikisaki_koza_id ,
    a.torihikisaki_kb ,
    a.torihikisaki_id ,
    a.bank_id ,
    a.order_no ,
    a.yokin_kb ,
    a.account_cd ,
    a.koza_meigi_nm ,
    a.biko ,
    b.tokui_cd_nm as torihikisaki_nm,
    c.bank_nm,
    c.branch_nm
from
    tbm_torihikisaki_koza a
    join tbv_tokui b
        on (a.user_company_id = b.user_company_id and a.torihikisaki_id::numeric = b.tokui_id)
    join tbv_bank c
        on (a.user_company_id = c.user_company_id and a.bank_id = c.bank_id)
where a.del_flg = '0'
    and   a.torihikisaki_kb = '1';
-- ------------------------------------------------------

--
-- view structure for view tmp_tbv_torihikisaki_koza_siire
--
create view tmp_tbv_torihikisaki_koza_siire as
select
    a.user_company_id ,
    a.torihikisaki_koza_id ,
    a.torihikisaki_kb ,
    a.torihikisaki_id ,
    a.bank_id ,
    a.order_no ,
    a.yokin_kb ,
    a.account_cd ,
    a.koza_meigi_nm ,
    a.biko ,
    b.siire_cd_nm as torihikisaki_nm,
    c.bank_nm,
    c.branch_nm
from
    tbm_torihikisaki_koza a
    join tbv_siire b
        on (a.user_company_id = b.user_company_id and a.torihikisaki_id::numeric = b.siire_id)
    join tbv_bank c
        on (a.user_company_id = c.user_company_id and a.bank_id = c.bank_id)
where a.del_flg = '0'
    and   a.torihikisaki_kb = '2';
-- ------------------------------------------------------

--
-- view structure for view tbv_torihikisaki_koza
--
create view tbv_torihikisaki_koza as
select *
from
    tmp_tbv_torihikisaki_koza_jisya
union all
select *
from
    tmp_tbv_torihikisaki_koza_tokui
union all
select *
from
tmp_tbv_torihikisaki_koza_siire;
-- ------------------------------------------------------

--
-- view structure for view tbv_torihiki_tanka
--
create view tbv_torihiki_tanka as
SELECT a.user_company_id, a.torihiki_tanka_id, a.torihiki_kb, a.torihiki_id, 
   CASE
        WHEN a.torihiki_kb::text = 1::text THEN b.tokui_cd
        ELSE c.siire_cd
   END AS torihiki_cd, 
   CASE
        WHEN a.torihiki_kb::text = 1::text THEN e.company_nm
        ELSE f.company_nm
   END AS torihiki_nm, a.item_id, d.item_cd, d.item_nm, d.standard_tnk, a.item_tanka_kb, g.code_nm as item_tanka_kbnm, a.item_tanka
FROM tbm_torihiki_tanka a
   LEFT JOIN (tbm_tokui b
   JOIN tbm_company_base e ON b.user_company_id = e.user_company_id AND b.company_id = e.company_id) ON a.user_company_id = b.user_company_id AND a.torihiki_id = b.tokui_id AND a.torihiki_kb::text = 1::text AND b.del_flg::text = '0'::text
   LEFT JOIN (tbm_siire c
   JOIN tbm_company_base f ON c.user_company_id = f.user_company_id AND c.company_id = f.company_id) ON a.user_company_id = c.user_company_id AND a.torihiki_id = c.siire_id AND a.torihiki_kb::text = 2::text AND c.del_flg::text = '0'::text
   LEFT JOIN tbm_item d ON a.user_company_id = d.user_company_id AND a.item_id = d.item_id AND d.del_flg::text = '0'::text
   LEFT JOIN tbm_code g ON g.code_kb::text = '31'::text AND a.user_company_id = g.user_company_id AND a.item_tanka_kb::text = g.code::text AND g.del_flg::text = '0'::text
WHERE a.del_flg::text = '0'::text;
-- ------------------------------------------------------

--
-- view structure for view tbv_tana
--
create view tbv_tana as
select
    d.user_company_id ,
    d.tana_id,
    e.sisetubi_kb,
    e.code_syubetu_nm,
    d.sisetubi_id,
    e.sisetubi_cd,
    e.sisetubi_nm,
    a.bunrui_kb,
    a.bunrui_id,
    a.bunrui_kanri_cd,
    a.bunrui_cd,
    a.bunrui_nm,
    a.bunrui_kaiso,
    a.up_bunrui_id,
    a.bunrui1_id,
    a.bunrui1_nm,
    a.bunrui2_id,
    a.bunrui2_nm,
    a.bunrui3_id,
    a.bunrui3_nm,
    a.orderno
from tbm_tana d
     left outer join tbv_sisetubi e
        on (d.user_company_id = e.user_company_id and d.sisetubi_id = e.sisetubi_id)
     left outer join tbv_bunrui a
        on (d.user_company_id = a.user_company_id and d.bunrui_kb = a.bunrui_kb and d.bunrui_id = a.bunrui_id)
where
     d.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_repository
--
create view tbv_repository as
select
    a.user_company_id,
    a.repository_id,
    a.repository_nm,
    a.repository_path,
    a.repo_user_cd,
    a.repo_password,
    a.repository_kb,
    b.code_nm as repository_kb_nm,
    a.repo_checkout_dt,
    a.repo_update_dt
from
    tbm_repository a,
    tbm_code b
where
        a.del_flg = '0'
    and b.del_flg = '0'
    and a.user_company_id = b.user_company_id
    and a.repository_kb = b.code
    and b.code_kb = '32';
-- ------------------------------------------------------

--
-- view structure for view tbv_resource_computer
--
create view tbv_resource_computer as
select a.user_company_id,
       a.computer_id,
       a.computer_nm,
       a.type_cd,
       a.model_cd,
--       a.bunrui_kb,                                      -- 分類区分は当Viewでは不要の為、削除
--       a.bunrui_id,                                      -- 名称統一の為にコマントアウトし下記にorganization_idを追加
       a.user_staff_cd,
       a.sekinin_staff_cd,
       a.maker_id,
       a.sisetubi_id,
       a.os_cd,
       a.os_version_nm,
       a.os_sp_nm,
       a.serial_cd,
       a.biko,
       b.code_nm as type_nm,                               -- タイプ
       c.code_nm as model_nm,                              -- モデル
       a.organization_id as organization_id,               -- 利用者所属
       d.bunrui_nm       as organization,                   -- 利用者所属
       e.personal_nm as user_nm,                           -- 利用者名
       f.personal_nm as sekinin_nm,                        -- 責任者名
       g.sisetubi_kb,                                      -- 施設設備区分
       g.code_syubetu_nm as sisetubi_kb_nm,                -- 施設設備種別
       g.sisetubi_nm,                                      -- 施設名称
       h.code_nm as os_nm,                                 -- ＯＳ名称
       i.maker_nm                                          -- メーカ名称
from   tbm_resource_computer a
       left outer join tbm_code b
            on a.user_company_id = b.user_company_id and b.code_kb = '35' and a.type_cd = b.code and b.del_flg='0'     -- タイプ
       left outer join tbm_code c
            on a.user_company_id = c.user_company_id and c.code_kb = '36' and a.model_cd = c.code and c.del_flg='0'     -- モデル
       left outer join tbm_bunrui d
            on a.user_company_id = d.user_company_id and d.bunrui_kb = '6' and a.organization_id = d.bunrui_id and d.del_flg = '0'    -- 利用者所属
       left outer join tbv_personal_info e
            on (a.user_company_id = e.user_company_id and a.user_staff_cd = e.staff_cd)      -- 利用者情報
       left outer join tbv_personal_info f
            on (a.user_company_id = f.user_company_id and a.sekinin_staff_cd = f.staff_cd)   -- 責任者情報
       left outer join tbv_sisetubi g
            on a.user_company_id = g.user_company_id and a.sisetubi_id = g.sisetubi_id       -- 施設情報
       left outer join tbm_code h
            on a.user_company_id = h.user_company_id and h.code_kb = '37' and a.os_cd = h.code and h.del_flg='0'     -- ＯＳ
       left outer join tbv_maker i
            on a.user_company_id = i.user_company_id and a.maker_id = i.maker_id     -- メーカ
where  a.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_resource_printer
--
create view tbv_resource_printer as
select a.user_company_id,
       a.printer_id ,
       a.printer_nm,
       a.type_cd,
       a.model_cd,
       a.bunrui_kb,
       -- a.bunrui_id,
       a.user_staff_cd,
       a.sekinin_staff_cd,
       a.maker_id,
       l.maker_nm,
       a.sisetubi_id,
       a.port_cd,
       a.ram_nm,
       a.kyusi_nm,
       a.serial_cd,
       a.biko,
       b.code_nm as type_nm,                               -- タイプ
       c.code_nm as model_nm,                              -- モデル
       a.organization_id as organization_id ,                    -- （元はbunrui_idをカラム名を変更)
       --d.bunrui_nm as user_organization_nm,
       d.bunrui_nm as organization,                        -- 利用者所属 （元はuser_organization_nmをカラム名を変更)
       e.personal_nm as user_nm,                           -- 利用者名
       f.personal_nm as sekinin_nm,                        -- 責任者名
       g.sisetubi_kb as sisetubi_kb,                                      -- 施設設備区分
       g.code_syubetu_nm as sisetubi_kb_nm,                -- 施設設備種別
       g.sisetubi_nm as sisetubi_nm,                                      -- 施設名称
       h.code_nm as port1_nm,                               -- ＰＯＲＴ1名称
       i.code_nm as port2_nm,                               -- ＰＯＲＴ2名称
       j.code_nm as port3_nm,                              -- ＰＯＲＴ3名称
       k.code_nm as port4_nm                               -- ＰＯＲＴ4名称
from   tbm_resource_printer a
       left outer join tbm_code b
            on a.user_company_id = b.user_company_id and b.code_kb = '38' and a.type_cd = b.code and b.del_flg='0'     -- タイプ
       left outer join tbm_code c
            on a.user_company_id = c.user_company_id and c.code_kb = '39' and a.model_cd = c.code and c.del_flg='0'    -- モデル
       left outer join tbm_bunrui d
            on a.user_company_id = d.user_company_id and d.bunrui_kb = '6' and a.organization_id = d.bunrui_id and d.del_flg = '0'    -- 利用者所属
       left outer join tbv_personal_info e
            on (a.user_company_id = e.user_company_id and a.user_staff_cd = e.staff_cd)      -- 利用者情報
       left outer join tbv_personal_info f
            on (a.user_company_id = f.user_company_id and a.sekinin_staff_cd = f.staff_cd)   -- 責任者情報
       left outer join tbv_sisetubi g
            on a.user_company_id = g.user_company_id and a.sisetubi_id = g.sisetubi_id       -- 施設情報
       left outer join tbm_code h
            on a.user_company_id = h.user_company_id and h.code_kb = '40' and substring(a.port_cd from 1 for 1) = h.code and h.del_flg='0'    -- Port名
       left outer join tbm_code i
            on a.user_company_id = i.user_company_id and i.code_kb = '40' and substring(a.port_cd from 2 for 1) = i.code and i.del_flg='0'     -- Port名
       left outer join tbm_code j
            on a.user_company_id = j.user_company_id and j.code_kb = '40' and substring(a.port_cd from 3 for 1) = j.code and j.del_flg='0'     -- Port名
       left outer join tbm_code k
            on a.user_company_id = k.user_company_id and k.code_kb = '40' and substring(a.port_cd from 4 for 1) = k.code and k.del_flg='0'     -- Port名
       left outer join tbv_maker l
            on a.user_company_id = l.user_company_id and a.maker_id = l.maker_id     -- メーカ
where  a.del_flg = '0';

-- ------------------------------------------------------

--
-- view structure for view tbv_route
--
create view tbv_route as
select
    a.user_company_id ,
    a.route_kb,
    a.route_id,
    case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is null then 1 else
    case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is not null then 2 else
    case when e.route_id is null and d.route_id is null and c.route_id is not null then 3 else
    case when e.route_id is null and d.route_id is not null then 4 else
    case when e.route_id is not null then 5 end end end end end as route_kaiso,
    case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is null then lpad(a.route_id::varchar,4,'0')||'0000000000000000' else
    case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is not null then lpad(b.route_id::varchar,4,'0')||lpad(a.route_id::varchar,4,'0')||'000000000000' else
    case when e.route_id is null and d.route_id is null and c.route_id is not null then lpad(c.route_id::varchar,4,'0')||lpad(b.route_id::varchar,4,'0')||lpad(a.route_id::varchar,4,'0')||'00000000' else
    case when e.route_id is null and d.route_id is not null then lpad(d.route_id::varchar,4,'0')||lpad(c.route_id::varchar,4,'0')||lpad(b.route_id::varchar,4,'0')||lpad(a.route_id::varchar,4,'0')||'0000' else
    case when e.route_id is not null then lpad(e.route_id::varchar,4,'0')||lpad(d.route_id::varchar,4,'0')||lpad(c.route_id::varchar,4,'0')||lpad(b.route_id::varchar,4,'0')||lpad(a.route_id::varchar,4,'0') end end end end end as route_kanri_cd,
    a.up_route_id,
    a.route_cd,
    a.route_nm,
    a.orderno,
    case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is null then a.route_id else
        case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is not null then b.route_id else
        case when e.route_id is null and d.route_id is null and c.route_id is not null then c.route_id else
        case when e.route_id is null and d.route_id is not null then d.route_id else
    case when e.route_id is not null then e.route_id end end end end end as route1_id,
        case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is null then a.route_nm else
        case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is not null then b.route_nm else
        case when e.route_id is null and d.route_id is null and c.route_id is not null then c.route_nm else
    case when e.route_id is null and d.route_id is not null then d.route_nm else
        case when e.route_id is not null then e.route_nm end end end end end as route1_nm,
        case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is null then null else
        case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is not null then a.route_id else
        case when e.route_id is null and d.route_id is null and c.route_id is not null then b.route_id else
        case when e.route_id is null and d.route_id is not null then c.route_id else
        case when e.route_id is not null then d.route_id end end end end end as route12_id,
    case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is null then null else
        case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is not null then a.route_nm else
        case when e.route_id is null and d.route_id is null and c.route_id is not null then b.route_nm else
        case when e.route_id is null and d.route_id is not null then c.route_nm else
        case when e.route_id is not null then d.route_nm end end end end end as route12_nm,
    case when e.route_id is null and d.route_id is null and c.route_id is null then null else
        case when e.route_id is null and d.route_id is null and c.route_id is not null then a.route_id else
        case when e.route_id is null and d.route_id is not null then b.route_id else
        case when e.route_id is not null then c.route_id end end end end as route13_id,
    case when e.route_id is null and d.route_id is null and c.route_id is null then null else
        case when e.route_id is null and d.route_id is null and c.route_id is not null then a.route_nm else
        case when e.route_id is null and d.route_id is not null then b.route_nm else
        case when e.route_id is not null then c.route_nm end end end end as route13_nm,
    case when e.route_id is null and d.route_id is null then null else
        case when e.route_id is null and d.route_id is not null then a.route_id else
        case when e.route_id is not null then b.route_id end end end as route14_id,
    case when e.route_id is null and d.route_id is null then null else
        case when e.route_id is null and a.route_id is not null then a.route_nm else
        case when e.route_id is not null then b.route_nm end end end as route14_nm,
    case when e.route_id is null then null else
        case when e.route_id is not null then a.route_id end end as route15_id,
    case when e.route_id is null then null else
        case when e.route_id is not null then a.route_nm end end as route15_nm,
    case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is null then case when a.orderno is null then 999999999999999 else a.orderno end else
        case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is not null then case when b.orderno is null then 999999999999999 else b.orderno end else
        case when e.route_id is null and d.route_id is null and c.route_id is not null then case when c.orderno is null then 999999999999999 else c.orderno end else
        case when e.route_id is null and d.route_id is not null then case when d.orderno is null then 999999999999999 else d.orderno end else
        case when e.route_id is not null then case when e.orderno is null then 999999999999999 else e.orderno end end end end end end as route1_order,
    case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is null then null else
        case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is not null then case when a.orderno is null then 999999999999999 else a.orderno end else
        case when e.route_id is null and d.route_id is null and c.route_id is not null then case when b.orderno is null then 999999999999999 else b.orderno end else
        case when e.route_id is null and d.route_id is not null then case when c.orderno is null then 999999999999999 else c.orderno end else
        case when e.route_id is not null then case when d.orderno is null then 999999999999999 else d.orderno end end end end end end as route2_order,
    case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is null then null else
        case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is not null then null else
        case when e.route_id is null and d.route_id is null and c.route_id is not null then case when a.orderno is null then 999999999999999 else a.orderno end else
        case when e.route_id is null and d.route_id is not null then case when b.orderno is null then 999999999999999 else b.orderno end else
        case when e.route_id is not null then case when c.orderno is null then 999999999999999 else c.orderno end end end end end end as route3_order,
    case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is null then null else
        case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is not null then null else
        case when e.route_id is null and d.route_id is null and c.route_id is not null then null else
        case when e.route_id is null and d.route_id is not null then case when a.orderno is null then 999999999999999 else a.orderno end else
        case when e.route_id is not null then case when b.orderno is null then 999999999999999 else b.orderno end end end end end end as route4_order,
    case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is null then null else
        case when e.route_id is null and d.route_id is null and c.route_id is null and b.route_id is not null then null else
        case when e.route_id is null and d.route_id is null and c.route_id is not null then null else
        case when e.route_id is null and d.route_id is not null then null else
        case when e.route_id is not null then case when a.orderno is null then 999999999999999 else a.orderno end end end end end end as route5_order
from tbm_route a
     left outer join tbm_route b
           on (a.user_company_id = b.user_company_id and a.route_kb = b.route_kb and a.up_route_id = b.route_id and b.del_flg = '0')
     left outer join tbm_route c
           on (b.user_company_id = c.user_company_id and b.route_kb = c.route_kb and b.up_route_id = c.route_id and c.del_flg = '0')
     left outer join tbm_route d
           on (c.user_company_id = d.user_company_id and c.route_kb = d.route_kb and c.up_route_id = d.route_id and d.del_flg = '0')
     left outer join tbm_route e
           on (d.user_company_id = e.user_company_id and d.route_kb = e.route_kb and d.up_route_id = e.route_id and e.del_flg = '0')
where a.del_flg = '0';

-- 20080408 banno追加
--
-- view structure for view tbv_parts
--
create view tbv_parts as
select
  user_company_id,
  root_item_id,
  item_id,
  parent_id,
  self_id,
  kousei_bunsi,
  kousei_bunbo,
  tani_cd,
  list_order,
  del_flg,
  add_date,
  upd_date,
  add_pgid,
  upd_pgid,
  add_user_cd,
  upd_user_cd
from
    tbm_parts a
where del_flg = '0';

-- ------------------------------------------------------

--
-- view structure for view tbv_store_info
--
create view tbv_store_info as
select
    a.user_company_id as user_company_id,
    a.store_id as store_id,
    a.company_id as company_id,
    b.company_nm as store_nm,
    b.company_kn as store_kn,
    b.president as president,
    b.logo_image_path as logo_image_path,
    b.etc as store_etc,
    b.mail as store_mail,
    b.start_dt as open_date,
    b.end_dt as close_date,
    a.add_date as add_date,
    c.tel as store_tel,
    c.fax as store_fax,
    c.zipcode as store_zipcode,
    c.address1 as store_address1,
    c.address2 as store_address2,
    c.address3 as store_address3,
    c.address4 as store_address4,
    a.bunrui_kb as store_bunrui_kb,
    a.bunrui_id as store_bunrui_id,
    f.bunrui_id as bunrui1_id,
    f.bunrui_nm as bunrui1_nm,
    g.bunrui_id as bunrui2_id,
    g.bunrui_nm as bunrui2_nm,
    h.bunrui_id as bunrui3_id,
    h.bunrui_nm as bunrui3_nm,
    b.parent_company_id as parent_company_id,
    b.parent_company_nm as parent_company_nm
from tbm_store a
    inner join tbm_company_base b
        on (a.user_company_id = b.user_company_id and a.company_id = b.company_id and b.del_flg = '0')
    inner join tbm_company_address c
        on (a.user_company_id = c.user_company_id and a.company_id = c.company_id)
    left outer join tbv_bunrui e
        on (b.user_company_id=e.user_company_id and a.bunrui_kb=e.bunrui_kb and a.bunrui_id=e.bunrui_id)
    left outer join tbv_bunrui f
        on (e.user_company_id=f.user_company_id and e.bunrui_kb=f.bunrui_kb and e.bunrui1_id=f.bunrui_id)
    left outer join tbv_bunrui g
        on (e.user_company_id=g.user_company_id and e.bunrui_kb=g.bunrui_kb and e.bunrui2_id=g.bunrui_id)
    left outer join tbv_bunrui h
        on (e.user_company_id=h.user_company_id and e.bunrui_kb=h.bunrui_kb and e.bunrui3_id=h.bunrui_id)
where a.del_flg = '0';

-- ------------------------------------------------------

--
-- view structure for view tbv_store_admin_list
--
create view tbv_store_admin_list as
select
    a.user_company_id as user_company_id,
    a.store_admin_id as store_admin_id,
    a.store_id as store_id,
    b.store_nm as store_nm,
    b.store_kn as store_kn,
    b.parent_company_id as parent_company_id,
    b.parent_company_nm as parent_company_nm,
    a.personal_id as personal_id,
    c.user_cd as user_cd,
    c.personal_nm as personal_nm,
    c.mail as mail,
    b.company_id as company_id,
    b.president as president,
    b.logo_image_path as logo_image_path,
    b.store_etc as store_etc,
    b.store_mail as store_mail,
    b.open_date as open_date,
    b.close_date as close_date,
    b.store_tel as store_tel,
    b.store_fax as store_fax,
    b.store_zipcode as store_zipcode,
    b.store_address1 as store_address1,
    b.store_address2 as store_address2,
    b.store_address3 as store_address3,
    b.store_address4 as store_address4,
    b.store_bunrui_kb as store_bunrui_kb,
    b.store_bunrui_id as store_bunrui_id,
    b.bunrui1_id as bunrui1_id,
    b.bunrui1_nm as bunrui1_nm,
    b.bunrui2_id as bunrui2_id,
    b.bunrui2_nm as bunrui2_nm,
    b.bunrui3_id as bunrui3_id,
    b.bunrui3_nm as bunrui3_nm,
    a.del_flg as del_flg,
    a.add_date as add_date
from tbm_store_admin a
    inner join tbv_store_info b
        on (a.user_company_id = b.user_company_id and a.store_id = b.store_id)
    inner join tbv_user_info c
        on (a.user_company_id = b.user_company_id and a.personal_id = c.personal_id)
where a.del_flg = '0';

