--
-- view structure for view tmp_order_list_0
--
-- ステータステーブルを見積番号・受注番号・入金番号でグループ
--
create view tmp_han_order_list_0 as 
select
    sta.user_company_id as user_company_id,
    sta.mitu_no as mitu_no,
    sta.order_no as order_no,
    sta.nyukin_no as nyukin_no,
    min(sta.sts_kb) as sts_kb
from
    tbt_han_status sta 
where
    sta.del_flg = '0'
group by
    sta.user_company_id,
    sta.mitu_no,
    sta.order_no,
    sta.nyukin_no;
-- ------------------------------------------------------

--
-- view structure for view tmp_order_list_1
--
-- ステータステーブルを見積番号・受注番号でグループ化し、
-- 入金番号が入っている場合には、最大となる入金日を取得。
-- （受注一覧での検索用）
--
create view tmp_han_order_list_1 as 
select
    a.user_company_id as user_company_id,
    a.mitu_no as mitu_no,
    a.order_no as order_no,
    min(a.sts_kb) as sts_kb,
    max(b.nyukin_dt) as nyukin_dt
from
    tmp_han_order_list_0 a 
    left outer join tbt_han_nyukin b 
    on(a.user_company_id = b.user_company_id and a.nyukin_no = b.nyukin_no and b.del_flg = '0')
group by
    a.user_company_id,
    a.mitu_no,
    a.order_no;
-- ------------------------------------------------------

--
-- view structure for view tmp_han_order_list_2
--
-- 受注番号ごとでの明細件数および、受注金額を取得
--
create view tmp_han_order_list_2 as
select
    a.user_company_id,
    a.order_no,
    count(*) as kensu,
    sum(kin) as goukei
from
    tbt_han_order_detail a
where
    a.del_flg = '0'
group by
    a.user_company_id,
    a.order_no;
-- ------------------------------------------------------

--
-- view structure for view tbv_han_order_list
--
-- 受注ヘッダの為の情報
--
create view tbv_han_order_list as
select
    sts.sts_kb,
    h.code_nm as sts_kb_nm,
    sts.nyukin_dt,
    hed.user_company_id,	
    hed.order_no,
    hed.order_dt,
    hed.ukezumi_dt,
    hed.toroku_staff_cd,
    f.toroku_staff_nm,
    hed.toroku_organization_id,
    i.bunrui_nm as toroku_organization,
    hed.tanto_staff_cd,
    e.tanto_staff_nm,
    hed.tanto_organization_id,
    j.bunrui_nm as tanto_organization,
    hed.tokui_chumon_nm,
    hed.mitu_no,
    hed.tokui_id,
    d.tokui_cd_nm as tokui_nm,
    NULL as tokui_url,
    hed.nouki_dt,
    hed.order_title,
    dtl.kensu,
    dtl.goukei
from
    tmp_han_order_list_1 sts
    join tbt_han_order hed
         on(sts.user_company_id = hed.user_company_id and sts.order_no = hed.order_no and hed.del_flg = '0')
    join tmp_han_order_list_2 dtl
         on(hed.user_company_id = dtl.user_company_id and hed.order_no = dtl.order_no)
    left outer join tbv_tokui d
         on(hed.user_company_id = d.user_company_id and hed.tokui_id = d.tokui_id)
    left outer join tbv_han_order_tanto e
         on(hed.user_company_id = e.user_company_id and hed.tanto_staff_cd = e.tanto_staff_cd)
    left outer join tbv_han_order_regist_user f
         on(hed.user_company_id = f.user_company_id and hed.toroku_staff_cd = f.toroku_staff_cd)
    left outer join tbm_code h
         on(sts.user_company_id = h.user_company_id and sts.sts_kb = h.code and h.code_kb = '24' and h.del_flg = '0')
    left outer join tbm_bunrui i
         on(hed.user_company_id = i.user_company_id and i.bunrui_kb = '6' and hed.toroku_organization_id = i.bunrui_id and i.del_flg = '0')
    left outer join tbm_bunrui j
         on(hed.user_company_id = j.user_company_id and j.bunrui_kb = '6' and hed.tanto_organization_id = j.bunrui_id  and j.del_flg = '0')
where
    sts.sts_kb >= '070';
-- ------------------------------------------------------

--
-- view structure for view tmp_han_order_detail_list0
--
-- 受注ヘッダと明細を紐付けたもの（主が明細）
-- ※明細の削除フラグは現状考えない。（明細は物理削除の為）
--
create view tmp_han_order_detail_list0 as
select 
    hed.user_company_id,
    hed.order_no,
    hed.mitu_no,
    dtl.order_edano,
    hed.order_dt,
    hed.ukezumi_dt,
    hed.toroku_staff_cd,
    hed.toroku_organization_id,
    i.bunrui_nm as toroku_organization,
    hed.tanto_staff_cd,
    hed.tanto_organization_id,
    j.bunrui_nm as tanto_organization,
    hed.tokui_chumon_nm,
    hed.tokui_id,
    hed.nouki_dt,
    hed.order_title,
    dtl.item_id,
    dtl.product_nm,
    dtl.product_kikaku,
    dtl.syubetu,
    dtl.su,
    dtl.tani_nm,
    dtl.tanka,
    dtl.kin,
    dtl.biko
from 
    tbt_han_order hed
    join tbt_han_order_detail dtl
         on(hed.user_company_id = dtl.user_company_id and hed.order_no = dtl.order_no)
    left outer join tbm_bunrui i
         on(hed.user_company_id = i.user_company_id and i.bunrui_kb = '6' and hed.toroku_organization_id = i.bunrui_id and i.del_flg = '0')
    left outer join tbm_bunrui j
         on(hed.user_company_id = j.user_company_id and j.bunrui_kb = '6' and hed.tanto_organization_id = j.bunrui_id  and j.del_flg = '0')
where
    hed.del_flg = '0';
-- ------------------------------------------------------

--
-- view structure for view tbv_han_order_detail_list
--
-- 画面にて使用する明細情報用
-- 明細が主となる受注情報とステータステーブルの紐付け
--
CREATE VIEW tbv_han_order_detail_list AS 
 SELECT ord_d.user_company_id, sts.status_id, ord_d.order_no, ord_d.order_edano, ord_d.order_dt, ord_d.ukezumi_dt, ord_d.toroku_staff_cd, ord_d.toroku_organization_id, i.bunrui_nm AS toroku_organization, ord_d.tanto_staff_cd, ord_d.tanto_organization_id, j.bunrui_nm AS tanto_organization, ord_d.tokui_chumon_nm, ord_d.tokui_id, ord_d.nouki_dt, ord_d.order_title, sts.sts_kb, cdm.code_nm AS sts_kb_nm, ord_d.item_id,  a.item_cd, ord_d.product_nm, ord_d.product_kikaku, ord_d.syubetu, ord_d.su, ord_d.tani_nm, ord_d.tanka, ord_d.kin, ord_d.biko, sts.mitu_irai_no, sts.mitu_irai_edano, sts.mitu_no, sts.mitu_edano
   FROM tmp_han_order_detail_list0 ord_d
   JOIN tbt_han_status sts ON ord_d.user_company_id = sts.user_company_id AND ord_d.order_no = sts.order_no AND ord_d.order_edano = sts.order_edano AND sts.del_flg::text = '0'::text AND sts.sts_kb::text >= '070'::text
   JOIN tbt_han_order ord ON ord_d.user_company_id = ord.user_company_id AND ord_d.order_no = ord.order_no
   LEFT JOIN tbm_code cdm ON sts.user_company_id = cdm.user_company_id AND sts.sts_kb::text = cdm.code::text AND cdm.code_kb::text = '24'::text AND cdm.del_flg::text = '0'::text
   LEFT JOIN tbm_bunrui i ON ord_d.user_company_id = i.user_company_id AND i.bunrui_kb::text = '6'::text AND ord_d.toroku_organization_id = i.bunrui_id AND i.del_flg::text = '0'::text
   LEFT JOIN tbm_bunrui j ON ord_d.user_company_id = j.user_company_id AND j.bunrui_kb::text = '6'::text AND ord_d.tanto_organization_id = j.bunrui_id AND j.del_flg::text = '0'::text
   LEFT JOIN tbm_item a ON ord_d.user_company_id = a.user_company_id AND ord_d.item_id = a.item_id AND a.del_flg::text = '0'::text;
-- ------------------------------------------------------

--
-- view structure for view tmp_han_order_print_list_0
--
-- 受注明細の合計金額を算出
--
create view tmp_han_order_print_list_0 as
select
    a.user_company_id,
    a.order_no,
    sum(a.kin) as sum_kin
from
    tbt_han_order_detail a
group by
    a.user_company_id,
    a.order_no,
    a.del_flg = '0';

-- ------------------------------------------------------

--
-- view structure for view tbv_han_order_print_list
--
-- 受注明細を主に受注ヘッダを結合
-- ※印刷用view
--
create view tbv_han_order_print_list as
select
    a.user_company_id,
    a.order_no,
    a.mitu_no,
    a.order_edano,
    b.sts_kb,
    c.code_nm as sts_kb_nm,
    a.order_dt,
    a.ukezumi_dt,
    h.jisya_nm,
    h.tel as jisya_tel,
    h.fax as jisya_fax,
    h.zipcode as jisya_zipcode,
    h.address1 as jisya_address1,
    h.address2 as jisya_address2,
    h.address3 as jisya_address3,
    h.address4 as jisya_address4,
    a.toroku_staff_cd,
    a.toroku_organization_id,
    i.bunrui_nm as toroku_organization,
    a.tanto_staff_cd,
    f.personal_nm as tanto_staff_nm,
    a.tanto_organization_id,
    j.bunrui_nm as tanto_organization,
    a.tokui_chumon_nm,
    a.tokui_id,
    d.tokui_cd_nm as tokui_nm,
    d.zipcode as tokui_zipcode,
    d.address1 as tokui_address1,
    d.address2 as tokui_address2,
    d.address3 as tokui_address3,
    d.address4 as tokui_address4,
    a.nouki_dt,
    a.order_title,
    a.item_id,
    g.item_cd,
    a.product_nm,
    a.product_kikaku,
    a.syubetu,
    a.su,
    (case when b.sts_kb < '100' then a.su else 0 end) as zan_su,
    a.tani_nm,
    a.tanka,
    a.kin,
    k.sum_kin,
    (case when b.sts_kb < '100' then a.kin else 0 end) as zan_kin,
    a.biko,
    e.item_nm,
    e.item_kikaku
from
    tmp_han_order_detail_list0 a
    join tbt_han_status b
         on(a.user_company_id = b.user_company_id and a.order_no = b.order_no and a.order_edano = b.order_edano and b.del_flg = '0' and b.sts_kb >= '070')
    left outer join tbm_code c
         on(b.user_company_id = c.user_company_id and b.sts_kb = c.code and c.code_kb = '24' and c.del_flg = '0')
    left outer join tbv_tokui d
         on(a.user_company_id = d.user_company_id and a.tokui_id = d.tokui_id)
    left outer join tbv_item e
         on(a.user_company_id = e.user_company_id and a.item_id = e.item_id)
    left outer join tbv_syain f
         on(a.user_company_id = f.user_company_id and a.tanto_staff_cd = f.staff_cd)
    left outer join tbv_item g
         on(a.user_company_id = g.user_company_id and a.item_id = g.item_id)
    left outer join tbv_jisya h
         on(a.user_company_id = h.user_company_id)
    join tmp_han_order_print_list_0 k
         on(a.user_company_id = k.user_company_id and a.order_no = k.order_no)
    left outer join tbm_bunrui i
         on(a.user_company_id = i.user_company_id and i.bunrui_kb = '6' and a.toroku_organization_id = i.bunrui_id and i.del_flg = '0')
    left outer join tbm_bunrui j
         on(a.user_company_id = j.user_company_id and j.bunrui_kb = '6' and a.tanto_organization_id = j.bunrui_id  and j.del_flg = '0')
;