--
-- view structure for view tmp_syuka_list_0
--
--  受注番号・納品書番号・ステータス毎にグループ化

create view tmp_syuka_list_0 as
select distinct
       a.user_company_id,
       a.order_no,
       a.delivery_no,
       a.sts_kb
from tbt_han_status a
where  a.del_flg = '0';

--
-- view structure for view tmp_syuka_list_1
--
-- １受注番号中に複数のステータスが入っている受注番号レコードは対象外

create view tmp_syuka_list_1 as
select a.user_company_id,
       a.order_no,
       a.delivery_no,
       max(a.sts_kb) as sts_kb,
       count(*) as kensu
from tmp_syuka_list_0 a
group by
       a.user_company_id,
       a.order_no,
       a.delivery_no
having count(*) <=1;

--
-- view structure for view tmp_syuka_list_2
--
-- １受注番号の受注数合計を取得

create view tmp_syuka_list_2 as
select a.user_company_id,
       a.order_no,
       sum(b.su) as jyuchu_su
from tmp_syuka_list_1 a
     left outer join tbt_han_order_detail b
     on a.user_company_id = b.user_company_id and a.order_no = b.order_no
where
     b.del_flg = '0'
group by 
     a.user_company_id,
     a.order_no;

--
-- view structure for view tmp_syuka_list_3
--
-- １受注番号の検品数合計を取得

create view tmp_syuka_list_3 as
select a.user_company_id,
       a.order_no,
       max(b.syuka_dt) as syuka_dt,
       sum(b.su) as syuka_su
from tmp_syuka_list_1 a
     left outer join tbt_han_syuka_detail b
     on a.user_company_id = b.user_company_id and a.order_no = b.order_no
where  b.del_flg = '0'
group by 
     a.user_company_id,
     a.order_no;

--
-- view structure for view tbv_syuka_list
--

create view tbv_syuka_list as
select a.user_company_id,
       a.order_no,
       a.delivery_no,
       a.sts_kb,
       b.ukezumi_dt,
       b.toroku_staff_cd        as toroku_staff_cd,
       c.personal_nm            as toroku_staff_nm,
       b.toroku_organization_id as toroku_organization_id,
       i.bunrui_nm              as toroku_organization,
       b.tanto_staff_cd         as tanto_staff_cd,
       d.personal_nm            as tanto_staff_nm,
       b.tanto_organization_id  as tanto_organization_id,
       j.bunrui_nm              as tanto_organization,
       b.tokui_id               as tokui_id,
       e.tokui_cd_nm            as tokui_nm,
       cast('' as varchar)      as tokui_url,
       b.nouki_dt,
       b.order_title,
       f.jyuchu_su,
       g.syuka_dt,
       cast(substr(g.syuka_dt,1,4) as varchar) as syuka_dt_yy,
       cast(substr(g.syuka_dt,5,2) as varchar) as syuka_dt_mm,
       cast(substr(g.syuka_dt,7,2) as varchar) as syuka_dt_dd,
       g.syuka_su
from tmp_syuka_list_1 a
      join tbt_han_order b
           on a.user_company_id = b.user_company_id and a.order_no = b.order_no
      left outer join tbv_syain c
           on b.user_company_id = c.user_company_id and b.toroku_staff_cd = c.staff_cd
      left outer join tbv_syain d
           on b.user_company_id = d.user_company_id and b.tanto_staff_cd = d.staff_cd
      left outer join tbv_tokui e
           on b.user_company_id = e.user_company_id and b.tokui_id = e.tokui_id
      left outer join tmp_syuka_list_2 f
           on a.user_company_id = f.user_company_id and a.order_no = f.order_no
      left outer join tmp_syuka_list_3 g
           on a.user_company_id = g.user_company_id and a.order_no = g.order_no
      left outer join tbm_bunrui i
           on(b.user_company_id = i.user_company_id and i.bunrui_kb = '6' and b.toroku_organization_id = i.bunrui_id and i.del_flg = '0')
      left outer join tbm_bunrui j
           on(b.user_company_id = j.user_company_id and j.bunrui_kb = '6' and b.tanto_organization_id = j.bunrui_id  and j.del_flg = '0')
where b.del_flg = '0';

--
-- view structure for view tmp_syuka_detail_list_0
--

create view tmp_syuka_detail_list_0 as
select distinct
       a.user_company_id,
       a.order_no,
       a.order_edano,
       a.delivery_no,
       a.delivery_edano,
       a.nyusyuko_rireki_id,                -- 入出庫履歴ID
       a.sts_kb
from tbt_han_status a
where a.del_flg = '0';

--
-- view structure for view tbv_syuka_detail_list
--

create view tbv_syuka_detail_list as
select a.user_company_id,
       a.order_no,
       a.order_edano,
       a.delivery_no,
       a.delivery_edano,
       a.sts_kb,
       b.order_dt,
       b.ukezumi_dt,
       b.toroku_staff_cd        as toroku_staff_cd,
       c.personal_nm            as toroku_staff_nm,
       b.toroku_organization_id as toroku_organization_id,
       i.bunrui_nm              as toroku_organization,
       b.tanto_staff_cd         as tanto_staff_cd,
       d.personal_nm            as tanto_staff_nm,
       b.tanto_organization_id  as tanto_organization_id,
       j.bunrui_nm              as tanto_organization,
       b.tokui_id               as tokui_id,
       e.tokui_cd_nm            as tokui_nm,
       cast('' as varchar)      as tokui_url,
       b.nouki_dt,
       b.order_title,
       f.su as jyuchu_su,
       f.tani_nm,
       f.product_nm,
       f.product_kikaku,
       g.syuka_dt,
       g.su as syuka_su,
       f.item_id,
       f.tanka,
       f.kin,
       h.standard_tnk,
       a.nyusyuko_rireki_id,
       k.nyusyuko_su
from tmp_syuka_detail_list_0 a
     join tbt_han_order b
          on a.user_company_id = b.user_company_id and a.order_no = b.order_no
     left outer join tbv_syain c
          on b.user_company_id = c.user_company_id and b.toroku_staff_cd = c.staff_cd
     left outer join tbv_syain d
          on b.user_company_id = d.user_company_id and b.tanto_staff_cd = d.staff_cd
     left outer join tbv_tokui e
          on b.user_company_id = e.user_company_id and b.tokui_id = e.tokui_id
     left outer join tbt_han_order_detail f
          on a.user_company_id = f.user_company_id and a.order_no = f.order_no and a.order_edano = f.order_edano and f.del_flg = '0'
     left outer join tbt_han_syuka_detail g
          on a.user_company_id = g.user_company_id and a.delivery_no = g.delivery_no and a.delivery_edano = g.delivery_edano and g.del_flg = '0'
     left outer join tbm_item h
          on f.user_company_id = g.user_company_id and f.item_id = h.item_id and h.del_flg = '0'
     left outer join tbm_bunrui i
          on(b.user_company_id = i.user_company_id and i.bunrui_kb = '6' and b.toroku_organization_id = i.bunrui_id and i.del_flg = '0')
     left outer join tbm_bunrui j
          on(b.user_company_id = j.user_company_id and j.bunrui_kb = '6' and b.tanto_organization_id = j.bunrui_id  and j.del_flg = '0')
     left outer join tbt_nyusyuko_rireki k 
          on a.user_company_id = k.user_company_id and a.nyusyuko_rireki_id = k.nyusyuko_rireki_id and k.del_flg = '0'
;
--
-- view structure for view tmp_syuka_kenpin_list_0
--

create view tmp_syuka_kenpin_list_0 as
select
       a.user_company_id,
       a.delivery_no,
       a.delivery_edano,
       min(b.kin) as kin
from  tbt_han_status a
      left outer join tbt_han_syuka_detail b
      on a.user_company_id = b.user_company_id and a.delivery_no = b.delivery_no and a.delivery_edano = b.delivery_edano
where a.del_flg = '0'
and   a.delivery_no is not null
and   b.del_flg = '0'
group by 
      a.user_company_id,
      a.delivery_no,
      a.delivery_edano;

--
-- view structure for view tbv_syuka_kenpin_list
--

create view tbv_syuka_kenpin_list as
select
     a.user_company_id,
     a.delivery_no,
     sum(a.kin) as sum_kin,
     b.tokui_id,
     c.tokui_cd_nm as tokui_nm,
     cast('' as varchar) as tokui_url
from tmp_syuka_kenpin_list_0 a
     join tbt_han_syuka b
     on a.user_company_id = b.user_company_id and a.delivery_no = b.delivery_no
     left outer join tbv_tokui c
     on b.user_company_id = c.user_company_id and b.tokui_id = c.tokui_id
where
     b.del_flg = '0'
group by 
     a.user_company_id,
     a.delivery_no,
     b.tokui_id,
     c.tokui_cd_nm;

--
-- view structure for view tmp_syuka_kenpin_detail_list_0
--

create view tmp_syuka_kenpin_detail_list_0 as
select
      a.user_company_id,
      a.delivery_no,
      a.delivery_edano,
      min(a.order_no) as order_no,
      min(a.order_edano) as order_edano,
      min(a.sts_kb) as sts_kb
from  tbt_han_status a
where a.del_flg = '0'
and   a.delivery_no is not null
group by 
      a.user_company_id,
      a.delivery_no,
      a.delivery_edano;

--
-- view structure for view tbv_syuka_kenpin_detail_list
--

create view tbv_syuka_kenpin_detail_list as
select
      a.user_company_id,
      a.delivery_no,
      a.delivery_edano,
      a.order_no,
      a.order_edano,
      a.sts_kb,
      min(b.product_nm) as product_nm,
      min(b.product_kikaku) as product_kikaku,
      min(b.su) as su,
      min(b.tani_nm) as tani_cd,
      min(d.code_nm) as tani_nm,
      min(b.tanka) as tanka,
      min(b.kin) as kin,
      c.code_nm as jyokyo_nm
from  tmp_syuka_kenpin_detail_list_0 a
      left outer join tbt_han_syuka_detail b
           on (a.user_company_id = b.user_company_id and a.delivery_no = b.delivery_no and a.delivery_edano = b.delivery_edano)
      left outer join tbm_code d
           on (b.user_company_id = d.user_company_id and b.tani_nm = d.code and d.code_kb = '2' and d.del_flg='0')
      left outer join tbm_code c 
           on (a.user_company_id = c.user_company_id and a.sts_kb = c.code and c.code_kb = '24' and c.del_flg='0')
group by 
      a.user_company_id,
      a.delivery_no,
      a.delivery_edano,
      a.order_no,
      a.order_edano,
      a.sts_kb,
      c.code_nm;

--
-- view structure for view tmp_syuka_okuri_list_0
--

create view tmp_syuka_okuri_list_0 as
select
      distinct
      a.user_company_id,
      a.order_no,
      a.order_edano,
      a.nyusyuko_rireki_id,
      a.delivery_no,
      a.delivery_edano,
      a.sts_kb
from  tbt_han_status a
where a.del_flg = '0'
and   a.sts_kb in ('071','080','090','100');

--
-- view structure for view tbv_syuka_okuri_list
--

create view tbv_syuka_okuri_list as
select
      a.user_company_id,
      a.order_no,
      a.order_edano,
      a.nyusyuko_rireki_id,
      a.delivery_no,
      a.delivery_edano,
      a.sts_kb,
      b.toroku_staff_cd,
      b.toroku_organization_id,
      i.bunrui_nm              as toroku_organization,
      b.tanto_staff_cd,
      b.tanto_organization_id,
      j.bunrui_nm              as tanto_organization,
      g.tokui_id,
      d.tokui_cd_nm as tokui_nm,
      cast('' as varchar) as tokui_url,
      b.nouki_dt,
      c.su as jyuchu_su,
      d.okuri_cd,
      d.haisou_id,
      e.haisou_nm,
      h.nyusyuko_su,
      f.su as syuka_su,
      f.syuka_dt as syuka_dt
from  tmp_syuka_okuri_list_0 a
      left outer join tbt_han_order b 
           on a.user_company_id = b.user_company_id and a.order_no = b.order_no and b.del_flg = '0'
      left outer join tbt_han_order_detail c 
           on a.user_company_id = c.user_company_id and a.order_no = c.order_no  and a.order_edano = c.order_edano and c.del_flg = '0'
      left outer join tbt_nyusyuko_rireki h 
           on a.user_company_id = h.user_company_id and a.nyusyuko_rireki_id = h.nyusyuko_rireki_id and h.del_flg = '0'
      left outer join tbt_han_syuka_detail f 
           on a.user_company_id = f.user_company_id and a.delivery_no = f.delivery_no and a.delivery_edano = f.delivery_edano and f.del_flg='0'
      left outer join tbt_han_syuka g
           on (f.user_company_id = g.user_company_id and f.delivery_no = g.delivery_no and g.del_flg = '0')
      left outer join tbv_tokui d 
           on g.user_company_id = d.user_company_id and g.tokui_id = d.tokui_id
      left outer join tbv_haisou e 
           on d.user_company_id = e.user_company_id and d.haisou_id = e.haisou_id
      left outer join tbm_bunrui i
           on(b.user_company_id = i.user_company_id and i.bunrui_kb = '6' and b.toroku_organization_id = i.bunrui_id and i.del_flg = '0')
      left outer join tbm_bunrui j
           on(b.user_company_id = j.user_company_id and j.bunrui_kb = '6' and b.tanto_organization_id = j.bunrui_id  and j.del_flg = '0')
;