<?php
/**
 * logon controller class.
 *
 * @author    S.Tajima <tajima@exbridge.jp> 2007/11/03
 *            S.Tajima <tajima@exbridge.jp> 2008/08/25
 * @version   svn:$Id: logonController.php 8479 2008-09-26 10:10:23Z tajima $
 * @copyright 2007- EXBRIDGE,Inc. All Rights Reserved.
 * @link      http://exbridge.jp/
 */
class logonController extends xbeCoreCommonController {

    var $_display_name  = TL_LOGON; //画面名

    var $_pw_layout_template = 'top';

    var $_pw_css = array('css/core.css', 'css/user.css');

    var $_pw_jscript = array(
                        'js/ext/jquery/jquery.js',
                        'js/interface.js',
                        'js/xbeJquery.js',
                        'js/validation.js',
                        'js/logon/logon.js'); //Jscript

    /**
     * 初期処理
     *
     * コントローラー初期処理
     *
     */
    function init() {
        coreUtil::load_view('UserLogon', 'xbrg_uam');
        coreUtil::load_view('UserList', 'xbrg_uam');
        parent::init(__CLASS__);
        $this->view = UserLogonView::getInstance();
    }

    /**
     * デフォルト呼出
     *
     * ログイン画面表示へフォワードする
     *
     */
    function executeDefault() {
        //退会からの遷移
        if ($this->delete == '1') {
            $this->_result = R_SUCCESS;
            $this->_message = I_DELETE_USER_SUCCESS;
        }
        //URLの直接呼出し
        if (isset($this->redirect_url)) {
            $this->setSession(REQURI, $this->redirect_url);
        }
        $this->forward('ShowLogon');
    }

    /**
     * ログオン処理
     *
     * ユーザー認証を行い、結果によって画面遷移を行う
     *
     */
    function executeRequestLogon() {
        //リクエストを取得する
        $user_company_id = $this->user_company_id;
        $user_cd = $this->user_cd;
        $password = $this->password;

        //仮パスワード発行時(メールに記入されているURLから呼ばれた場合)
        if (!isNULL($this->tmp_password)) {
            $password = $this->tmp_password;
        }

        $data = null;
        $user_info = null;
        $results = $this->logon($user_company_id, $user_cd, $password, $data, $user_info);
        $this->_loadLogonUserInfo();

        //認証OK
        if ($results) {
            //次回から自動的にログオン
            if ($this->remember) {
                $this->setAutoLogon($user_company_id, $user_cd, $password);
            }
            //仮パスワード発行時
            if (!isNULL($this->tmp_password)) {
                //仮パスワードを無効にする(ログオン時のtbt_logon_userへの操作で自動的に無効になる)
                //My アカウント画面へ移動する
                $this->redirectToPath(R_LOGON_ACCOUNT_HOME, array('result' => '1'));
            }
            return $this->_routing();
        }
        //認証失敗
        else {
            $this->_result = R_ERROR;
            $this->_message = E_LOGON_FAILED;
            $this->forward('ShowLogon');
        }
    }

    /**
     * ログオフ処理
     *
     * ユーザー情報をセッションから削除します
     *
     */
    function executeRequestLogoff() {
        $this->signOut();
        return $this->render('logon/logon');
    }

    /**
     * パスワード送信
     *
     * 指定されたメールアドレスをもつユーザーにパスワードを送信します
     *
     */
    function executeRequestSendPassword() {
        $mail = $this->mail;
        $get_user_url = CORE_AURORA_URL . 'xbeWebLogon.php?action=RequestSendPassword&mail=' . $mail;
        $result = get_url_contents($get_user_url);
        $this->_result = $result;
        if ($result == R_SUCCESS) {
            $this->_message = I_SENDMESSAGE_SUCCESS;
        }
        else {
            $this->_message = E_SENDPASSWORD_FAILED;
        }
        $this->forward('ShowLogon');
    }

    /**
     * ユーザーを有効にする
     *
     */
    function executeRequestActivate() {
        $user_company_id = $this->user_company_id;
        $user_cd = $this->user_cd;
        $activate_url = CORE_AURORA_URL . 'xbeWebLogon.php?action=RequestUserActivate&user_company_id=' . $user_company_id . '&user_cd=' . $user_cd;
        debugLog( 'request acrivate url[' . $activate_url . ']', __CLASS__, __FILE__, __LINE__);
        $result = get_url_contents($activate_url);
        //認証完了のメッセージ
        $this->_result = $result;
        switch ($result) {
            case R_SUCCESS:
                //こちらを通ることは無いはず
                $this->_message = I_ACTIVATE_SUCCESS;
                break;
            case R_SUCCESS_UPDATE:
                $this->_message = I_ACTIVATE_SUCCESS;
                break;
            case R_ERROR:
                $this->_message = E_ACTIVATE_FAILED;
                break;
            case R_ERROR_NULL:
                $this->_message = E_ACTIVATE_FAILED;
                break;
            case R_ERROR_DUPL:
                $this->_message = E_ACTIVATE_DUPLICATE;
                break;
            default:
                $this->_message = E_UNKNOWN;
            break;
        }
        $this->forward('ShowLogon');
    }

    /**
     * ログオン画面表示
     *
     */
    function executeShowLogon() {
        //自動ログオン
        if ($this->autoLogon()) {
            $this->redirectToUrl($this->top_url);
        }
        //ログオン後はトップページへ
        if ($this->authenticated) {
            $this->redirectToUrl($this->top_url);
        }
        return $this->render('logon/logon');
    }

    /**
     * ルーティング処理
     *
     */
    function _routing() {
        $post_url = null;
        $pw_user = & xbpwContext::getUser();
        $user = $pw_user->getUserParameter(SESSION_AURORA_USER_MANAGER);

        $request_uri = $this->getSession(REQURI);
        if (!isNULL($request_uri)) {
            //ゲストユーザーは、社内ファイル便以外アクセスを認めない
            //Aurora限定仕様
            if ($this->logon_sec_level == AuthService::GUEST) {
                if (!preg_match('/RequestReceiveConfirm/i', $request_uri)) {
                    $user->signOut();
                    $pw_user->setAuthenticated(false);
                    $post_url = CORE_URL . XBE_DENY_NOT_SYAIN;
                }
                else{
                    $this->clearSession(REQURI);
                    $post_url = $request_uri;
                }
            }
            //要求URLへ
            else {
                $this->clearSession(REQURI);
                $post_url = $request_uri;
            }
        }
        //トップページへ
        else {
            if ($this->logon_sec_level == AuthService::GUEST) {
                $user->signOut();
                $pw_user->setAuthenticated(false);
                $post_url = CORE_URL . XBE_DENY_NOT_SYAIN;
            }
            else {
                if (CORE_BASE_APPLICATION!=XBE_PRODUCT_AURORA) {
                    if ($this->logon_sec_level==AuthService::SUPER || $this->logon_sec_level==AuthService::ADMIN) {
                        $post_url = $this->top_url;
                    }
                    else {
                        $post_url = $this->home_url;
                    }
                }
                else {
                    $post_url = $this->top_url;
                }
            }
        }
        $pw_user->setUserParameter(SESSION_AURORA_USER_MANAGER, $user);
        xbpwContext::setUser($pw_user);
        unset($_SESSION[SESSION_AURORA_USER_COMPANY_ID]);

        $oid             = session_id();
        $user_company_id = $this->user_company_id;
        $user_cd         = $this->logon_user_cd;
        $hash            = $this->hash;
        $project_from    = $this->logon_project_from;
        $param = '&oid=' . session_id() . '&user_company_id=' . $user_company_id . '&user_cd=' . $user_cd . '&hash=' . $hash . '&project_from=' .  $project_from;
        if (!strpos($post_url, '?')) {
            $param = '?oid=' . session_id() . '&user_company_id=' . $user_company_id . '&user_cd=' . $user_cd . '&hash=' . $hash . '&project_from=' .  $project_from;
        }
        debugLog('posted>>>' . $post_url . $param);
        $this->redirectToUrl($post_url . $param);
    }
}
