<?php
/**
 * function auroraUtils
 *
 * PHP versions 4 and 5
 *
 * @author     Shiro Tajima <tajima@exbridge.jp>
 * @copyright  2007 Exbridge,inc.
 * @version    1.0
 */

/**
 * Service関連クラスローダー
 */
function load_service() {
    require_once(XBE_LIBS_DIR . '/xb.library/factory/auroraService.class.php');
    require_once(XBE_LIBS_DIR . '/xb.library/factory/auroraValueObject.class.php');
}

/**
 * application関連クラスローダー
 */
function load_app($app = null) {
    if (!isNULL($app)) {
        //20080425 UTF化のため追加
        if (file_exists(PW_ROOT_DIR . "/app/config/aurora/IDs/" . $app . "IDs.ja.inc")) {
            require_once(PW_ROOT_DIR . "/app/config/aurora/IDs/" . $app . "IDs.ja.inc");
        }
        if (file_exists(PW_ROOT_DIR . "/app/config/aurora/messages/" . $app . "Messages.ja.inc")) {
            require_once(PW_ROOT_DIR . "/app/config/aurora/messages/" . $app . "Messages.ja.inc");
        }
        //
        //20080512 Routingファイルの追加
        if (file_exists(PW_ROOT_DIR . "/app/config/aurora/routing/" . $app . "Routing.inc")) {
            require_once(PW_ROOT_DIR . "/app/config/aurora/routing/" . $app . "Routing.inc");
        }
        //
        //↓廃止予定
        if (file_exists(XBE_LIBS_DIR . "/xb.apps/IDs/" . $app . "IDs.class.php")) {
            require_once(XBE_LIBS_DIR . "/xb.apps/IDs/" . $app . "IDs.class.php");
        }
        if (file_exists(XBE_LIBS_DIR . "/xb.apps/messages/" . $app . "Messages.class.php")) {
            require_once(XBE_LIBS_DIR . "/xb.apps/messages/" . $app . "Messages.class.php");
        }
        //
    }
}

/**
 * view関連クラスローダー
 */
function load_view($view, $app = null) {
    if (!isNULL($app)) {
        require_once(XBE_LIBS_DIR . '/xb.library/validator/xbCommonValidate.class.php');
        require_once(XBE_LIBS_DIR . '/xb.library/view/xbBaseView.class.php');
        require_once(XBE_LIBS_DIR . '/xb.library/view/xbCommonView.class.php');
        require_once(XBE_LIBS_DIR . '/xb.library/view/xbPrintView.class.php');
        require_once(XBE_LIBS_DIR . '/xb.library/view/xbTestView.class.php');
        //detail
        if(!class_exists($view.'DetailView')){
            $file = XBE_LIBS_DIR . "/xb.views/" . $app . "/" . $view . "DetailView.class.php";
            if(file_exists($file)){
                require_once($file);
            }
        }
        //item
        if(!class_exists($view.'ItemView')){
            $file = XBE_LIBS_DIR . "/xb.views/" . $app . "/" . $view . "ItemView.class.php";
            if(file_exists($file)){
                require_once ($file);
            }
        }
        require_once(XBE_LIBS_DIR . '/xb.views/' . $app . '/' . $view . 'View.class.php');

        //list
        if(!class_exists($view.'ListView')){
            $file = XBE_LIBS_DIR . "/xb.views/" . $app . "/" . $view . "ListView.class.php";
            if(file_exists($file)){
                require_once($file);
            }
        }
    }
}

/**
 * デモ用メッセージ（ヘッダー）
 */
function demo_messages(){
    if (DEMO==true) {
        return DEMO_MESSAGES;
    }
    else {
        return '';
    }
}

/**
 * デモ用メッセージ（フッター）
 */
function demo_messages_footer(){
    if (DEMO==true) {
        return DEMO_MESSAGES_FOOTER;
    }
    else {
        return '';
    }
}

/**
 * パン屑リスト設定
 * @param string $name 名称
 * @param string $link リンク先
 */
function push_breadcrumb($name, $link) {
    $pwUser     = & xbpwContext::getUser();
    $breadcrumb = $pwUser->getUserParameter(XBE_AURORA_COMMON_BREADCRUMB);

    if (!is_array($breadcrumb)) {
        $breadcrumb = array();
    }
    $breadcrumb[$name] = $link;
//    if (count($breadcrumb) > 5) {
//        $breadcrumb = array_shift($breadcrumb);
//    }

    $pwUser->setUserParameter(XBE_AURORA_COMMON_BREADCRUMB, $breadcrumb);
    xbpwContext::setUser($pwUser);
}

/**
 * パン屑リストからポップする
 * @param string $name 名称
 * @param string $link リンク先
 */
function pop_breadcrumb() {
    $pwUser     = & xbpwContext::getUser();
    $breadcrumb = $pwUser->getUserParameter(XBE_AURORA_COMMON_BREADCRUMB);
    return array_pop($breadcrumb);
}
/**
 * パン屑リストからデキューする
 * @param string $name 名称
 * @param string $link リンク先
 */
function shift_breadcrumb(){
    $pwUser     = & xbpwContext::getUser();
    $breadcrumb = $pwUser->getUserParameter(XBE_AURORA_COMMON_BREADCRUMB);
    return array_shift($breadcrumb);
}

/**
 * パン屑リストクリア
 */
function init_breadcrumb() {
    $pwUser = & xbpwContext::getUser();
    $pwUser->setUserParameter(XBE_AURORA_COMMON_BREADCRUMB, null);
    xbpwContext::setUser($pwUser);
}

/**
 * パン屑リスト構築
 * @param string $currentName 現在のページ名称。
 * @param array  $parentNode  親のページ名称およびリンク先の一覧となります。
 *
 */
function link_location($currentName) {
    $pwUser     = & xbpwContext::getUser();
    $breadcrumb = $pwUser->getUserParameter(XBE_AURORA_COMMON_BREADCRUMB);
    $buffer = '';
    if (isset($breadcrumb)) {
        foreach ($breadcrumb as $key => &$val) {
            if($key == $currentName){
                unset($val);
                continue;
            }
            if ($buffer == '') {
                $buffer = link_to($key, $val);
            }
            else {
                $buffer .= ' > ' . link_to($key, $val);
            }
        }
    }
    if ($buffer != '') {
        $buffer .= ' > ' . $currentName;
    }
    $pwUser->setUserParameter(XBE_AURORA_COMMON_BREADCRUMB, $breadcrumb);
    xbpwContext::setUser($pwUser);
    //パンくずリストをクリア
    //$pwUser->setUserParameter(XBE_AURORA_COMMON_BREADCRUMB, null);
    //xbpwContext::setUser($pwUser);
    return $buffer;
}

/**
 * パン屑リストを表示します
 */
function generate_breadcrumb($currentName) {
    $link = link_location($currentName);
    $html = array ();
    if(!isNULL($link)){
        $html[] = "<table border=0 class='navi_table'>";
        $html[] = "<tr><td align=left>" . $link . "</td></tr>";
        $html[] = "</table>";
    }
    return implode('', $html);
}

/**
 * 【Aurora専用】登録ボタン
 * @param type              [0:通常][1:モーダル]
 * @param prepareRouting    [前処理ルーティング]
 * @param execRouting       [実行ルーティング]
 * @param message           [アラートメッセージ]
 * @param prepareJsFunction [前処理Jscript]
 * @param afterJsFunction   [後処理Jscript]
 * @param name              [ボタン名称]
 */
function aurora_submit($parameter) {
    //パラメータ取得
    $id             = $parameter['id'];
    $type           = $parameter['type'];
    $js_before      = isNULL($parameter['js_before'])?'':$parameter['js_before'] . ';';
    $js_after       = $parameter['js_after'];
    $prepareRouting = $parameter['prepareRouting'];
    $execRouting    = $parameter['execRouting'];
    $postRouting    = $parameter['postRouting'];
    $postJsFunction = $parameter['postJsFunction'];
    $location       = $parameter['location'];
    $name           = $parameter['name'];
    $options        = $parameter['options'];
    $waiing         = isNULL($parameter['waiing'])?true:$parameter['waiing'];

    $lc = "";
    if (!isNULL($location)) {
        $lc = "location.href = '" . $location . "';";
    }

    if (isNULL($postRouting)) {
        $jsPost = $postJsFunction . ";" . $lc;
    }
    else {
        $jsPost = "ajax_request('$postRouting', function(r){" . $lc . "});";
    }

    //$jsExe  = "ajax_request('$execRouting', function(r){var t=r.split(',');if(t[0]=='OK'){alert(t[1])}else{alert(t[1]);return;};" . $jsPost . "});";
    if(isNULL($execRouting)){
        $jsExe = $jsPost;
    }else{
        $jsExe  = "ajax_request('$execRouting', function(r){" . $jsPost . "});";
    }
    $jsPre  = $js_before . "ajax_request('$prepareRouting', function(r){r=r.replace(/^\s+|\s+$/g, '');if(r==''){ ";
    if($waiing){
        $jsPre .= "showWaiing();";
    }
    $jsPre .= $jsExe . "}else{alert(r);return;}});";

    //名称取得
    if (isNULL($name) || $name == '') {
        $name = B_NM_REG;
    }

    $tmpOption = array('type'=>'button', 'class'=>'btn', 'onclick'=>$jsPre);
    if(is_array($options)){
        $button_option = array_merge($tmpOption,$options);
    }else{
        $button_option=$tmpOption;
    }
    return input_tag($id, $name, $button_option);
}

/**
 * 【Aurora専用】登録ボタン（旧）
 * @param type              [0:通常][1:モーダル]
 * @param prepareRouting    [前処理ルーティング]
 * @param execRouting       [実行ルーティング]
 * @param postRouting       [後処理ルーティング]
 * @param afterJsFunction   [後処理Jscript]
 * @param imageName         [image 名称]
 * @param location          [遷移先]
 */
function xb_submit($parameter) {
    //パラメータ取得
    $type           = $parameter['type'];
    $prepareRouting = $parameter['prepareRouting'];
    $execRouting    = $parameter['execRouting'];
    $postRouting    = $parameter['postRouting'];
    $postJsFunction = $parameter['postJsFunction'];
    $imageName      = $parameter['imageName'];
    $location       = $parameter['location'];

    //モーダルダイアログURL生成
    //$modalUrl = xbUtil::generateURL('xbrg_pop.php', 'RequestModalDialog');
    $lc = "";
    if (!isNULL($location)) {
        $lc = "location.href = '" . $location . "';";
    }

    if (isNULL($postRouting)) {
        $jsPost = $postJsFunction . ";" . $lc;
    }
    else {
        $jsPost = "ajax_request('$postRouting', function(r){" . $lc . "});";
    }

    $jsExe  = "ajax_request('$execRouting', function(r){var t=r.split(',');if(t[0]=='OK'){alert(t[1])}else{alert(t[1]);return;};" . $jsPost . "});";
    $jsPre  = "ajax_request('$prepareRouting', function(r){if(r==''){" . $jsExe . "}else{alert(r);return;}});";

    return image_button_tag($imageName, array('onClick'=>$jsPre . ";"));
}

/**
 * 【Aurora専用】サブミットボタンイメージ用
 * $options["target"] ターゲットフォーム
 * $options["action"] ターゲットアクション
 */
function submit_image_button_tag($name, $value, $options) {

    $options["type"] = "button";
    $options["class"] = "btn";

    $target = $options["target"];
    $action = $options["action"];
    if (!isNULL($target)) {
        $script = "sendForm('$target', '$action')";
    }
    if (isset($options["target"])) {
        unset($options["target"]);
    }
    if (isset($options["action"])) {
        unset($options["action"]);
    }

    $options["onClick"] .= ";$script";

    return input_tag($name, $value, $options);
}

/**
 * 【Aurora専用】リンクボタンイメージ用
 */
function image_button_to($name, $internal_uri, $options) {
    if ($internal_uri) {
        $options['onClick'] .= ";document.location.href='" . $internal_uri . "';";
    }
    return image_button_tag($name, $options);
}

/**
 * 【Aurora専用】ボタンイメージ用
 */
function image_button_tag($name, $options) {
    $mouseOut  = "'" . image_path("button/$name" . "_r2_c2.gif") . "'";
    $mouseOver = "'" . image_path("button/$name" . "_r2_c2_f2.gif") . "'";
    $mouseDown = "'" . image_path("button/$name" . "_r2_c2_f4.gif") . "'";
    $onClick   = "'" . image_path("button/$name" . "_r2_c2_f3.gif") . "'";

    $options["onMouseOut"]  .= ";buttonEventImage(this, null, $mouseOut, $onClick);";
    $options["onMouseOver"] .= ";buttonEventImage(this, null, $mouseOver, $mouseDown);";
    //$options["onMousedown"] .= ";buttonEventImage(this, null, $onClick, $onClick);";
    //$options["onMouseup"]   .= ";buttonEventImage(this, null, $mouseOut, $mouseOut);";
    $options["onClick"] .= ";buttonEventImage(this, 'onClick', $onClick, null);";
    $options["style"]       .= ";cursor:pointer;";
    return image_tag("button/$name" . "_r2_c2.gif", $options);
}

/**
 * ページング情報の取得
 *
 * @access public
 * @param  $page_id     利用会社ID
 * @param  $limit       1ページ表示件数
 * @param  $count       全件数
 * @return array
 */
function getPageInfoAurora($page_id = 1, $limit = -1, $count = 0) {
    $offset = $limit * ( $page_id - 1);

    $ret['page_id'] = $page_id;
    $ret['count'] = $count;
    $ret['limit'] = $limit;

    //表示件数の最初と最後の数字を取得
    $ret['snum'] = $offset + 1;
    if( $count == 0 ){
        $ret['snum'] = 0;
    }
    $ret['enum'] = $offset + $limit;
    if( $ret['enum'] > $count ){
        $ret['enum'] = $count;
    }

    //前のページ、次のページ、最後のページのページ番号を取得
    if($count != 0){

        $ret['lastPage'] = ceil( $count / $limit );

        if( $page_id > 1){
            $ret['prePage'] = $page_id - 1;
        }
        else {
            $ret['prePage'] = 1;
        }

        if( $page_id < $ret['lastPage']){
            $ret['nextPage'] = $page_id + 1;
        }
        else {
            $ret['nextPage'] = $ret['lastPage'];
        }
    }

    //ページング情報を返す
    return $ret;
}

/**
 * 承認権限チェック
 * 
 * param: 承認リスト
 * param: ログインユーザーの権限
 * param: 最終承認履歴者の権限
 * 
 * orderno=1→最高承認権限
 * 
 * return: true(承認権限あり) false(承認権限なし)
 */
function check_syonin_sec_level($syonin_route, $logon_user_sec_level, $last_syonin_sec_level) {

    //ログオンユーザの権限が管理者またはユーザ管理者の場合
    if($logon_user_sec_level == AuthService::SUPER || $logon_user_sec_level == AuthService::ADMIN){
        //承認可
        true;
    }

    debugLog('承認リスト：' . print_r($syonin_route, 1), __CLASS__, __FILE__, __LINE__);
    debugLog('ログインユーザ権限：' . $logon_user_sec_level, __CLASS__, __FILE__, __LINE__);
    debugLog('最終承認権限：' . $last_syonin_sec_level, __CLASS__, __FILE__, __LINE__);
    foreach($syonin_route as $data){
        if($logon_user_sec_level == $data['route_id']){
            //ログオンユーザーの承認順を取得
            $logon_user_sec_level_orderno = $data['orderno'];
        }
        if($last_syonin_sec_level == $data['route_id']){
            //最終承認履歴者の承認順を取得
            $last_syonin_sec_level_orderno = $data['orderno'];
        }
    }
    //-----------------------------------------------------------------
    //承認順を比較
    //-----------------------------------------------------------------
    //ログオンユーザーに承認権限あり
    if(!isNULL($logon_user_sec_level_orderno)){
        if(isNULL($last_syonin_sec_level_orderno)) {
        //承認未処理 → 承認可
            return true;
        }
        else if($last_syonin_sec_level_orderno <= $logon_user_sec_level_orderno){
        //ログオンユーザーの承認処理は終了済み → 承認不可
            return false;
        }
        else{
            return true;
        }
    }
    else{
        //ログオンユーザーに承認権限なし → 承認不可
        return false;
    }
}

/**
 * 概要
 *  バックアップ処理
 *
 */
function backup(){

    if(DBTYPE==0){
        myBackup();
    }
    else{
        pgBackup();
    }
}

/**
 * 概要
 *  MySQLバックアップ
 *
 * いまこのコメントを見た人が作ってくれます！！
 */
function myBackup(){
}

/**
 * 概要
 *  PostgreSQLバックアップ
 *
 */
function pgBackup(){

    $rootPath   = PW_ROOT_DIR;
    $cmd;
    $user       = DBUSER;
    $database   = DATABASE;
    $time       = date("YmdHis", time());
    $outputPath = "$rootPath/app/backup/aurora/process/backup_$time.txt";

    //Windows用コマンド
    //詳しくは、C:\svnroot\xbrg_aurora_src\trunk\aurora\batch\pg_backup.bat
    //の中を読んでください。
    if(isset($_ENV['OS']) && preg_match("/window/i", $_ENV['OS'])){
        $cmd    = $rootPath."/app/batch/aurora/pg_backup.bat %s %s %s";
        $exec       = sprintf($cmd, $user, $database ,$outputPath);
        $result = NULL;
        $output = array();
        debugLog(">>>>>backup cmd[$exec]", __CLASS__, __FILE__, __LINE__);
        exec($exec, $output, $result);
    }
    //その他用コマンド
    //外部ファイルは使っていません。わかる人は直してください。
    else{
        system("su - postgres");
        system("/usr/local/pgsql/bin/pg_dump -U $user $database > $rootPath/app/backup/aurora/process/backup_$time.sql");
    }

    //ファイルサイズ 0k の場合、エラー扱い
    if( file_exists($outputPath) ){
        if( filesize($outputPath)==0 ){
            return false;
        }
    }
    else{
        return false;
    }
    return true;
}


?>
