<?php
/**
 * コード Service component.
 *
 * コードcomponent処理を行います
 *
 * PHP versions 5
 *
 * @package     MstCodeService
 * @author      Liu Cheng<liuch@csoft.com.cn> 2006年5月09日
 *              Liu Cheng<liuch@csoft.com.cn> 2006年5月10日
 *              Shiro Tajima <tajima@exbridge.jp> 2007年11月21日 somfa対応
 *              H.Banno<banno@exbridge.jp> 2008年4月8日 pettiwork対応
 * @copyright   2006-2007 EXBRIDGE,Inc. All Rights Reserved.
 * @version     SVN : $Id
 * @link        http://exbridge.jp/
 * @see         なし
 */
class mstCodeService extends xbeAuroraCommonService {

    /**
     * コード一覧取得
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->code_kb
     * @data   $view->[]
     * @return $view
     */
    public function getCodeList(& $vo) {

        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('user_company_id'), & $vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'vo'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getDatabase();

        try {

            //--------------------------------------------------------------
            //検索キー取得
            //--------------------------------------------------------------
            $userCompanyId = $vo->user_company_id;
            $codeKb        = $vo->code_kb;

            //--------------------------------------------------------------
            //条件設定
            //--------------------------------------------------------------
            $keys = null;
            $vals = null;
            if (isNULL($codeKb)) {
                $keys = 'user_company_id = ? ';
                $vals = array($userCompanyId);
            }
            else {
                $keys = 'user_company_id = ? and code_kb = ? ';
                $vals = array($userCompanyId, $codeKb);
            }

            //--------------------------------------------------------------
            //コード情報検索
            //--------------------------------------------------------------
            $rs = $somfa->select('tbv_code',
                                 '*',
                                 $keys,
                                 $vals,
                                 'code_kb, code',
                                 null,
                                 $vo->page_id);

            $vo->count = $somfa->count();

            $detailArray = array();
            foreach ($rs as $item) {
                $codeDetailView = array();
                $codeDetailView['code_kb'] = $item['code_kb'];
                $codeDetailView['code'] = $item['code'];
                $codeDetailView['code_nm'] = $item['code_nm'];
                $detailArray[] = $codeDetailView;
            }
            $vo->list= $detailArray;

            return R_SUCCESS;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * コード登録／更新
     *
     * @access public
     * @param  $vo->user_company_id
     * @param  $vo->code_kb
     * @param  $vo->code
     * @param  $vo->*
     * @return integer
     */
    public function saveCode(& $vo) {

        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert( array('user_company_id', 'code_kb', 'code'), & $vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'vo'));
        }

        //--------------------------------------------------------------
        //対象テーブル
        //--------------------------------------------------------------
        $table = 'tbm_code';

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getDatabase();

        try {

            //--------------------------------------------------------------
            //コード情報取得
            //--------------------------------------------------------------
            $old = $somfa->retrieveByPK($table, array('user_company_id' => $vo->user_company_id,
                                                      'code_kb'         => $vo->code_kb,
                                                      'code'            => $vo->code));

            //--------------------------------------------------------------
            //コード登録用情報生成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id'] = $vo->user_company_id;
            $data['code_kb']         = $vo->code_kb;
            $data['code']            = $vo->code;
            $data['code_nm']         = $vo->code_nm;
            $data['del_flg']         = DB_ENABLE;
            $data['add_date']        = is_array($old)?$old['add_date']:xbUtil::getTimestamp();
            $data['add_pgid']        = is_array($old)?$old['add_pgid']:__METHOD__;
            $data['add_user_cd']     = is_array($old)?$old['add_user_cd']:$vo->logon_user_cd;
            $data['upd_date']        = xbUtil::getTimestamp();
            $data['upd_pgid']        = __METHOD__;
            $data['upd_user_cd']     = $vo->logon_user_cd;

            //--------------------------------------------------------------
            //コード登録／更新実行
            //--------------------------------------------------------------
            $somfa->begin();
            $results = $somfa->save($table, $data);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * コード削除
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->code_kb
     * @param  $view->code
     * @return integer
     */
    public function deleteCode(& $vo) {

        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert( array('user_company_id','code_kb','code'), & $vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'vo'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getDatabase();

        try {

            //--------------------------------------------------------------
            //コード削除用情報生成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id'] = $vo->user_company_id;
            $data['code_kb']         = $vo->code_kb;
            $data['code']            = $vo->code;
            $data['del_flg']         = DB_DELETE;
            $data['upd_date']        = xbUtil::getTimestamp();
            $data['upd_pgid']        = __METHOD__;
            $data['upd_user_cd']     = $vo->logon_user_cd;

            //--------------------------------------------------------------
            //コード削除実行
            //--------------------------------------------------------------
            $somfa->begin();
            $results = $somfa->save('tbm_code', $data);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * コードリスト削除
     *
     * @access public
     * @param  $view->codeListDetailView
     * @return integer
     */
    public function deleteCodeList(& $vo) {

        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getDatabase();

        try {

            //--------------------------------------------------------------
            //コード一括削除
            //--------------------------------------------------------------
            $detailView = $vo->code_list_detail_view();
            $delCount   = 0;

            $somfa->begin();
            foreach($detailView as $v) {
                $delChk = $v->getChecked();
                if($delChk == '1') {
                    //--------------------------------------------------------------
                    //削除実行
                    //--------------------------------------------------------------
                    $this->deleteCode($v);
                    $delCount++;
                }
            }
            $somfa->commit();

            if ($delCount == 0) {
                return R_SUCCESS_NODATA;
            } else {
                return R_SUCCESS_DELETE;
            }
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * コードリスト
     *
     * @param  $view->user_company_id
     * @param  $view->code_kb
     * @data   $view->[]
     * @return integer
     */
    public function createCodeList(& $vo) {

        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('user_company_id'), & $vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'vo'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getDatabase();

        try {

            //--------------------------------------------------------------
            //コード検索
            //--------------------------------------------------------------
            $rs = $somfa->select('tbv_code', 'code, code_nm',
                                 'user_company_id = ? and code_kb = ?',
                                 array($vo->user_company_id, $vo->code_kb),
                                 'code_kb, code');

            $code_list = array();
            foreach ($rs as $item) {
                $code_list[$item['code']] = $item['code_nm'];
            }
            $vo->code_list = $code_list;
            return R_SUCCESS;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }
}
?>
