<?php
/*
 * This file is part of HELIOS.PetitForm
 * (c) 2007-2008 Exbridge,inc. <info@exbridge.jp>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

/**
 * フォーム登録情報管理サービス
 *
 * @copyright 2008- EXBRIDGE,Inc. All Rights Reserved.
 * @link      http://exbridge.jp/
 * @package   HELIOS.PetitForm
 * @version   svn:$Id: requestFormService.php 8740 2008-10-03 00:58:33Z kobayashi $
 */
class requestFormService extends xbpwService {

    var $_company_list  = array();      //個人ID-個人名の配列
    var $_personal_list = array();      //会社ID-会社名の配列

    /**
     * 一覧取得
     *
     * @access  public
     * @param   
     * @return  
     */
    public function getRequestList(& $vo){
        //--------------------------------------------------------------
        //呼出ログ出力
        //--------------------------------------------------------------
        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('user_company_id'), & $vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'vo'));
        }

        try {
            //--------------------------------------------------------------
            //テーブル情報の取得
            //--------------------------------------------------------------
            $somfa = $this->getDatabase();

            $this->_company_list  = heliosPetitFormConfig::getCompany();
            $this->_personal_list = heliosPetitFormConfig::getPersonal();

            $search_flg = true;     //クエリ実行の判断
            $count = 0;             //結果件数

            if (!isNULL($vo->page_id)) {
                $limit  = $somfa->_my_conf['default']['page_max'];
                $offset = ($vo->page_id - 1) * $limit;
            }
            else {
                $limit  = -1;
                $offset = -1;
            }

            $keys = array();
            $vals = array();

            $keys[] = ' user_company_id = ? ';
            $vals[] = $vo->user_company_id;

            $keys[] = ' del_flg = ? ';
            $vals[] = DB_ENABLE;

            //会社名 (会社リストを走査し、入力した会社名が含まれれば条件に追加)
            if (!isNULL($vo->company_nm)) {
                $ph = array();
                foreach ($this->_company_list as $id => $nm) {
                    if (mb_strpos($nm, $vo->company_nm) !== false) {
                        $ph[] = '?';
                        $vals[] = $id;
                    }
                }
                if (count($ph) > 0) {
                    $keys[] = 'company_id IN (' . implode(', ', $ph) . ')';
                }
                else {
                    $search_flg = false;    //存在しなければ検索しない
                }
            }

            //氏名 (個人リストを走査し、入力した個人名が含まれれば条件に追加)
            if (!isNULL($vo->personal_nm)) {
                $ph = array();
                foreach ($this->_personal_list as $id => $nm) {
                    if (mb_strpos($nm, $vo->personal_nm) !== false) {
                        $ph[] = '?';
                        $vals[] = $id;
                    }
                }
                if (count($ph) > 0) {
                    $keys[] = 'personal_id IN (' . implode(', ', $ph) . ')';
                }
                else {
                    $search_flg = false;    //存在しなければ検索しない
                }
            }

            //個人／法人
            if (count($vo->client_kb_list) > 0){
                $ph = array();
                foreach ($vo->client_kb_list as $kb) {
                    $ph[] = '?';
                    $vals[] = $kb;
                }
                $keys[] = 'client_kb IN (' . implode(', ', $ph) . ')';
            }

            //対応状況
            if (count($vo->answer_status_kb_list) > 0){
                $ph = array();
                foreach ($vo->answer_status_kb_list as $kb) {
                    $ph[] = '?';
                    $vals[] = $kb;
                }
                $keys[] = 'answer_status_kb IN (' . implode(', ', $ph) . ')';
            }

            //お問い合わせ内容
            if (!isNULL($vo->request)){
                $keys[] = 'request like ?';
                $vals[] = '%' . $vo->request . '%';
            }

            //日付 from
            if (!isNULL($vo->request_date_from)){
                $keys[] = 'request_date >= ?';
                $vals[] = $vo->request_date_from;
            }

            //日付 to
            if (!isNULL($vo->request_date_to)){
                $keys[] = 'request_date <= ?';
                $vals[] = $vo->request_date_to;
            }

            $keys_str = implode(' AND ', $keys);

            //一覧取得
            if ($search_flg === true) {
                $rs = $somfa->selectLimit('SELECT user_company_id,
                                                  request_id,
                                                  client_kb,
                                                  personal_id,
                                                  tanto_id,
                                                  company_id,
                                                  organization_nm,
                                                  official_nm,
                                                  request,
                                                  request_date,
                                                  answer_status_kb,
                                                  biko,
                                                  del_flg,
                                                  add_date,
                                                  upd_date,
                                                  add_pgid,
                                                  upd_pgid,
                                                  add_user_cd,
                                                  upd_user_cd
                                            FROM tbt_request
                                            WHERE' . $keys_str .
                                           'ORDER BY add_date DESC',
                                           $limit,
                                           $offset,
                                           $vals);
                $count = count($rs);
            }

            //ページ情報の取得
            if (!isNULL($vo->page_id)) {
                $vo->page_info = getPageInfo($vo->page_id, $limit, $count);
            }

            //--------------------------------------------------------------
            //返り値設定
            //--------------------------------------------------------------
            if ($count > 0) {
                //会社名、個人名を付加
                foreach ($rs as $key => $request) {
                    $rs[$key]['company_nm'] = $this->_company_list[$request['company_id']];
                    $rs[$key]['personal_nm'] = $this->_personal_list[$request['personal_id']];
                }
                $vo->request_list = $rs;
                return R_SUCCESS;
            }
            else {
                return R_ERROR_NULL;
            }
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 一件取得
     *
     * @access  public
     * @param   
     * @return  
     */
    public function getRequest(& $vo){
        //--------------------------------------------------------------
        //呼出ログ出力
        //--------------------------------------------------------------
        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('user_company_id', 'request_id'), & $vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'vo'));
        }

        try {
            //--------------------------------------------------------------
            //テーブル情報の取得
            //--------------------------------------------------------------
            $somfa = $this->getDatabase();

            $cond = array();
            $cond['user_company_id'] = $vo->user_company_id;
            $cond['request_id']      = $vo->request_id;

            //取得
            $record = $somfa->retrieveByPK('tbt_request',
                                           $cond);

            //--------------------------------------------------------------
            //返り値設定
            //--------------------------------------------------------------
            if (is_array($record)) {
                //マスタ情報を付加
                if ($record['client_kb'] == CLIENTKB_PERSON) {
                    $personal = $this->_getPersonal($record['personal_id']);

                    $record = array_merge($record, $personal);
                    unset($record['company_id']);
                    unset($record['company_nm']);
                }
                else if ($record['client_kb'] == CLIENTKB_CORPORATION) {
                    $company = $this->_getCompany($record['company_id']);

                    $record = array_merge($record, $company);

                    $personal = $this->_getPersonal($record['personal_id']);

                    $record['personal_kn'] = $personal['personal_kn'];
                    $record['personal_nm'] = $personal['personal_nm'];
                    $record['mail'] = $personal['emp_mail'];
                }

                $vo->request = $record;
                return R_SUCCESS;
            }
            else {
                return R_ERROR_NULL;
            }
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 一覧削除
     *
     * @access  public
     * @param   
     * @return  
     */
    public function deleteRequestList(& $vo){
        //--------------------------------------------------------------
        //呼出ログ出力
        //--------------------------------------------------------------
        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('user_company_id'), & $vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'vo'));
        }

        try {
            $somfa = $this->getDatabase();

            $somfa->begin();

            foreach ($vo->request_id_list as $request_id) {
                $vo->request_id = $request_id;
                $result = $this->deleteRequest($vo);

                if ($result != R_SUCCESS_UPDATE) {
                    $somfa->rollback();
                    return R_ERROR;
                }
            }

            $somfa->commit();
            return R_SUCCESS_DESTROY;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 削除
     *
     * @access  public
     * @param   
     * @return  
     */
    public function deleteRequest(& $vo){
        //--------------------------------------------------------------
        //呼出ログ出力
        //--------------------------------------------------------------
        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('user_company_id', 'request_id'), & $vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'vo'));
        }

        try {
            $somfa = $this->getDatabase();

            $data = array();
            $data['user_company_id'] = $vo->user_company_id;
            $data['request_id']        = $vo->request_id;
            $data['del_flg']         = DB_DELETE;
            $data['upd_date']        = xbUtil::getTimestamp();
            $data['upd_pgid']        = __METHOD__;
            $data['upd_user_cd']     = $vo->logon_user_cd;

            //削除実行
            $somfa->begin();
            $result = $somfa->save('tbt_request', $data);

            if ($result == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                $somfa->rollback();
            }

            return $result;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * お問い合わせ登録／更新
     *
     * @access public
     * @param  $vo->user_company_id
     * @param  $vo->request_id
     * @param  $vo->*
     * @return integer
     */
    public function saveRequest(& $vo) {
        //--------------------------------------------------------------
        //呼出ログ出力
        //--------------------------------------------------------------
        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        //--------------------------------------------------------------
        //対象テーブル
        //--------------------------------------------------------------
        $table = 'tbt_request';

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getDatabase();

        $somfa->begin();

        try {

            //--------------------------------------------------------------
            //自動採番
            //--------------------------------------------------------------
            if (isNULL($vo->request_id)) {
                //テーブルロック
                $rs_lock = $somfa->select($table,
                                          '*',
                                          'user_company_id = ? for update',
                                          $vo->user_company_id);

                $rs = $somfa->select($table,
                                     'case when max(request_id) is null then 1 else max(request_id) + 1 end as request_id',
                                     'user_company_id=?',
                                     array($vo->user_company_id));

                $vo->request_id = $rs[0]['request_id'];
            }

            $old = $somfa->retrieveByPK($table,
                                        array('user_company_id' => $vo->user_company_id,
                                              'request_id'    => $vo->request_id));

            //--------------------------------------------------------------
            //お問い合わせ登録用情報生成
            //--------------------------------------------------------------
            $update_time = xbUtil::getTimestamp();

            $data = array();
            $data['user_company_id']  = $vo->user_company_id;
            $data['request_id']       = $vo->request_id;
            $data['client_kb']        = $vo->client_kb;
            $data['personal_id']      = $vo->personal_id;
            $data['tanto_id']         = $vo->tanto_id;
            $data['company_id']       = $vo->company_id;
            $data['organization_nm']  = $vo->organization_nm;
            $data['official_nm']      = $vo->official_nm;
            $data['request']          = $vo->request;
            $data['request_date']     = is_array($old)?$old['request_date']:$update_time;
            $data['answer_status_kb'] = $vo->answer_status_kb;
            $data['biko']             = $vo->biko;
            $data['del_flg']          = DB_ENABLE;
            $data['add_date']        = is_array($old)?$old['add_date']:$update_time;
            $data['add_pgid']        = is_array($old)?$old['add_pgid']:__METHOD__;
            $data['add_user_cd']     = is_array($old)?$old['add_user_cd']:$vo->logon_user_cd;
            $data['upd_date']         = $update_time;
            $data['upd_pgid']         = __METHOD__;
            $data['upd_user_cd']      = $vo->logon_user_cd;

            //--------------------------------------------------------------
            //お問い合わせ登録／更新実行
            //--------------------------------------------------------------
            $results = $somfa->save($table, $data);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                $somfa->rollback();
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人情報の登録/更新
     *
     * @access public
     * @param  $vo
     * @return
     */
    public function savePersonal(& $vo){

        //--------------------------------------------------------------
        //呼出ログ出力
        //--------------------------------------------------------------
        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        try {

            //AURORA WEBサービスを使用
            $url = AURORA_URL . 'xbeWebMaster.php?action=RequestSavePersonal';

            $params = array();

            $params['client_kb']       = $vo->client_kb;
            $params['personal_nm']     = $vo->personal_nm;
            $params['personal_kn']     = $vo->personal_kn;
            $params['mail']            = $vo->mail;
            $params['url']             = $vo->url;
            $params['zipcode']         = $vo->zipcode;
            $params['address1']        = $vo->address1;
            $params['address2']        = $vo->address2;
            $params['address3']        = $vo->address3;
            $params['address4']        = $vo->address4;
            $params['tel']             = $vo->tel;

            debugLog('params ' . print_r($params, true), __CLASS__, __FILE__, __LINE__);

            //POSTで渡す
            $result_info_json = get_url_contents($url, $params);
            $result_info = json_decode($result_info_json, true);
            $vo->personal_id = $result_info['personal_id'];
            return $result_info['r_code'];
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 会社情報の登録/更新
     *
     * @access public
     * @param  $vo
     * @return
     */
    public function saveCompany(& $vo){

        //--------------------------------------------------------------
        //呼出ログ出力
        //--------------------------------------------------------------
        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        try {

            //AURORA WEBサービスを使用
            $url = AURORA_URL . 'xbeWebMaster.php?action=RequestSaveCompany';

            $params = array();

            $params['url']             = $vo->url;
            $params['company_nm']      = $vo->company_nm;
            $params['company_kn']      = $vo->company_kn;
            $params['zipcode']         = $vo->zipcode;
            $params['address1']        = $vo->address1;
            $params['address2']        = $vo->address2;
            $params['address3']        = $vo->address3;
            $params['address4']        = $vo->address4;
            $params['tel']             = $vo->tel;

            debugLog('params ' . print_r($params, true), __CLASS__, __FILE__, __LINE__);

            //POSTで渡す
            $result_info_json = get_url_contents($url, $params);
            $result_info = json_decode($result_info_json, true);
            $vo->company_id = $result_info['company_id'];
            return $result_info['r_code'];
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 従業員情報の登録/更新
     *
     * @access public
     * @param  $vo
     * @return
     */
    public function savePersonalEmployee(& $vo){

        //--------------------------------------------------------------
        //呼出ログ出力
        //--------------------------------------------------------------
        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        try {

            //AURORA WEBサービスを使用
            $url = AURORA_URL . 'xbeWebMaster.php?action=RequestSavePersonalEmployee';

            $params = array();

            $params['personal_id']     = $vo->personal_id;
            $params['company_id']      = $vo->company_id;
            $params['mail']            = $vo->mail;
            $params['tel']             = $vo->tel;

            debugLog('params ' . print_r($params, true), __CLASS__, __FILE__, __LINE__);

            //POSTで渡す
            $result_info_json = get_url_contents($url, $params);
            $result_info = json_decode($result_info_json, true);
            return $result_info['r_code'];
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 担当情報の登録/更新
     *
     * @access public
     * @param  $vo
     * @return
     */
    public function saveTanto(& $vo){

        //--------------------------------------------------------------
        //呼出ログ出力
        //--------------------------------------------------------------
        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        try {

            //AURORA WEBサービスを使用
            $url = AURORA_URL . 'xbeWebMaster.php?action=RequestSaveTanto';

            $params = array();

            $params['personal_id']     = $vo->personal_id;

            debugLog('params ' . print_r($params, true), __CLASS__, __FILE__, __LINE__);

            //POSTで渡す
            $result_info_json = get_url_contents($url, $params);
            $result_info = json_decode($result_info_json, true);
            $vo->tanto_id = $result_info['tanto_id'];
            return $result_info['r_code'];
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * メール送信
     *
     * @access public
     * @param  $vo->to_address_list
     * @param  $vo->title
     * @param  $vo->body
     * @param  $vo->*
     * @return integer
     */
    public function send(& $vo) {
        debugLog('called ' . __METHOD__, __CLASS__, __FILE__, __LINE__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (isNULL($vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'vo'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('to_mail_info_list', 'from_mail_info', 'subject', 'body'), & $vo)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'vo'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getDatabase();

        try {

            $mail = new xbpwMail(SMTP_HOST, SMTP_PORT);

            //--------------------------------------
            //送信者設定
            //--------------------------------------
            $mail->setSender($vo->from_mail_info);

            //--------------------------------------
            //受信者設定
            //--------------------------------------
            foreach ($vo->to_mail_info_list as $to_mail_info) {
                if(!isNULL($to_mail_info)){
                    $mail->addTo($to_mail_info);
                }
            }
            //--------------------------------------
            //CC設定
            //--------------------------------------
            foreach ($vo->cc_mail_info_list as $cc_mail_info) {
                if(!isNULL($cc_mail_info)){
                    $mail->addCC($cc_mail_info);
                }
            }

            //--------------------------------------
            //BCC設定
            //--------------------------------------
            foreach ($vo->bcc_mail_info_list as $bcc_mail_info) {
                if(!isNULL($bcc_mail_info)){
                    $mail->addBCC($bcc_mail_info);
                }
            }

            //--------------------------------------
            //件名設定
            //--------------------------------------
            $mail->setSubject($vo->subject);

            //--------------------------------------
            //本文設定 @todo 文頭に改行コードが必要。。。
            //--------------------------------------
            $mail->setBody("\n" . $vo->body);

            //--------------------------------------
            //添付ファイル設定
            //--------------------------------------
            foreach ($vo->file_list as $file) {
                $mail->addFile($path . '/' . $file, $file);
            }

            //--------------------------------------
            //メール送信
            //--------------------------------------
            $result_info = $mail->send();

            return $result_info;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人情報取得
     *
     * @access  private
     * @param   integer $personal_id    個人ID
     * @return  array                   個人情報配列
     */
    private function _getPersonal($personal_id) {
        if (isNULL($personal_id)) {
            return $array;
        }

        $requestUrl = AURORA_URL . 'xbeWebMaster.php?action=RequestPersonal' . '&magic=' . AUTH_MAGIC . '&personal_id=' . $personal_id;
        $data = get_url_contents($requestUrl);

        return json_decode($data, true);
    }

    /**
     * 会社情報取得
     *
     * @access  private
     * @param   integer $company_id     会社ID
     * @return  array                   会社情報配列
     */
    private function _getCompany($company_id) {
        if (isNULL($company_id)) {
            return $array;
        }

        $requestUrl = AURORA_URL . 'xbeWebMaster.php?action=RequestCompany' . '&magic=' . AUTH_MAGIC . '&company_id=' . $company_id;
        $data = get_url_contents($requestUrl);

        return json_decode($data, true);
    }
}
?>