<?php
/**
 * ユーザー Service component.
 *
 * ユーザーcomponent処理を行います
 *
 * PHP versions 5
 *
 * @package     MstUserService
 * @author      Shiro Tajima <tajima@exbridge.jp> 2007年11月26日 somfa対応
 * @copyright   2006-2007 EXBRIDGE,Inc. All Rights Reserved.
 * @version     SVN : $Id
 * @link        http://exbridge.jp/
 * @see         なし
 */
class MstUserService extends xbService {

    /**
     * ユーザー検索条件構築
     *
     * @access private
     * @param  $view->user_company_id
     * @param  $view->personal_nm
     * @param  $view->personal_kn
     * @param  $view->personal_tel
     * @param  $view->mobile
     * @param  $view->personal_address
     * @data   $keys
     * @data   $vals
     * @data   $ords
     * @return integer
     */
    private function _createCriteria(& $view, & $keys, & $vals, & $ords) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        try {

            $_keys = array();
            $_vals = array();

            //--------------------------------------------------------------
            //利用会社ID（必須・完全一致）
            //--------------------------------------------------------------
            $_keys[] = 'user_company_id = ? ';
            $_vals[] = $view->getUserCompanyId();

            if (method_exists($view, 'getFrom')) {
                //--------------------------------------------------------------
                //個人名称（部分一致）
                //--------------------------------------------------------------
                if (!xbUtil::isNULL($view->getPersonalNm())) {
                    $_keys[] = 'personal_nm like ? ';
                    $_vals[] = '%' . $view->getPersonalNm() . '%';
                }

                //--------------------------------------------------------------
                //個人名かな（部分一致）
                //--------------------------------------------------------------
                if (!xbUtil::isNULL($view->getPersonalKn())) {
                    $_keys[] = 'personal_kn like ? ';
                    $_vals[] = '%' . $view->getPersonalKn() . '%';
                }

                //--------------------------------------------------------------
                //電話番号（部分一致）
                //--------------------------------------------------------------
                if (!xbUtil::isNULL($view->getPersonalTel())) {
                    $_keys[] = 'personal_tel like ? ';
                    $_vals[] = '%' . $view->getPersonalTel() . '%';
                }

                //--------------------------------------------------------------
                //携帯電話（部分一致）
                //--------------------------------------------------------------
                if (!xbUtil::isNULL($view->getMobile())) {
                    $_keys[] = 'mobile like ? ';
                    $_vals[] = '%' . $view->getMobile() . '%';
                }

                //--------------------------------------------------------------
                //住所（部分一致）
                //--------------------------------------------------------------
                if (!xbUtil::isNULL($view->getPersonalAddress())) {
                    $_keys[] = ' (personal_address1 like ? or personal_address2 like ? or personal_address3 like ? or personal_address4 like ?) ';
                    $_vals[] = '%' . $view->getPersonalAddress() . '%';
                    $_vals[] = '%' . $view->getPersonalAddress() . '%';
                    $_vals[] = '%' . $view->getPersonalAddress() . '%';
                    $_vals[] = '%' . $view->getPersonalAddress() . '%';
                }

                if ($view->getFrom() == 'msb_dengon') {
                    $_keys[] = 'staff_cd is not null ';
                }
            }
            else {

                //--------------------------------------------------------------
                //個人名称（部分一致）
                //--------------------------------------------------------------
                if (!xbUtil::isNULL($view->getUserNm())) {
                    $_keys[] = 'personal_nm like ? ';
                    $_vals[] = '%' . $view->getUserNm() . '%';
                }

                //--------------------------------------------------------------
                //メールアドレス（部分一致）
                //--------------------------------------------------------------
                if (!xbUtil::isNULL($view->getMail())) {
                    $_keys[] = 'mail like ? ';
                    $_vals[] = '%' . $view->getMail() . '%';
                }

                //--------------------------------------------------------------
                //状態（完全一致）
                //--------------------------------------------------------------
                if (!xbUtil::isNULL($view->getAuthGroupId())) {
                    if($view->getAuthGroupId() == 'none'){
                        $_keys[] = 'auth_group_id is null ';
                    }
                    else{
                        $_keys[] = 'auth_group_id = ? ';
                        $_vals[] = $view->getAuthGroupId();
                    }
                }
                //--------------------------------------------------------------
                //承認状態
                //--------------------------------------------------------------
                if (!xbUtil::isNULL($view->getActivate())) {
                    $_keys[] = 'activate = ? ';
                    $_vals[] = $view->getActivate();
                }


            }

            $keys = implode(" and ", $_keys);
            $vals = $_vals;
            $ords = 'user_cd, personal_id';

            return R_SUCCESS;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * ユーザー／社員　存在確認
     *
     * @access private
     * @param  $view->user_company_id
     * @param  $view->user_cd
     * @param  $view->personal_id
     * @param  $target 'user'
     * @return boolean true/fase
     */
    private function _exists(& $view, $target='user') {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            $method = 'get' . ucfirst($target) . 'Cd';

            if (xbUtil::isNULL($view->$method())) {
                return false;
            }

            //--------------------------------------------------------------
            //論理チェック
            //新規登録時　ユーザー（or社員）がすでに存在する場合、登録不可
            //更新時　　　ユーザー（or社員）が自身以外でユーザー（or社員）がすでに存在する場合、更新不可
            //--------------------------------------------------------------
            $keys = array();
            $vals = array();
            if (xbUtil::isNULL($view->getPersonalId())) {
                $rs = $somfa->select('tbv_user_info', '*',
                                     'user_company_id = ? and '.$target.'_cd = ? ',
                                     array($view->getUserCompanyId(), $view->$method()));
            }
            else {
                $rs = $somfa->select('tbv_user_info', '*',
                                     'user_company_id = ? and '.$target.'_cd = ? and personal_id <> ? ',
                                     array($view->getUserCompanyId(), $view->$method(), $view->getPersonalId()));
            }
            if (is_array($rs)) {
                if (count($rs) > 0) {
                    return true;
                }
            }
            return false;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人登録／更新
     *
     * @access private
     * @param  $view->user_company_id
     * @param  $view->user_cd
     * @param  $view->staff_cd
     * @param  $view->personal_id
     * @param  $target 'user' or 'staff'
     * @return boolean true/fase
     */
    private function _savePersonal(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        try {

            //--------------------------------------------------------------
            //個人を登録する
            //--------------------------------------------------------------
            $personalView = PersonalBaseView::getInstance();
            $personalView->setPersonalId($view->getPersonalId());
            $personalView->setPersonalNm($view->getUserNm());
            $personalView->setPersonalKn($view->getUserKn());
            $personalView->setMail($view->getMail());

            $personalHomeView = PersonalHomeView::getInstance();
            $personalHomeView->setPersonalId($view->getPersonalId());

            $personalParentView = PersonalParentView::getInstance();
            $personalParentView->setPersonalId($view->getPersonalId());

            $personalView->setHomeView($personalHomeView);
            $personalView->setParentView($personalParentView);

            $results = auroraService::getInstance('PersonalService')->savePersonal($personalView);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $view->setPersonalId($personalView->getPersonalId());
                return $results;
            }
            else if ($results == R_ERROR_DUPL) {
                return $results;
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * ユーザー認証
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->user_cd
     * @param  boolean [false:パスワード除外] [true:パスワード含む]
     * @return boolean
     */
    function isUser(& $view, $pass=false) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId', 'userCd'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //条件設定
            //--------------------------------------------------------------
            $_keys = array();
            $_vals = array();

            $_keys[] = 'user_company_id = ? ';
            $_vals[] = $view->getUserCompanyId();

            $_keys[] = 'user_cd = ? ';
            $_vals[] = $view->getUserCd();

            if ($pass) {
                $passwd    = $view->getPasswd();
                //仮パスワードが発行されている場合
                $tmpPasswd = $passwd;
                if (AUTH_MAGIC_ENABLED) {
                    $passwd = sha1($passwd . ':' . AUTH_MAGIC);
                }
                //仮パスワードが発行されていてかつ有効になっている場合
                $_keys[] = '((password = ? and tmp_password is null ) or (tmp_password = ?))';
                $_keys[] = 'auth_group_id <> ? ';
                $_vals[] = $passwd;
                $_vals[] = $tmpPasswd;
                //未承認ユーザー
                $_vals[] = '97';
            }

            $keys = implode(" and ", $_keys);
            $vals = $_vals;

            //--------------------------------------------------------------
            //ユーザー検索
            //--------------------------------------------------------------
            $rs = $somfa->select('tbv_user_info', '*',
                                 $keys,
                                 $vals);

            //--------------------------------------------------------------
            //ユーザー存在判定
            //--------------------------------------------------------------
            if (is_array($rs)) {
                if (count($rs) > 0) {
                    xbLog::logger(xbLog::DEBUG, __CLASS__, 'checked : true');
                    return true;
                }
                else {
                    xbLog::logger(xbLog::DEBUG, __CLASS__, 'checked : false');
                    return false;
                }
            }
            else {
                xbLog::logger(xbLog::DEBUG, __CLASS__, 'checked : false');
                return false;
            }
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * ユーザー認証（ワンタイムパスワード）社内ファイル便で利用
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->user_cd
     * @param  $view->password
     * @return boolean
     */
    public function isUserOneTimePassword(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId', 'userCd'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //ユーザー確認
            //--------------------------------------------------------------
            $results = $this->isUser($view, false);
            if (!$results) {
                xbLog::logger(xbLog::DEBUG, __CLASS__, 'checked : false');
                return false;
            }

            //--------------------------------------------------------------
            //ワンタイムパスワード取得
            //--------------------------------------------------------------
            $password = $view->getPasswd();

            //--------------------------------------------------------------
            //メールアドレス取得
            //--------------------------------------------------------------
            $view = $this->getUser($view);

            //--------------------------------------------------------------
            //ファイル便レコードの検索
            //@todo 何百通も送信した時にメールアドレスでワンタイムパスワードが被ることがあったら困る。
            //      そのうちきっと偉い人が直してくれます。今これを読んでるあなたです。
            //--------------------------------------------------------------
            $rs = $somfa->select('tbt_taku_send_record_detail', '*',
                                 'user_company_id = ? and send_mail = ? and user_password = ? ',
                                 array($view->getUserCompanyId(), $view->getMail(), $password));

            //--------------------------------------------------------------
            //ユーザー存在判定
            //--------------------------------------------------------------
            if (is_array($rs)) {
                if (count($rs) > 0) {
                    xbLog::logger(xbLog::DEBUG, __CLASS__, 'checked : true');
                    return true;
                }
                else {
                    xbLog::logger(xbLog::DEBUG, __CLASS__, 'checked : false');
                    return false;
                }
            }
            else {
                xbLog::logger(xbLog::DEBUG, __CLASS__, 'checked : false');
                return false;
            }
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * ユーザー取得
     *
     * @access public
     * @param  $view->user_company_id
     * @return $view
     */
    public function getUserList(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //条件設定
            //--------------------------------------------------------------
            $keys = null;
            $vals = null;
            $ords = null;
            $this->_createCriteria($view, $keys, $vals, $ords);

            //--------------------------------------------------------------
            //ユーザー検索
            //--------------------------------------------------------------
            $page_id = $view->getPageId();

            $rs = $somfa->select('tbv_user_info', '*',
                                 $keys,
                                 $vals,
                                 $ords,
                                 null,
                                 $page_id);

            $userListView = $view;
            $userListView->setPageId($page_id);
            $userListView->setCount($somfa->count());

            if (!method_exists($view, 'getFrom')) {
                $detailArray = array();
                foreach ($rs as $item) {
                    $userListDetailView = UserListDetailView::getInstance();
                    $userListDetailView->setPersonalId($item['personal_id']);
                    $userListDetailView->setUserCd($item['user_cd']);
                    $userListDetailView->setUserNm($item['personal_nm']);
                    $userListDetailView->setMail($item['mail']);
                    $userListDetailView->setMobileMail($item['mobile_mail']);
                    $userListDetailView->setAuthGroupId($item['auth_group_id']);
                    $userListDetailView->setAuthGroupNm($item['auth_group_nm']);
                    $userListDetailView->setActivate($item['activate']);
                    $userListDetailView->setAuthRank($item['auth_rank']);
                    $detailArray[] = $userListDetailView;
                }
                $userListView->setUserListDetailView($detailArray);
            }
            else {
                $detailArray = array();
                foreach ($rs as $item) {
                    $userListDetailView = PersonalListDetailView::getInstance();
                    $userListDetailView->setPersonalId($item['personal_id']);
                    $userListDetailView->setPersonalNm($item['personal_nm']);
                    $userListDetailView->setPersonalKn($item['personal_kn']);
                    $userListDetailView->setZipcode($item['personal_zipcode']);
                    $userListDetailView->setAddress($item['personal_address1'] . $item['personal_address2'] . $item['personal_address3'] . $item['personal_address4']);
                    $userListDetailView->setAddress1($item['personal_address1']);
                    $userListDetailView->setAddress2($item['personal_address2']);
                    $userListDetailView->setAddress3($item['personal_address3']);
                    $userListDetailView->setAddress4($item['personal_address4']);
                    $userListDetailView->setTel($item['personal_tel']);
                    $userListDetailView->setUrl($item['url']);
                    $userListDetailView->setMail($item['mail']);
                    $userListDetailView->setMobile($item['mobile']);
                    $userListDetailView->setMobileMail($item['mobile_mail']);
                    $userListDetailView->setOrganizationId($item['organization']);
                    $userListDetailView->setCompanyId($item['company_id']);
                    $userListDetailView->setCompanyNm($item['company_nm']);
                    $userListDetailView->setCompanyTel($item['company_tel']);
                    $userListDetailView->setTelIn($item['tel_in']);
                    $userListDetailView->setOfficeMail($item['office_mail']);
                    $userListDetailView->setOfficialId($item['official_id']);
                    $userListDetailView->setUserCd($item['user_cd']);
                    $userListDetailView->setPassword($item['password']);
                    $detailArray[$item['personal_id']] = $userListDetailView;
                }
                $userListView->setPersonalListDetailView($detailArray);
            }
            return $userListView;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * ユーザー取得         //@todo ユーザーを管理するview tbv_user_info　ひとつでいいの？
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->user_cd
     * @data   $view->*
     * @return $view
     */
    function getUser(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //条件設定
            //--------------------------------------------------------------
            $keys = array();
            $vals = array();
            if (!xbUtil::isNULL($view->getUserCd())) {
                $keys[] = '(user_company_id = ? and user_cd = ? and user_cd is not null) ';
                $vals[] = $view->getUserCompanyId();
                $vals[] = $view->getUserCd();
            }
            if (!xbUtil::isNULL($view->getPersonalId())) {
                $keys[] = '(user_company_id = ? and personal_id = ? and personal_id is not null) ';
                $vals[] = $view->getUserCompanyId();
                $vals[] = $view->getPersonalId();
            }
            if (!xbUtil::isNULL($view->getMail())) {
                $keys[] = '(user_company_id = ? and mail = ? and mail is not null) ';
                $vals[] = $view->getUserCompanyId();
                $vals[] = $view->getMail();
            }
            if (!xbUtil::isNULL($view->getMobileMail())) {
                $keys[] = '(user_company_id = ? and mobile_mail = ? and mobile_mail is not null) ';
                $vals[] = $view->getUserCompanyId();
                $vals[] = $view->getMobileMail();
            }
            if (count($keys) == 0) {
                return $view;
            }
            $keys = implode(' or ', $keys);

            //--------------------------------------------------------------
            //ユーザーの検索
            //--------------------------------------------------------------
            $rs = $somfa->select('tbv_user_info',
                                 '*',
                                 $keys,
                                 $vals);

            $userView = $view;

            foreach ($rs as $item) {
                $userView->setPersonalId($item['personal_id']);
                $userView->setUserCd($item['user_cd']);
                $userView->setUserKn($item['personal_kn']);
                $userView->setUserNm($item['personal_nm']);
                $userView->setStaffCd($item['staff_cd']);
                $userView->setUserOrganizationId($item['organization_id']);
                $userView->setUserOrganization($item['organization']);
                $userView->setPasswd($item['password']);
                $userView->setCompanyNm($item['company_nm']);
                $userView->setMail($item['mail']);
                $userView->setMobileMail($item['mobile_mail']);
                $userView->setAuthGroupId($item['auth_group_id']);
                $userView->setActivate($item['activate']);
                $userView->setAuthRank($item['auth_rank']);
                $userView->setIcalFile($item['ical_file']);
                //@add K.Arai(2008/04/14)
                $userView->setStoreId($item['store_id']);
                break;
            }
            return $userView;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * ユーザー・個人の登録／更新
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->user_cd
     * @param  $view->personal_id
     * @param  $view->*
     * @return integer
     */
    function saveUser(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId','userCd'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //論理チェック－１
            //新規登録時　ユーザーがすでに存在する場合、登録不可
            //更新時　　　ユーザーが自身以外でユーザーがすでに存在する場合、更新不可
            //--------------------------------------------------------------
            if ($this->_exists($view, 'user')) {
                return R_ERROR_DUPL;
            }

            //--------------------------------------------------------------
            //ユーザー情報取得
            //--------------------------------------------------------------
            $old = $somfa->retrieveByPK('tbm_user_info', array('user_company_id' => $view->getUserCompanyId(),
                                                               'user_cd'         => $view->getUserCd()));

            //--------------------------------------------------------------
            //ユーザー情報登録・更新用情報作成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id'] = $view->getUserCompanyId();
            $data['user_cd'] = $view->getUserCd();

            if (method_exists($view, 'getPasswd')) {
                if (!is_null($view->getPasswd())) {
                    if (AUTH_MAGIC_ENABLED){
                        $data['password'] = sha1($view->getPasswd() . ':' . AUTH_MAGIC);
                    }
                    else {
                        $data['password'] = $view->getPasswd();
                    }
                }
            }
            if (method_exists($view, 'getMail')) {
                if (!is_null($view->getMail())) {
                    $data['mail'] = $view->getMail();
                }
            }
            if (method_exists($view, 'getAuthGroupId')) {
                if (!is_null($view->getAuthGroupId())) {
                    $data['auth_group_id'] = $view->getAuthGroupId();
                }
            }
            if (method_exists($view, 'getActivate')) {
                if (!is_null($view->getActivate())) {
                    $data['activate'] = $view->getActivate();
                }
            }
            $data['del_flg']     = DB_ENABLE;
            $data['add_date']    = is_array($old)?$old['add_date']:xbUtil::getTimestamp();
            $data['add_pgid']    = is_array($old)?$old['add_pgid']:__METHOD__;
            $data['add_user_cd'] = is_array($old)?$old['add_user_cd']:$view->getLogonUserCd();
            $data['upd_date']    = xbUtil::getTimestamp();
            $data['upd_pgid']    = __METHOD__;
            $data['upd_user_cd'] = $view->getLogonUserCd();

            if (method_exists($view, 'getMail')) {
                //--------------------------------------------------------------
                //メール情報取得
                //--------------------------------------------------------------
                $old_mail = $somfa->retrieveByPK('tbm_mail', array('user_company_id' => $view->getUserCompanyId(),
                                                                   'mail'            => $view->getMail()));
                //--------------------------------------------------------------
                //メール情報登録・更新用情報作成
                //--------------------------------------------------------------
                $mail = array();
                $mail['user_company_id'] = $view->getUserCompanyId();
                $mail['mail']          = $view->getMail();
                $mail['auth_user']     = $view->getAuthUser();
                $mail['auth_password'] = $view->getAuthPass();
                $mail['auth_method']   = $view->getAuthMethod();
                $mail['del_flg']       = DB_ENABLE;
                $mail['add_date']      = is_array($old_mail)?$old_mail['add_date']:xbUtil::getTimestamp();
                $mail['add_pgid']      = is_array($old_mail)?$old_mail['add_pgid']:__METHOD__;
                $mail['add_user_cd']   = is_array($old_mail)?$old_mail['add_user_cd']:$view->getLogonUserCd();
                $mail['upd_date']      = xbUtil::getTimestamp();
                $mail['upd_pgid']      = __METHOD__;
                $mail['upd_user_cd']   = $view->getLogonUserCd();
            }

            $somfa->begin();

            $ret = null;

            //--------------------------------------------------------------
            //個人の登録／更新
            //--------------------------------------------------------------
            $results = $this->_savePersonal($view);
            if (!($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE)) {
                if ($results == R_ERROR_DUPL) {
                    $results = R_ERROR_DUPL_MAIL;
                }
                return $results;
            }
            //個人IDをセット（個人IDは個人登録後に取得すること）
            $data['personal_id'] = $view->getPersonalId();

            //--------------------------------------------------------------
            //更新前のユーザー情報取得 (key:personal_id)
            //--------------------------------------------------------------
            $old_user_personal = $somfa->retrieveByLK('tbm_user_info', array('user_company_id' => $view->getUserCompanyId(),
                                                                             'personal_id'     => $view->getPersonalId()));
            if(is_array($old_user_personal) && $old_user_personal['user_cd'] != $view->getUserCd()){
                //--------------------------------------------------------------
                //更新前のユーザーの削除
                //--------------------------------------------------------------
                $del_user = array();
                $del_user['user_company_id'] = $view->getUserCompanyId();
                $del_user['user_cd']         = $old_user_personal['user_cd'];
                $result = $somfa->delete('tbm_user_info', $del_user);
                $update_flg = true;

                //データの引継ぎ
                $data['password'] = (isNULL($data['password']))?$old_user_personal['password']:$data['password'];
                $data['auth_group_id'] = (isNULL($data['auth_group_id']))?$old_user_personal['auth_group_id']:$data['auth_group_id'];
                $data['activate'] = (isNULL($data['activate']))?$old_user_personal['activate']:$data['activate'];
                $data['add_date'] = (isNULL($data['add_date']))?$old_user_personal['add_date']:$data['add_date'];
                $data['add_pgid'] = (isNULL($data['add_pgid']))?$old_user_personal['add_pgid']:$data['add_pgid'];
                $data['add_user_cd'] = (isNULL($data['add_user_cd']))?$old_user_personal['add_user_cd']:$data['add_user_cd'];
            }

            //--------------------------------------------------------------
            //登録／更新実行
            //--------------------------------------------------------------
            $results = $somfa->save('tbm_user_info', $data);
            $ret = ($update_flg)?R_SUCCESS_UPDATE:$results;
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                if (method_exists($view, 'getMail')) {
                    $results = $somfa->save('tbm_mail', $mail);
                    if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                        $somfa->commit();
                    }
                    else {
                        throw new xbpwException(E_USER_ERROR, E_DB_99);
                    }
                }
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }

            if ($old['del_flg'] == 1) {
                $ret = R_SUCCESS_INSERT;
            }
            return $ret;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     *  ゲストユーザーの更新　外部システムより使用【EC-CUBE連携専用】
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->mail
     * @param  $view->password
     * @param  $view->*
     * @return integer
     */
    public function updateUserGuestForEcCubeRelation(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            $tmpUser = clone($view);

            //--------------------------------------------------------------
            //ゲスト情報を取得
            //--------------------------------------------------------------
            $tmpUser = $this->getUser($tmpUser);
            $view->setPersonalId($tmpUser->getPersonalId());
            if (xbUtil::isNULL($view->getPasswd())) {
                $view->setPasswd($tmpUser->getPasswd());
            }
            else {
                if (AUTH_MAGIC_ENABLED) {
                    $view->setPasswd(sha1($view->getPasswd() . ':' . AUTH_MAGIC));
                }
            }

            $somfa->begin();

            if( $view->getUserCd() != $view->getMail()){
                $sql = "delete from tbm_user_info where user_cd = '" . $view->getUserCd() . "'";
                $somfa->execute($sql);

                $sql = "insert into tbm_user_info(user_company_id,user_cd,password,mail,auth_group_id,personal_id,add_date,upd_date,add_pgid,upd_pgid,add_user_cd,upd_user_cd) values ( ";
                $sql.= "'" . $view->getUserCompanyId() . "',";
                $sql.= "'" . $view->getMail() . "',";
                $sql.= "'" . $view->getPasswd() . "',";
                $sql.= "'" . $view->getMail() . "',";
                $sql.= "'" . $view->getAuthGroupId() . "',";
                $sql.= "'" . $view->getPersonalId() . "',";
                $sql.= "'" . xbUtil::getTimestamp() . "',";
                $sql.= "'" . xbUtil::getTimestamp() . "',";
                $sql.= "'" . __METHOD__ . "',";
                $sql.= "'" . __METHOD__ . "',";
                $sql.= "'" . $view->getLogonUserCd() . "',";
                $sql.= "'" . $view->getLogonUserCd() . "' ";
                $sql.= ")";
                $somfa->execute($sql);
            }
            else{
                $sql = "update tbm_user_info ";
                $sql.= "set password    = '" . $view->getPasswd() . "', ";
                $sql.= "    upd_date    = '" . xbUtil::getTimestamp() . "',";
                $sql.= "    upd_pgid    = '" . __METHOD__ . "',";
                $sql.= "    upd_user_cd = '" . $view->getLogonUserCd() . "' ";
                $sql.= "where user_cd = '" . $view->getUserCd() . "'";
                $somfa->execute($sql);
            }

            $somfa->commit();

            return $view;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * ユーザー削除
     *
     * @param  $view->user_company_id
     * @param  $view->user_cd
     * @return integer
     */
    function deleteUser(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId', 'userCd'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //ユーザー削除用情報生成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id'] = $view->getUserCompanyId();
            $data['user_cd']         = $view->getUserCd();
            $data['del_flg']         = DB_DELETE;
            $data['upd_date']        = xbUtil::getTimestamp();
            $data['upd_pgid']        = __METHOD__;
            $data['upd_user_cd']     = $view->getLogonUserCd();

            //--------------------------------------------------------------
            //ユーザー削除実行
            //--------------------------------------------------------------
            $somfa->begin();
            $results = $somfa->save('tbm_user_info', $data);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * ユーザーリスト削除
     *
     * @access public
     * @param  $view->userListDetailView
     * @return integer
     */
    public function deleteUserList(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try{

            //--------------------------------------------------------------
            //ユーザー一括削除
            //--------------------------------------------------------------
            $detailView = $view->getUserListDetailView();
            $delCount   = 0;

            $somfa->begin();
            foreach($detailView as $v) {
                $delChk = $v->getChecked();
                if($delChk == '1') {
                    //--------------------------------------------------------------
                    //ユーザー削除
                    //--------------------------------------------------------------
                    $this->deleteUser($v);
                    $delCount++;
                }
            }
            $somfa->commit();

            if ($delCount == 0) {
                return R_SUCCESS;
            } else {
                return R_SUCCESS_DELETE;
            }
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * ユーザー承認・未承認
     *
     * @param  $view->user_company_id
     * @param  $view->user_cd
     * @param  $view->activate
     * @return integer
     */
    function activateUser(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId', 'userCd'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //ユーザー削除用情報生成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id'] = $view->getUserCompanyId();
            $data['user_cd']         = $view->getUserCd();
            $data['activate']        = $view->getActivate();
            $data['upd_date']        = xbUtil::getTimestamp();
            $data['upd_pgid']        = __METHOD__;
            $data['upd_user_cd']     = $view->getLogonUserCd();

            //--------------------------------------------------------------
            //ユーザー認証実行
            //--------------------------------------------------------------
            $somfa->begin();
            $results = $somfa->save('tbm_user_info', $data);
            if ($results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * ユーザリスト
     *
     * @param  $view->user_company_id
     * @data   $view->[]
     * @return integer
     */
    public function createUserList(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try{

            //--------------------------------------------------------------
            //ユーザー検索
            //--------------------------------------------------------------
            $rs = $somfa->select('tbv_user_info', 'user_cd, personal_nm',
                                 "user_company_id = ? and user_cd is not null and auth_group_id <>'99' ",
                                 array($view->getUserCompanyId()),
                                 'personal_nm');

            $user_list = array();
            foreach ($rs as $item) {
                $user_list[$item['user_cd']] = $item['personal_nm'];
            }
            $view->setUserList($user_list);

            return $view;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

}
?>
