<?php
/**
 * 個人 Service component.
 *
 * 個人component処理を行います
 *
 * PHP versions 5
 *
 * @package     PersonalService
 * @author      liuCheng<liuch@mail.csoft.com.cn> 2006年3月29日
 *              Shiro Tajima <tajima@exbridge.jp> 2007年11月23日 somfa対応
 * @copyright   2006-2007 EXBRIDGE,Inc. All Rights Reserved.
 * @version     SVN : $Id
 * @link        http://exbridge.jp/
 * @see         なし
 */
class PersonalService extends xbService {

    /**
     * 個人一覧検索条件構築
     *
     * @access private
     * @param  $view->user_company_id
     * @param  $view->frigana
     * @param  $view->search_condision
     * @data   $keys
     * @data   $vals
     * @data   $ords
     * @return integer
     */
    private function _createCriteria(& $view, & $keys, & $vals, & $ords) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        try {

            $_keys = array();
            $_vals = array();

            $_keys_az = array();
            $_vals_az = array();

            $_keys_ot  = array();
            $_vals_ot = array();


            //利用会社ID
            $_keys[] = 'user_company_id = ? ';
            $_vals[] = $view->getUserCompanyId();

            //フリガナ条件作成
            $furigana = $view->getFrigana();
            $scon     = $view->getSearchCondision();
            $cnt      = count($scon);
            for ($i=0; $i<$cnt; $i++) {
                //katakana 'ソ'対応
                $tmp = rtrim($scon[$i], ' ');
                if (ccmIDs::NMFAZ == $furigana) {
                    $_keys_az[] = 'personal_kn not like ? ';
                    $_vals_az[] = '%' . $tmp . '%';
                }
                else {
                    $_keys_ot[] = 'personal_kn like ? ';
                    $_vals_ot[] = '%' . $tmp . '%';
                }
            }

            if (ccmIDs::NMFAZ == $furigana) {
                $_keys[] = " ((" . implode(" and ", $_keys_az) . ") or (personal_kn is null)) ";
                $_vals = array_merge($_vals, $_vals_az);
            }
            else {
                $_keys[] = " (" . implode(" or ", $_keys_ot) . ") ";
                $_vals = array_merge($_vals, $_vals_ot);
            }

            $keys = implode(" and ", $_keys);
            $vals = $_vals;
            $ords = 'personal_kn, personal_nm, personal_id';

            return R_SUCCESS;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人検索条件構築
     *
     * @access private
     * @param  $view->user_company_id
     * @param  $view->personal_nm
     * @param  $view->personal_kn
     * @param  $view->personal_tel
     * @param  $view->mobile
     * @param  $view->personal_address
     * @data   $keys
     * @data   $vals
     * @data   $ords
     * @return integer
     */
    private function _createCriteriaSearch(& $view, & $keys, & $vals, & $ords) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        try {

            $_keys = array();
            $_vals = array();

            //利用会社ID
            $_keys[] = 'user_company_id = ? ';
            $_vals[] = $view->getUserCompanyId();

            //個人名称
            if (!xbUtil::isNULL($view->getPersonalNm())) {
                $_keys[] = 'personal_nm like ? ';
                $_vals[] = '%' . $view->getPersonalNm() . '%';
            }

            //個人名かな
            if (!xbUtil::isNULL($view->getPersonalKn())) {
                $_keys[] = 'personal_kn like ? ';
                $_vals[] = '%' . $view->getPersonalKn() . '%';
            }

            //メールアドレス
            if (!xbUtil::isNULL($view->getMail())) {
                $_keys[] = 'mail like ? ';
                $_vals[] = '%' . $view->getMail() . '%';
            }

            //電話番号
            $personal_tel   = $view->getPersonalTel();
            //携帯電話
            $mobile_tel     = $view->getMobile();

            if (!xbUtil::isNULL($personal_tel) || !xbUtil::isNULL($mobile_tel)) {
                $tmp_keys = array();
                if(!xbUtil::isNULL($personal_tel)) {
                    $tmp_keys[] = 'personal_tel like ? ';
                    $_vals[] = '%' . $view->getPersonalTel() . '%';
                }
                if(!xbUtil::isNULL($mobile_tel)) {
                    $tmp_keys[] = 'mobile like ? ';
                    $_vals[] = '%' . $view->getMobile() . '%';
                }
                $_keys[] = '(' . implode(" or ", $tmp_keys) . ')';
            }

            //会社名
            if (method_exists($view, 'getCompanyNm')) {
                if (!xbUtil::isNULL($view->getCompanyNm())) {
                    $_keys[] = 'company_nm like ? ';
                    $_vals[] = '%' . $view->getCompanyNm() . '%';
                }
            }

            //住所
            if (!xbUtil::isNULL($view->getPersonalAddress())) {
                $_keys[] = ' personal_address1 like ? or personal_address2 like ? or personal_address3 like ? or personal_address4 like ?) ';
                $_vals[] = '%' . $view->getPersonalAddress() . '%';
                $_vals[] = '%' . $view->getPersonalAddress() . '%';
                $_vals[] = '%' . $view->getPersonalAddress() . '%';
                $_vals[] = '%' . $view->getPersonalAddress() . '%';
            }

            $keys = implode(" and ", $_keys);
            $vals = $_vals;
            $ords = 'personal_kn, personal_nm, personal_id';

            return R_SUCCESS;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人一覧リスト作成
     *
     * @access private
     * @param  $rs
     * @param  $view
     * @return $view
     */
    private function _createPersonalList(& $rs, & $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        try {

            //--------------------------------------------------------------
            //一覧取得
            //--------------------------------------------------------------
            $detailArray = array();
            foreach ($rs as $item) {
                $personalListDetailView = PersonalListDetailView::getInstance();
                $personalListDetailView->setPersonalId($item['personal_id']);
                $personalListDetailView->setPersonalNm($item['personal_nm']);
                $personalListDetailView->setPersonalKn($item['personal_kn']);
                $personalListDetailView->setUrl($item['url']);
                $personalListDetailView->setZipcode($item['personal_zipcode']);
                $personalListDetailView->setAddress($item['personal_address1'] . $item['personal_address2'] . $item['personal_address3'] . $item['personal_address4']);
                $personalListDetailView->setAddress1($item['personal_address1']);
                $personalListDetailView->setAddress2($item['personal_address2']);
                $personalListDetailView->setAddress3($item['personal_address3']);
                $personalListDetailView->setAddress4($item['personal_address4']);
                $personalListDetailView->setTel($item['personal_tel']);
                $personalListDetailView->setMobile($item['personal_mobile']);
                $personalListDetailView->setMail($item['mail']);
                $personalListDetailView->setCompanyId($item['company_id']);
                $personalListDetailView->setCompanyNm($item['company_nm']);
                $personalListDetailView->setOrganizationId($item['organization_id']);
                $personalListDetailView->setOrganization($item['organization']);
                $personalListDetailView->setOfficialId($item['official_id']);
                $personalListDetailView->setOfficialNm($item['official_nm']);
                $personalListDetailView->setTelIn($item['tel_in']);
                $personalListDetailView->setOfficeMail($item['official_mail']);
                $personalListDetailView->setOfficeZipcode($item['company_zipcode']);
                $personalListDetailView->setOfficeAddress1($item['company_address1']);
                $personalListDetailView->setOfficeAddress2($item['company_address2']);
                $personalListDetailView->setOfficeAddress3($item['company_address3']);
                $personalListDetailView->setOfficeAddress4($item['company_address4']);
                $personalListDetailView->setBirthday($item['birthday']);
                $personalListDetailView->setIcalFile($item['ical_file']);
                $personalListDetailView->setUserCd($item['user_cd']);
                $personalListDetailView->setPassword($item['password']);
                $personalListDetailView->setAuthGroupId($item['auth_group_id']);
                $detailArray[$item['personal_id']] = $personalListDetailView;
            }
            $view->setPersonalListDetailView($detailArray);

            return $view;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人一覧取得
     *
     * @access public
     * @param  $view->user_company_id
     * 1 or 2 のパターン
     * @param  $view->frigana           - 1
     * @param  $view->search_condision  - 1
     * @param  $view->personal_nm       - 2
     * @param  $view->personal_kn       - 2
     * @param  $view->personal_tel      - 2
     * @param  $view->mobile            - 2
     * @param  $view->personal_address  - 2
     * @data   $view->data_list
     * @return $view
     */
    public function getPersonalList(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //条件設定
            //--------------------------------------------------------------
            $keys = null;
            $vals = null;
            $ords = null;
            if (method_exists($view, 'getSearchCondision')) {
                $this->_createCriteria($view, $keys, $vals, $ords);
            }
            else {
                $this->_createCriteriaSearch($view, $keys, $vals, $ords);
            }

            //追加条件
            if (method_exists($view, 'getFrom')) {
                switch ($view->getFrom()) {
                    case 'syain':
                        $keys = $keys . ' and staff_cd is null ';
                        break;
                    case 'uam_user':
                        $keys = $keys . ' and user_cd is null';
                        break;
                    case 'uam_userGuest':
                        $keys = $keys . ' and user_cd is null and staff_cd is null ';
                        break;
                }
            }

            //--------------------------------------------------------------
            //検索
            //--------------------------------------------------------------
            $page_id = $view->getPageId();

            $rs = $somfa->select('tbv_personal_info',
                                 '*',
                                 $keys,
                                 $vals,
                                 $ords,
                                 null,
                                 $page_id);

            $personalListView = $view;
            $personalListView->setPageId($page_id);
            $personalListView->setCount($somfa->count());
            $personalListView = $this->_createPersonalList( $rs, $personalListView );

            return $personalListView;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人一覧取得（自社以外の人）
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->personal_nm
     * @param  $view->personal_kn
     * @param  $view->personal_tel
     * @param  $view->mobile
     * @param  $view->personal_address
     * @data   $view->data_list
     * @return $view
     */
    public function getTantoPersonalList(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //条件設定
            //--------------------------------------------------------------
            $keys = null;
            $vals = null;
            $ords = null;
            $this->_createCriteriaSearch($view, $keys, $vals, $ords);

            //社員以外の人間（条件追加）
            $keys   = $keys . " and  ( company_id <> ? or company_id is null) ";
            $vals[] = $view->getUserCompanyId();

            //--------------------------------------------------------------
            //検索
            //--------------------------------------------------------------
            $page_id = $view->getPageId();

            $personal = $somfa->select('tbv_personal_info',
                                       '*',
                                       $keys,
                                       $vals,
                                       $ords,
                                       null,
                                       $page_id);

            $personalListView = $view;
            $personalListView->setPageId($page_id);
            $personalListView->setCount($somfa->count());
            $personalListView = $this->_createPersonalList( $personal, $personalListView );

            //--------------------------------------------------------------
            //すでに担当者として登録されている人間を除外
            //--------------------------------------------------------------
            $tanto = $somfa->select('tbv_tanto', '*',
                                    'user_company_id = ? ',
                                    array($view->getUserCompanyId()));

            $detailArray = $personalListView->getPersonalListDetailView();
            foreach ($tanto as $item) {
                unset($detailArray[$item['personal_id']]);
            }
            $personalListView->setPersonalListDetailView($detailArray);

            return $personalListView;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人取得
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @data   $view->*
     * @return $view
     */
    public function getPersonal(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //Viewのインスタンス化
            //--------------------------------------------------------------
            $personalBaseView    = $view;
            $personalHomeView    = PersonalHomeView::getInstance();
            $personalParentView  = PersonalParentView::getInstance();
            $personalEmployeeView= PersonalEmployeeView::getInstance();

            //--------------------------------------------------------------
            //個人情報取得
            //--------------------------------------------------------------
            $rs = $somfa->select('tbv_personal_info',
                                 '*',
                                 'user_company_id = ? and personal_id = ? ',
                                 array($view->getUserCompanyId(), $view->getPersonalId()));
            foreach ($rs as $item) {
                //BaseVeiwへの設定
                $personalBaseView->setCompanyId($item['company_id']);
                $personalBaseView->setPersonalId($item['personal_id']);
                $personalBaseView->setPersonalKn($item['personal_kn']);
                $personalBaseView->setPersonalNm($item['personal_nm']);
                $personalBaseView->setBloodtype($item['bloodtype']);
                $personalBaseView->setMail($item['mail']);
                $personalBaseView->setMobileMail($item['mobile_mail']);
                $personalBaseView->setUrl($item['url']);
                $personalBaseView->setEtc($item['etc']);
                $birth = $item['birthday'];
                $year  = substr($birth,0,4);
                $month = substr($birth,4,2);
                $day   = substr($birth,6,2);
                $personalBaseView->setBirthdayYear($year);
                $personalBaseView->setBirthdayMonth($month);
                $personalBaseView->setBirthdayDay($day);

                //HomeVeiwへの設定
                $personalHomeView->setPersonalId($item['personal_id']);
                $personalHomeView->setTel($item['personal_tel']);
                $personalHomeView->setFax($item['personal_fax']);
                $personalHomeView->setMobile($item['personal_mobile']);
                $personalHomeView->setZipcode($item['personal_zipcode']);
                $personalHomeView->setAddress1($item['personal_address1']);
                $personalHomeView->setAddress2($item['personal_address2']);
                $personalHomeView->setAddress3($item['personal_address3']);
                $personalHomeView->setAddress4($item['personal_address4']);

                //ParentVeiwへの設定
                $personalParentView->setPersonalId($item['personal_id']);
                $personalParentView->setTel($item['parent_tel']);
                $personalParentView->setFax($item['parent_fax']);
                $personalParentView->setMobile($item['parent_mobile']);
                $personalParentView->setZipcode($item['parent_zipcode']);
                $personalParentView->setAddress1($item['parent_address1']);
                $personalParentView->setAddress2($item['parent_address2']);
                $personalParentView->setAddress3($item['parent_address3']);
                $personalParentView->setAddress4($item['parent_address4']);

                //EmployeeViewへの設定
                $personalEmployeeView->setPersonalId($item['personal_id']);
                $personalEmployeeView->setCompanyId($item['company_id']);
                $personalEmployeeView->setCompanyNm($item['company_nm']);
                $personalEmployeeView->setStaffCd($item['staff_cd']);
                $personalEmployeeView->setOrganizationId($item['organization_id']);
                $personalEmployeeView->setOrganization($item['organization']);
                $personalEmployeeView->setOfficialId($item['official_id']);
                $personalEmployeeView->setOfficialNm($item['official_nm']);
                $personalEmployeeView->setMobile($item['mobile']);
                $personalEmployeeView->setTelIn($item['tel_in']);
                $personalEmployeeView->setEmpMail($item['office_mail']);
                $birth = $item['retire_dt'];
                $year  = substr($birth,0,4);
                $month = substr($birth,4,2);
                $day   = substr($birth,6,2);
                $personalEmployeeView->setRetireYear($year);
                $personalEmployeeView->setRetireMonth($month);
                $personalEmployeeView->setRetireDay($day);

                $enter = $item['enter_dt'];
                $year  = substr($enter,0,4);
                $month = substr($enter,4,2);
                $day   = substr($enter,6,2);
                $personalEmployeeView->setEnterYear($year);
                $personalEmployeeView->setEnterMonth($month);
                $personalEmployeeView->setEnterDay($day);

                break;
            }

            //--------------------------------------------------------------
            //デフォルト値設定
            //--------------------------------------------------------------
            if (xbUtil::isNULL($personalEmployeeView->getCompanyId())) {
                $rs = $somfa->select('tbv_company_info', '*',
                                     'user_company_id = ? and company_id = ? ',
                                     array($view->getUserCompanyId(), '1'));
                foreach ($rs as $item) {
                    $personalEmployeeView->setCompanyId($item['company_id']);
                    $personalEmployeeView->setCompanyNm($item['company_nm']);
                }
            }

            $personalBaseView->setHomeView($personalHomeView);
            $personalBaseView->setParentView($personalParentView);
            $personalBaseView->setEmployeeView($personalEmployeeView);
            return $personalBaseView;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人登録／更新
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @param  $view->*
     * @return integer
     */
    public function savePersonal(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //個人ＩＤ、個人メールアドレス
            //--------------------------------------------------------------
            $personal_id   = $view->getPersonalId();
            $personal_mail = $view->getMail();

            //--------------------------------------------------------------
            //View取得
            //--------------------------------------------------------------
            $homeView     = $view->getHomeView();
            $parentView   = $view->getParentView();
            $employeeView = $view->getEmployeeView();
            
            //ユーザーサービスから利用される場合は$employeeViewがnull
            if (method_exists($employeeView, 'getEmpMail')) {
                $office_mail = $employeeView->getEmpMail();
            }

            //--------------------------------------------------------------
            //論理チェック
            //新規登録時　個人または会社メールアドレスがすでに存在する場合、登録不可
            //更新時　　　個人ＩＤが自身以外で個人または会社メールアドレスがすでに存在する場合、更新不可
            //--------------------------------------------------------------
            if (xbUtil::isNULL($personal_id)) {
                if (xbUtil::isNULL($personal_mail) && xbUtil::isNULL($office_mail)) {
                    $rs = array();
                }
                else if (!xbUtil::isNULL($personal_mail) && !xbUtil::isNULL($office_mail)) {
                    $rs = $somfa->select( 'tbv_personal_info', '*',
                                          '(mail = ? or mail = ? or office_mail = ? or office_mail = ?) ',
                                          array($personal_mail, $office_mail, $personal_mail, $office_mail));
                }
                else if (xbUtil::isNULL($personal_mail)) {
                    $rs = $somfa->select( 'tbv_personal_info', '*',
                                          '(mail = ? or office_mail = ?) ',
                                          array($office_mail, $office_mail));
                }
                else if (xbUtil::isNULL($office_mail)) {
                    $rs = $somfa->select( 'tbv_personal_info', '*',
                                          '(mail = ? or office_mail = ?) ',
                                          array($personal_mail, $personal_mail));
                }
            }
            else {
                if (xbUtil::isNULL($personal_mail) && xbUtil::isNULL($office_mail)) {
                    $rs = array();
                }
                else if (!xbUtil::isNULL($personal_mail) && !xbUtil::isNULL($office_mail)) {
                    $rs = $somfa->select( 'tbv_personal_info', '*',
                                          'personal_id <> ? and (mail = ? or mail = ? or office_mail = ? or office_mail = ?) ',
                                          array($personal_id, $personal_mail, $office_mail, $personal_mail, $office_mail));
                }
                else if (xbUtil::isNULL($personal_mail)) {
                    $rs = $somfa->select( 'tbv_personal_info', '*',
                                          'personal_id <> ? and (mail = ? or office_mail = ?) ',
                                          array($personal_id, $office_mail, $office_mail));
                }
                else if (xbUtil::isNULL($office_mail)) {
                    $rs = $somfa->select( 'tbv_personal_info', '*',
                                          'personal_id <> ? and (mail = ? or office_mail = ?) ',
                                          array($personal_id, $personal_mail, $personal_mail));
                }
            }
            if (is_array($rs)) {
                if(count($rs) > 0) {
                    $view->setPersonalId($rs[0]['personal_id']);
                    return R_ERROR_DUPL;
                }
            }

            //--------------------------------------------------------------
            //自動採番
            //--------------------------------------------------------------
            if (xbUtil::isNULL($personal_id)) {
                $view->setPersonalId($this->generateId(TBMPERSONALBASE_ID));
                $homeView->setPersonalId($view->getPersonalId());
                $parentView->setPersonalId($view->getPersonalId());
                if (method_exists($employeeView, 'getPersonalId')) {
                    $employeeView->setPersonalId($view->getPersonalId());
                }
            }

            //--------------------------------------------------------------
            //登録実行
            //--------------------------------------------------------------
            $somfa->begin();
            //tbm_personal_base

            $results = $this->_savePersonalBase($view);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                //tbm_personal_address
                $results = $this->_savePersonalHomeAddress($homeView);
                if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                    //tbm_parentl_address
                    $results = $this->_savePersonalParentAddress($parentView);
                    if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                        if (method_exists($employeeView, 'getCompanyId')) {
                            $companyId = $employeeView->getCompanyId();
                        }
                        //会社IDが存在する場合
                        if(!xbUtil::isNULL($companyId)){
                            $results = $this->_savePersonalEmployee($employeeView);
                            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                                $somfa->commit();
                            }
                        }
                        else{
                            $somfa->commit();
                        }
                    }
                }
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人リスト削除
     *
     * @access public
     * @param  $view->personalListDetailView
     * @return integer
     */
    public function deletePersonalList(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //削除実行
            //--------------------------------------------------------------
            $detailView = $view->getPersonalListDetailView();
            $detailCnt  = count($detailView);
            $delCount   = 0;

            $somfa->begin();
            foreach ($detailView as $v) {
                //削除チェック取得
                $delChk = $v->getChecked();
                if ($delChk == '1') {
                    //削除実行
                    $this->deletePersonalBase($v);
                    $delCount++;
                }
            }
            $somfa->commit();

            if ($delCount == 0) {
                return R_SUCCESS;
            } else {
                return R_SUCCESS_DELETE;
            }
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人基本登録
     *
     * @access private
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @param  $view->*
     * @return integer
     */
    private function _savePersonalBase(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if(!$this->assert(array('userCompanyId', 'personalId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //マスタ情報取得
            //--------------------------------------------------------------
            $old = $somfa->retrieveByPK('tbm_personal_base',
                                        array('user_company_id' => $view->getUserCompanyId(),
                                              'personal_id'     => $view->getPersonalId()));

            //--------------------------------------------------------------
            //登録用情報生成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id'] = $view->getUserCompanyId();
            $data['personal_id'] = $view->getPersonalId();
            if (method_exists($view, 'getPersonalNm')) {
                $data['personal_nm'] = $view->getPersonalNm();
            }
            if (method_exists($view, 'getPersonalKn')) {
                $data['personal_kn'] = $view->getPersonalKn();
            }
            if (method_exists($view, 'getBirthdayYear')) {
                $data['birthday'] = $view->getBirthdayYear() . $view->getBirthdayMonth() . $view->getBirthdayDay();
            }
            if (method_exists($view, 'getBloodtype')) {
                $data['bloodtype'] = $view->getBloodtype();
            }
            if (method_exists($view, 'getMail')) {
                $data['mail'] = $view->getMail();
            }
            if (method_exists($view, 'getSex')) {
                $data['sex'] = $view->getSex();
            }
            if (method_exists($view, 'getMobileMail')) {
                $data['mobile_mail'] = $view->getMobileMail();
            }
            if (method_exists($view, 'getUrl')) {
                $data['url'] = $view->getUrl();
            }
            if (method_exists($view, 'getEtc')) {
                $data['etc'] = $view->getEtc();
            }
            if (method_exists($view, 'getIcalFile')) {
                $data['ical_file'] = $view->getIcalFile();
            }
            $data['del_flg']     = DB_ENABLE;
            $data['add_date']    = is_array($old)?$old['add_date']:xbUtil::getTimestamp();
            $data['add_pgid']    = is_array($old)?$old['add_pgid']:__METHOD__;
            $data['add_user_cd'] = is_array($old)?$old['add_user_cd']:$view->getLogonUserCd();
            $data['upd_date']    = xbUtil::getTimestamp();
            $data['upd_pgid']    = __METHOD__;
            $data['upd_user_cd'] = $view->getLogonUserCd();

            //--------------------------------------------------------------
            //登録／更新実行
            //--------------------------------------------------------------
            $somfa->begin();
            $results = $somfa->save('tbm_personal_base', $data);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人削除
     *
     * @access private
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @return integer
     */
    public function deletePersonalBase(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId', 'personalId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //削除用情報生成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id'] = $view->getUserCompanyId();
            $data['personal_id']     = $view->getPersonalId();
            $data['del_flg']         = DB_DELETE;
            $data['upd_date']        = xbUtil::getTimestamp();
            $data['upd_pgid']        = __METHOD__;
            $data['upd_user_cd']     = $view->getLogonUserCd();

            //--------------------------------------------------------------
            //削除実行
            //--------------------------------------------------------------
            $somfa->begin();
            $results = $somfa->save('tbm_personal_base', $data);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人自宅登録
     *
     * @access private
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @param  $view->*
     * @return integer
     */
    private function _savePersonalHomeAddress(& $view) {

        xbLog::logger(xbLog :: DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId', 'personalId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //登録用情報生成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id'] = $view->getUserCompanyId();
            $data['personal_id'] = $view->getPersonalId();
            if (method_exists($view, 'getTel')) {
                $data['tel'] = $view->getTel();
            }
            if (method_exists($view, 'getFax')) {
                $data['fax'] = $view->getFax();
            }
            if (method_exists($view, 'getMobile')) {
                $data['mobile'] = $view->getMobile();
            }
            if (method_exists($view, 'getZipcode')) {
                $data['zipcode'] = $view->getZipcode();
            }
            if (method_exists($view, 'getAddress1')) {
                $data['address1'] = $view->getAddress1();
            }
            if (method_exists($view, 'getAddress2')) {
                $data['address2'] = $view->getAddress2();
            }
            if (method_exists($view, 'getAddress3')) {
                $data['address3'] = $view->getAddress3();
            }
            if (method_exists($view, 'getAddress4')) {
                $data['address4'] = $view->getAddress4();
            }

            //--------------------------------------------------------------
            //登録／更新実行
            //--------------------------------------------------------------
            $somfa->begin();
            $results = $somfa->save('tbm_personal_address', $data);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人実家登録
     *
     * @access private
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @param  $view->*
     * @return integer
     */
    private function _savePersonalParentAddress(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId', 'personalId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //登録用情報生成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id'] = $view->getUserCompanyId();
            $data['personal_id'] = $view->getPersonalId();
            if (method_exists($view, 'getTel')) {
                $data['tel'] = $view->getTel();
            }
            if (method_exists($view, 'getFax')) {
                $data['fax'] = $view->getFax();
            }
            if (method_exists($view, 'getMobile')) {
                $data['mobile'] = $view->getMobile();
            }
            if (method_exists($view, 'getZipcode')) {
                $data['zipcode'] = $view->getZipcode();
            }
            if (method_exists($view, 'getAddress1')) {
                $data['address1'] = $view->getAddress1();
            }
            if (method_exists($view, 'getAddress2')) {
                $data['address2'] = $view->getAddress2();
            }
            if (method_exists($view, 'getAddress3')) {
                $data['address3'] = $view->getAddress3();
            }
            if (method_exists($view, 'getAddress4')) {
                $data['address4'] = $view->getAddress4();
            }

            //--------------------------------------------------------------
            //登録／更新実行
            //--------------------------------------------------------------
            $somfa->begin();
            $results = $somfa->save('tbm_parent_address', $data);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 社員属性登録
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @param  $view->*
     * @return integer
     */
    public function _savePersonalEmployee(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId', 'personalId', 'companyId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //--------------------------------------------------------------
            //登録用情報生成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id'] = $view->getUserCompanyId();
            $data['personal_id'] = $view->getPersonalId();
            $data['company_id'] = $view->getCompanyId();
            if (method_exists($view, 'getStaffCd')) {
                $data['staff_cd'] = $view->getStaffCd();
            }
            if (method_exists($view, 'getOrganizationId')) {
                $data['organization_id'] = $view->getOrganizationId();
            }
            if (method_exists($view, 'getOfficialId')) {
                $data['official_id'] = $view->getOfficialId();
            }
            if (method_exists($view, 'getMobile')) {
                $data['mobile'] = $view->getMobile();
            }
            if (method_exists($view, 'getTelIn')) {
                $data['tel_in'] = $view->getTelIn();
            }
            if (method_exists($view, 'getEmpMail')) {
                $data['mail'] = $view->getEmpMail();
            }
            if (method_exists($view, 'getRetireYear')) {
                if (!xbUtil::isNULL($view->getRetireYear())) {
                    $data['retire_dt'] = $view->getRetireYear() . $view->getRetireMonth() . $view->getRetireDay();
                }else{
                    $data['retire_dt'] = "NULL";
                }
            }
            if (method_exists($view, 'getEnterYear')) {
                if (!xbUtil::isNULL($view->getEnterYear())) {
                    $data['enter_dt'] = $view->getEnterYear() . $view->getEnterMonth() . $view->getEnterDay();
                }else{
                    $data['enter_dt'] = "NULL";
                }
            }


            $data['del_flg']     = DB_ENABLE;
            $data['add_date']    = xbUtil::getTimestamp();
            $data['add_pgid']    = __METHOD__;

            //--------------------------------------------------------------
            //登録／更新実行
            //--------------------------------------------------------------
            $somfa->begin();
            $results = $somfa->save('tbm_employee_property', $data);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人リクルート情報取得
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @data   $view->*
     * @return $view
     */
    public function getPersonalRecruit(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId', 'personalId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //個人情報取得
            //--------------------------------------------------------------
            $rs = $somfa->select('tbv_personal_recruit',
                                 '*',
                                 'user_company_id = ? and personal_id = ? ',
                                 array($view->getUserCompanyId(), $view->getPersonalId()));
            foreach ($rs as $item) {
                $view->setPersonalNm($item['personal_nm']);
                $view->setPersonalKn($item['personal_kn']);
                $view->setMail($item['mail']);
                $view->setMobileMail($item['mobile_mail']);
                $view->setSex($item['sex']);
                $view->setSexNm($item['sex_nm']);
                $view->setTel($item['tel']);
                $view->setFax($item['fax']);
                $view->setMobile($item['mobile']);
                $view->setZipcode($item['zipcode']);
                $view->setAddress1($item['address1']);
                $view->setAddress2($item['address2']);
                $view->setAddress3($item['address3']);
                $view->setAddress4($item['address4']);
                $view->setRequestArea($item['request_area']);
                $view->setWorkArea($item['work_area']);
                $view->setTransportationKb($item['transportation_kb']);
                $view->setTransportationKbNm($item['transportation_kb_nm']);

                $birth_year;
                $birth_month;
                $birth_day;
                $birth = $item['birthday'];
                if(strlen($birth)>=8){
                    $birth_year  = substr($birth,0,4);
                    $birth_month = substr($birth,4,2);
                    $birth_day   = substr($birth,6,2);
                }
                $view->setBirthdayYear($birth_year);
                $view->setBirthdayMonth($birth_month);
                $view->setBirthdayDay($birth_day);

                $start_year;
                $start_month;
                $start_day;
                $start_dt   = $item['start_dt'];
                if(strlen($start_dt)>=8){
                    $start_year       = substr($start_dt,0,4);
                    $start_month      = substr($start_dt,4,2);
                    $start_day        = substr($start_dt,6,2);
                }
                $view->setStartDtYear($start_year);
                $view->setStartDtMonth($start_month);
                $view->setStartDtDay($start_day);
                $view->setMediumKb($item['medium_kb']);
                $view->setMediumKbNm($item['medium_kb_nm']);
                $view->setStoreId($item['store_id']);
                $view->setStoreNm($item['store_nm']);
                $view->setEmployKb($item['employ_kb']);
                $view->setEmployKbNm($item['employ_kb_nm']);
                $view->setStaffCd($item['staff_cd']);
                $view->setQrId($item['qr_id']);
                $view->setBiko($item['biko']);
                $view->setAddDate($item['add_date']);
                $view->setRecruitKb($item['recruit_kb']);
                $view->setRecruitKbNm($item['recruit_kb_nm']);
                $view->setRecruitBiko($item['recruit_biko']);
                $view->setSchoolNm($item['school_nm']);
                $view->setBunruiId($item['bunrui_id']);
                $view->setBunruiNm($item['bunrui_nm']);
                $view->setEducationalBackgroundKb($item['educational_background_kb']);
                $view->setEducationalBackgroundKbNm($item['educational_background_kb_nm']);
                break;
            }

            return R_SUCCESS;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人リクルート情報一覧取得
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @data   $view->*
     * @return $view
     */
    public function getPersonalRecruitList(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //条件設定
            //--------------------------------------------------------------
            $keys = null;
            $vals = null;
            $ords = null;
            $this->_createCriteriaSearch($view, $keys, $vals, $ords);

            if (!xbUtil::isNULL($view->getStoreId())) {
                $tmp_store_id = $view->getStoreId();
                if($tmp_store_id == -1) {
                    $keys   = $keys . ' and store_id is not null ';
                }
                else {
                    $keys   = $keys . ' and store_id = ? ';
                    $vals[] = $tmp_store_id;
                }
            }
            if (!xbUtil::isNULL($view->getQrId())) {
                $tmp_qr_id = $view->getQrId();
                if($tmp_qr_id == -1) {
                    $keys   = $keys . ' and qr_id is not null ';
                }
                else {
                    $keys   = $keys . ' and qr_id = ? ';
                    $vals[] = $view->getQrId();
                }
            }

            //採用区分（条件追加）
            if (!xbUtil::isNULL($view->getEmployKb()) || count($view->getEmployKb()) > 0) {
                $employ_kb_list = $view->getEmployKb();
                foreach ($employ_kb_list as $employ_kb) {
                    $tmp_key_list[] = "employ_kb = ?";
                    $vals[] = $employ_kb;
                }
                $keys   = $keys . 'and (' . implode(' or ', $tmp_key_list) . ') ';
            }

            //--------------------------------------------------------------
            //検索 @todo add_dateでソートしているが応募日でソートするように変更
            //--------------------------------------------------------------
            $page_id = $view->getPageId();

            $rs = $somfa->select('tbv_personal_recruit',
                                       '*',
                                       $keys,
                                       $vals,
                                       'add_date',
                                       null,
                                       $page_id);

            $view->setCount($somfa->count());
            $recruit_list = array();
            foreach ($rs as $item) {
                $PersonalRecruitView = PersonalRecruitView::getInstance();
                $PersonalRecruitView->setPersonalId($item['personal_id']);
                $PersonalRecruitView->setPersonalNm($item['personal_nm']);
                $PersonalRecruitView->setPersonalKn($item['personal_kn']);
                $PersonalRecruitView->setMail($item['mail']);
                $PersonalRecruitView->setMobileMail($item['mobile_mail']);
                $PersonalRecruitView->setSex($item['sex']);
                $PersonalRecruitView->setSexNm($item['sex_nm']);
                $PersonalRecruitView->setTel($item['tel']);
                $PersonalRecruitView->setFax($item['fax']);
                $PersonalRecruitView->setMobile($item['mobile']);
                $PersonalRecruitView->setZipcode($item['zipcode']);
                $PersonalRecruitView->setAddress1($item['address1']);
                $PersonalRecruitView->setAddress2($item['address2']);
                $PersonalRecruitView->setAddress3($item['address3']);
                $PersonalRecruitView->setAddress4($item['address4']);
                $PersonalRecruitView->setRequestArea($item['request_area']);
                $PersonalRecruitView->setWorkArea($item['work_area']);
                $PersonalRecruitView->setTransportationKb($item['transportation_kb']);
                $PersonalRecruitView->setTransportationKbNm($item['transportation_kb_nm']);

                $birth_year;
                $birth_month;
                $birth_day;
                $birth = $item['birthday'];
                if(strlen($birth)>=8){
                    $birth_year  = substr($birth,0,4);
                    $birth_month = substr($birth,4,2);
                    $birth_day   = substr($birth,6,2);
                }
                $PersonalRecruitView->setBirthdayYear($birth_year);
                $PersonalRecruitView->setBirthdayMonth($birth_month);
                $PersonalRecruitView->setBirthdayDay($birth_day);

                $start_year;
                $start_month;
                $start_day;
                $start_dt   = $item['start_dt'];
                if(strlen($start_dt)>=8){
                    $start_year       = substr($start_dt,0,4);
                    $start_month      = substr($start_dt,4,2);
                    $start_day        = substr($start_dt,6,2);
                }
                $PersonalRecruitView->setStartDtYear($start_year);
                $PersonalRecruitView->setStartDtMonth($start_month);
                $PersonalRecruitView->setStartDtDay($start_day);
                $PersonalRecruitView->setMediumKb($item['medium_kb']);
                $PersonalRecruitView->setMediumKbNm($item['medium_kb_nm']);
                $PersonalRecruitView->setEmployKb($item['employ_kb']);
                $PersonalRecruitView->setEmployKbNm($item['employ_kb_nm']);
                $PersonalRecruitView->setStoreId($item['store_id']);
                $PersonalRecruitView->setStoreNm($item['store_nm']);
                $PersonalRecruitView->setQrId($item['qr_id']);
                $PersonalRecruitView->setBiko($item['biko']);
                $PersonalRecruitView->setStaffCd($item['staff_cd']);
                $PersonalRecruitView->setAddDate($item['add_date']);
                $PersonalRecruitView->setRecruitKb($item['recruit_kb']);
                $PersonalRecruitView->setRecruitKbNm($item['recruit_kb_nm']);
                $PersonalRecruitView->setRecruitBiko($item['recruit_biko']);
                $PersonalRecruitView->setSchoolNm($item['school_nm']);
                $PersonalRecruitView->setBunruiId($item['bunrui_id']);
                $PersonalRecruitView->setBunruiNm($item['bunrui_nm']);
                $PersonalRecruitView->setEducationalBackgroundKb($item['educational_background_kb']);
                $PersonalRecruitView->setEducationalBackgroundKbNm($item['educational_background_kb_nm']);
                $recruit_list[] = $PersonalRecruitView;
            }
            $view->setPersonalRecruitViewList($recruit_list);

            return R_SUCCESS;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * リクルート情報登録
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @param  $view->*
     * @return integer
     */
    public function savePersonalRecruit(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            $somfa->begin();

            if (isNULL($view->getStaffCd())) {
                //--------------------------------------------------------------
                //個人を登録する
                //--------------------------------------------------------------
                $personalView = PersonalBaseView::getInstance();
                $personalView->setPersonalId($view->getPersonalId());
                $personalView->setPersonalNm($view->getPersonalNm());
                $personalView->setPersonalKn($view->getPersonalKn());
                $personalView->setMail($view->getMail());
                $personalView->setMobileMail($view->getMobileMail());
                $personalView->setSex($view->getSex());
                $personalView->setBirthdayYear($view->getBirthdayYear());
                $personalView->setBirthdayMonth($view->getBirthdayMonth());
                $personalView->setBirthdayDay($view->getBirthdayDay());

                $personalHomeView = PersonalHomeView::getInstance();
                $personalHomeView->setPersonalId($view->getPersonalId());
                $personalHomeView->setTel($view->getTel());
                $personalHomeView->setFax($view->getFax());
                $personalHomeView->setMobile($view->getMobile());
                $personalHomeView->setZipcode($view->getZipcode());
                $personalHomeView->setAddress1($view->getAddress1());
                $personalHomeView->setAddress2($view->getAddress2());
                $personalHomeView->setAddress3($view->getAddress3());
                $personalHomeView->setAddress4($view->getAddress4());

                $personalParentView = PersonalParentView::getInstance();
                $personalParentView->setPersonalId($view->getPersonalId());

                $personalView->setHomeView($personalHomeView);
                $personalView->setParentView($personalParentView);

                $results = $this->savePersonal($personalView);

                if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                    $view->setPersonalId($personalView->getPersonalId());
                }
                else if ($results == R_ERROR_DUPL) {
                    return $results;
                }
                else {
                    throw new xbpwException(E_USER_ERROR, E_DB_99);
                }
            }
            else {
                //--------------------------------------------------------------
                //社員を登録する
                //--------------------------------------------------------------
                $syainView = SyainView::getInstance();
                $syainView->setPersonalId($view->getPersonalId());
                $syainView->setPersonalKn($view->getPersonalKn());
                $syainView->setPersonalNm($view->getPersonalNm());
                $syainView->setStaffCd($view->getStaffCd());
                $syainView->setTel($view->getTel());
                $syainView->setMobile($view->getMobile());
                $syainView->setMail($view->getMail());
                $syainView->setYear($view->getBirthdayYear());
                $syainView->setMonth($view->getBirthdayMonth());
                $syainView->setDay($view->getBirthdayDay());
                $syainView->setSchoolNm($view->getSchoolNm());
                $syainView->setEducationalBackgroundKb($view->getEducationalBackgroundKb());
                $results = auroraService::getInstance('MstSyainService')->saveSyain($syainView);
                if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                    $view->setPersonalId($syainView->getPersonalId());
                }
                else if ($results == R_ERROR_DUPL || $results == R_ERROR_DUPL_MAIL  || $results == R_ERROR_DUPL_STAFFCD) {
                    return $results;
                }
                else {
                    throw new xbpwException(E_USER_ERROR, E_DB_99);
                }
            }


            //--------------------------------------------------------------
            //マスタ情報取得
            //--------------------------------------------------------------
            $old = $somfa->retrieveByPK('tbm_personal_recruit',
                                        array('user_company_id' => $view->getUserCompanyId(),
                                              'personal_id'     => $view->getPersonalId()));

            //--------------------------------------------------------------
            //登録用情報生成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id']    = $view->getUserCompanyId();
            $data['personal_id']        = $view->getPersonalId();
            $data['request_area']       = $view->getRequestArea();
            $data['work_area']          = $view->getWorkArea();
            $data['transportation_kb']  = $view->getTransportationKb();
            $data['start_dt']           = $view->getStartDtYear() . $view->getStartDtMonth() . $view->getStartDtDay();
            $data['medium_kb']          = is_array($old)?null:$view->getMediumKb();
            $data['store_id']           = $view->getStoreId();
            $data['qr_id']              = $view->getQrId();
            $data['employ_kb']          = $view->getEmployKb();
            $data['biko']               = $view->getBiko();
            $data['recruit_kb']         = $view->getRecruitKb();
            $data['bunrui_id']          = $view->getBunruiId();
            $data['recruit_biko']       = $view->getRecruitBiko();
            $data['school_nm']          = $view->getSchoolNm();
            $data['educational_background_kb'] = $view->getEducationalBackgroundKb();
            $data['del_flg']     = DB_ENABLE;
            $data['add_date']    = is_array($old)?$old['add_date']:xbUtil::getTimestamp();
            $data['add_pgid']    = is_array($old)?$old['add_pgid']:__METHOD__;
            $data['add_user_cd'] = is_array($old)?$old['add_user_cd']:$view->getLogonUserCd();
            $data['upd_date']    = xbUtil::getTimestamp();
            $data['upd_pgid']    = __METHOD__;
            $data['upd_user_cd'] = $view->getLogonUserCd();

            //--------------------------------------------------------------
            //登録／更新実行
            //--------------------------------------------------------------
            $results = $somfa->save('tbm_personal_recruit', $data);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人リスト削除
     *
     * @access public
     * @param  $view->personalListDetailView
     * @return integer
     */
    public function deletePersonalRecruitList(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //削除実行
            //--------------------------------------------------------------
            $detailView = $view->getPersonalRecruitViewList();
            $detailCnt  = count($detailView);
            $delCount   = 0;

            $somfa->begin();
            foreach ($detailView as $v) {
                $this->deletePersonalRecruit($v);
            }
            $somfa->commit();

            if ($delCount == 0) {
                return R_SUCCESS;
            } else {
                return R_SUCCESS_DELETE;
            }
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 応募者削除
     *
     * @access private
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @return integer
     */
    public function deletePersonalRecruit(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId', 'personalId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //削除用情報生成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id'] = $view->getUserCompanyId();
            $data['personal_id']     = $view->getPersonalId();
            $data['del_flg']         = DB_DELETE;
            $data['upd_date']        = xbUtil::getTimestamp();
            $data['upd_pgid']        = __METHOD__;
            $data['upd_user_cd']     = $view->getLogonUserCd();

            //--------------------------------------------------------------
            //削除実行
            //--------------------------------------------------------------
            $somfa->begin();
            $results = $somfa->save('tbm_personal_recruit', $data);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人会員情報取得
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @data   $view->*
     * @return $view
     */
    public function getPersonalMember(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId', 'personalId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //個人情報取得
            //--------------------------------------------------------------
            $rs = $somfa->select('tbv_personal_member',
                                 '*',
                                 'user_company_id = ? and personal_id = ? ',
                                 array($view->getUserCompanyId(), $view->getPersonalId()));
            foreach ($rs as $item) {
                $view->setPersonalNm($item['personal_nm']);
                $view->setPersonalKn($item['personal_kn']);
                $view->setMail($item['mail']);
                $view->setMobileMail($item['mobile_mail']);
                $view->setSex($item['sex']);
                $view->setSexNm($item['sex_nm']);
                $view->setTel($item['tel']);
                $view->setFax($item['fax']);
                $view->setMobile($item['mobile']);
                $view->setZipcode($item['zipcode']);
                $view->setAddress1($item['address1']);
                $view->setAddress2($item['address2']);
                $view->setAddress3($item['address3']);
                $view->setAddress4($item['address4']);

                $birth_year;
                $birth_month;
                $birth_day;
                $birth = $item['birthday'];
                if(strlen($birth)>=8){
                    $birth_year  = substr($birth,0,4);
                    $birth_month = substr($birth,4,2);
                    $birth_day   = substr($birth,6,2);
                }
                $view->setBirthdayYear($birth_year);
                $view->setBirthdayMonth($birth_month);
                $view->setBirthdayDay($birth_day);

                $view->setMediumKb($item['medium_kb']);
                $view->setMediumKbNm($item['medium_kb_nm']);
                $view->setStoreId($item['store_id']);
                $view->setStoreNm($item['store_nm']);
                $view->setStaffCd($item['staff_cd']);
                $view->setBiko($item['biko']);
                $view->setAddDate($item['add_date']);
                break;
            }
            return R_SUCCESS;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 個人会員情報一覧取得
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @data   $view->*
     * @return $view
     */
    public function getPersonalMemberList(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //条件設定
            //--------------------------------------------------------------
            $keys = null;
            $vals = null;
            $ords = null;
            $this->_createCriteriaSearch($view, $keys, $vals, $ords);

            if (!xbUtil::isNULL($view->getStoreId())) {
                $tmp_store_id = $view->getStoreId();
                if($tmp_store_id == -1) {
                    $keys   = $keys . ' and store_id is not null ';
                }
                else {
                    $keys   = $keys . ' and store_id = ? ';
                    $vals[] = $tmp_store_id;
                }
            }
            if (!xbUtil::isNULL($view->getQrId())) {
                $tmp_qr_id = $view->getQrId();
                if($tmp_qr_id == -1) {
                    $keys   = $keys . ' and qr_id is not null ';
                }
                else {
                    $keys   = $keys . ' and qr_id = ? ';
                    $vals[] = $view->getQrId();
                }
            }

            $page_id = $view->getPageId();
            $rs = $somfa->select('tbv_personal_member',
                                 '*',
                                 $keys,
                                 $vals,
                                 'add_date',
                                 null,
                                 $page_id);

            $view->setCount($somfa->count());
            $member_list = array();
            foreach ($rs as $item) {
                $PersonalMemberView = PersonalMemberView::getInstance();
                $PersonalMemberView->setPersonalId($item['personal_id']);
                $PersonalMemberView->setPersonalNm($item['personal_nm']);
                $PersonalMemberView->setPersonalKn($item['personal_kn']);
                $PersonalMemberView->setMail($item['mail']);
                $PersonalMemberView->setMobileMail($item['mobile_mail']);
                $PersonalMemberView->setSex($item['sex']);
                $PersonalMemberView->setSexNm($item['sex_nm']);
                $PersonalMemberView->setTel($item['tel']);
                $PersonalMemberView->setFax($item['fax']);
                $PersonalMemberView->setMobile($item['mobile']);
                $PersonalMemberView->setZipcode($item['zipcode']);
                $PersonalMemberView->setAddress1($item['address1']);
                $PersonalMemberView->setAddress2($item['address2']);
                $PersonalMemberView->setAddress3($item['address3']);
                $PersonalMemberView->setAddress4($item['address4']);

                $birth_year;
                $birth_month;
                $birth_day;
                $birth = $item['birthday'];
                if(strlen($birth)>=8){
                    $birth_year  = substr($birth,0,4);
                    $birth_month = substr($birth,4,2);
                    $birth_day   = substr($birth,6,2);
                }
                $PersonalMemberView->setBirthdayYear($birth_year);
                $PersonalMemberView->setBirthdayMonth($birth_month);
                $PersonalMemberView->setBirthdayDay($birth_day);

                $PersonalMemberView->setMediumKb($item['medium_kb']);
                $PersonalMemberView->setMediumKbNm($item['medium_kb_nm']);
                $PersonalMemberView->setStoreId($item['store_id']);
                $PersonalMemberView->setStoreNm($item['store_nm']);
                $PersonalMemberView->setQrId($item['qr_id']);
                $PersonalMemberView->setBiko($item['biko']);
                $PersonalMemberView->setStaffCd($item['staff_cd']);
                $PersonalMemberView->setAddDate($item['add_date']);
                $member_list[] = $PersonalMemberView;
            }
            $view->setPersonalMemberViewList($member_list);
            return R_SUCCESS;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 会員情報登録
     *
     * @access public
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @param  $view->*
     * @return integer
     */
    public function savePersonalMember(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            $somfa->begin();

            if (isNULL($view->getStaffCd())) {
                //--------------------------------------------------------------
                //個人を登録する
                //--------------------------------------------------------------
                $personalView = PersonalBaseView::getInstance();
                $personalView->setPersonalId($view->getPersonalId());
                $personalView->setPersonalNm($view->getPersonalNm());
                $personalView->setPersonalKn($view->getPersonalKn());
                $personalView->setMail($view->getMail());
                $personalView->setMobileMail($view->getMobileMail());
                $personalView->setSex($view->getSex());
                $personalView->setBirthdayYear($view->getBirthdayYear());
                $personalView->setBirthdayMonth($view->getBirthdayMonth());
                $personalView->setBirthdayDay($view->getBirthdayDay());

                $personalHomeView = PersonalHomeView::getInstance();
                $personalHomeView->setPersonalId($view->getPersonalId());
                $personalHomeView->setTel($view->getTel());
                $personalHomeView->setFax($view->getFax());
                $personalHomeView->setMobile($view->getMobile());
                $personalHomeView->setZipcode($view->getZipcode());
                $personalHomeView->setAddress1($view->getAddress1());
                $personalHomeView->setAddress2($view->getAddress2());
                $personalHomeView->setAddress3($view->getAddress3());
                $personalHomeView->setAddress4($view->getAddress4());

                $personalParentView = PersonalParentView::getInstance();
                $personalParentView->setPersonalId($view->getPersonalId());

                $personalView->setHomeView($personalHomeView);
                $personalView->setParentView($personalParentView);

                $results = $this->savePersonal($personalView);

                if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                    $view->setPersonalId($personalView->getPersonalId());
                }
                else if ($results == R_ERROR_DUPL) {
                    return $results;
                }
                else {
                    throw new xbpwException(E_USER_ERROR, E_DB_99);
                }
            }
            else {
                //--------------------------------------------------------------
                //社員を登録する
                //--------------------------------------------------------------
                $syainView = SyainView::getInstance();
                $syainView->setPersonalId($view->getPersonalId());
                $syainView->setPersonalKn($view->getPersonalKn());
                $syainView->setPersonalNm($view->getPersonalNm());
                $syainView->setStaffCd($view->getStaffCd());
                $syainView->setTel($view->getTel());
                $syainView->setMobile($view->getMobile());
                $syainView->setMail($view->getMail());
                $syainView->setYear($view->getBirthdayYear());
                $syainView->setMonth($view->getBirthdayMonth());
                $syainView->setDay($view->getBirthdayDay());
                $results = auroraService::getInstance('MstSyainService')->saveSyain($syainView);
                if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                    $view->setPersonalId($syainView->getPersonalId());
                }
                else if ($results == R_ERROR_DUPL || $results == R_ERROR_DUPL_MAIL  || $results == R_ERROR_DUPL_STAFFCD) {
                    return $results;
                }
                else {
                    throw new xbpwException(E_USER_ERROR, E_DB_99);
                }
            }


            //--------------------------------------------------------------
            //マスタ情報取得
            //--------------------------------------------------------------
            $old = $somfa->retrieveByPK('tbm_personal_member',
                                        array('user_company_id' => $view->getUserCompanyId(),
                                              'personal_id'     => $view->getPersonalId()));

            //--------------------------------------------------------------
            //登録用情報生成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id'] = $view->getUserCompanyId();
            $data['personal_id']     = $view->getPersonalId();
            $data['medium_kb']       = is_array($old)?null:$view->getMediumKb();
            $data['store_id']        = $view->getStoreId();
            $data['qr_id']           = $view->getQrId();
            $data['biko']            = $view->getBiko();
            $data['del_flg']         = DB_ENABLE;
            $data['add_date']        = is_array($old)?$old['add_date']:xbUtil::getTimestamp();
            $data['add_pgid']        = is_array($old)?$old['add_pgid']:__METHOD__;
            $data['add_user_cd']     = is_array($old)?$old['add_user_cd']:$view->getLogonUserCd();
            $data['upd_date']        = xbUtil::getTimestamp();
            $data['upd_pgid']        = __METHOD__;
            $data['upd_user_cd']     = $view->getLogonUserCd();

            //--------------------------------------------------------------
            //登録／更新実行
            //--------------------------------------------------------------
            $results = $somfa->save('tbm_personal_member', $data);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 会員リスト削除
     *
     * @access public
     * @param  $view->personalListDetailView
     * @return integer
     */
    public function deletePersonalMemberList(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //削除実行
            //--------------------------------------------------------------
            $detailView = $view->getPersonalMemberViewList();
            $detailCnt  = count($detailView);
            $delCount   = 0;

            $somfa->begin();
            foreach ($detailView as $v) {
                $this->deletePersonalMember($v);
            }
            $somfa->commit();

            if ($delCount == 0) {
                return R_SUCCESS;
            } else {
                return R_SUCCESS_DELETE;
            }
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }

    /**
     * 会員削除
     *
     * @access private
     * @param  $view->user_company_id
     * @param  $view->personal_id
     * @return integer
     */
    public function deletePersonalMember(& $view) {

        xbLog::logger(xbLog::DEBUG, __CLASS__, 'Called ' . __METHOD__);

        //--------------------------------------------------------------
        //引数存在チェック
        //--------------------------------------------------------------
        if (xbUtil::isNULL($view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_02, 'view'));
        }

        //--------------------------------------------------------------
        //引数パラメータ必須チェック
        //--------------------------------------------------------------
        if (!$this->assert(array('userCompanyId', 'personalId'), & $view)) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_03, 'view'));
        }

        //--------------------------------------------------------------
        //somfaオブジェクト取得
        //--------------------------------------------------------------
        $somfa = $this->getSomfa();

        try {

            //--------------------------------------------------------------
            //削除用情報生成
            //--------------------------------------------------------------
            $data = array();
            $data['user_company_id'] = $view->getUserCompanyId();
            $data['personal_id']     = $view->getPersonalId();
            $data['del_flg']         = DB_DELETE;
            $data['upd_date']        = xbUtil::getTimestamp();
            $data['upd_pgid']        = __METHOD__;
            $data['upd_user_cd']     = $view->getLogonUserCd();

            //--------------------------------------------------------------
            //削除実行
            //--------------------------------------------------------------
            $somfa->begin();
            $results = $somfa->save('tbm_personal_member', $data);
            if ($results == R_SUCCESS_INSERT || $results == R_SUCCESS_UPDATE) {
                $somfa->commit();
            }
            else {
                throw new xbpwException(E_USER_ERROR, E_DB_99);
            }
            return $results;
        }
        catch (xbpwException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbpwException(E_USER_ERROR, sprintf(F_NM_01, $e->getMessage()));
        }
    }
}
?>
