<?php
/**
 * xbFileNX
 *
 * @since    PHP 5.0
 */
class xbFile {

    private $fp;
    private $file;
    private $delimiter = ','; //delimiter
    private $enclosure = '"';  //enclosure

    public function getFile() {
        return $this->file;
    }

    public function setFile($value) {
        $this->file = $value;
    }

    public function getDelimiter() {
        return $this->delimiter;
    }

    public function setDelimiter($value) {
        $this->delimiter = $value;
    }

    public function getEnclosure() {
        return $this->enclosure;
    }

    public function setEnclosure($value) {
        $this->enclosure = $value;
    }

    /**
     * Tv
     *
     * 
     *
     * @return object
     * @access public
     */
    public static function getInstance() {
        $class = __CLASS__;
        $instance = new $class ();
        return $instance;
    }

    /**
     * function open(integer)
     * open the csv file.
     * @param $mode-->(r,r+,w,w+,a,a+,x,x+).    
     *
     * @return bool true, if set Select Control successfully, otherwise false.
     */
    public function open($mode) {
        try {
            $fp = fopen($this->file, $mode);
            if (!$fp) {
                throw new xbException(xbUtil::errorMessage(__METHOD__, sprintf(E_FL_01,$this->file)));
            }
            return $fp;
        }
        catch (xbException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbException(xbUtil::errorMessage(__METHOD__, $e->getMessage()));
        }
    }

    /**
     *  writeln()
     */
    public function write($str) {
        try {
            $this->contentsWrite($str, 'wb');
        }
        catch (xbException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbException(xbUtil::errorMessage(__METHOD__, $e->getMessage()));
        }
    }

    /**
     *  writeln()
     */
    public function writeln($str) {
        try {
            $this->contentsWrite($str."\n", 'ab');
        }
        catch (xbException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbException(xbUtil::errorMessage(__METHOD__, $e->getMessage()));
        }
    }

    /**
     *  getBinaryContents()
     */
    public function getBinaryContents() {
        try {
            if (!$this->fp) {
                $this->fp = $this->open('r');
            }
            $contents = fread($this->fp, filesize($this->file));
            $this->close();
            return $contents;
        }
        catch (xbException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbException(xbUtil::errorMessage(__METHOD__, $e->getMessage()));
        }
    }

    /**
     *  getContents()
     */
    public function getContents() {
        try {
            if (!$this->fp) {
                $this->fp = $this->open('r');
            }
            $contents = fread($this->fp, filesize($this->file));
            $this->close();
            return mb_convert_encoding($contents, "SJIS-win", "UTF-8, SJIS, SJIS-win");
        }
        catch (xbException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbException(xbUtil::errorMessage(__METHOD__, $e->getMessage()));
        }
    }

    public function getCSVToArray() {
        try {
            if (!$this->fp) {
                $this->fp = $this->open('r');
            }
            $records = array();
            $row = 0;
            while ($data = fgetcsv($this->fp, filesize($this->file), $this->delimiter, $this->enclosure)) {
                $col = count($data);
                for ($i=0; $i<$col; $i++) {
                    $records[$row][$i] = mb_convert_encoding($data[$i], "UTF-8", "UTF-8, SJIS, SJIS-win");
                }
                $row++;
            }
            return $records;
        }
        catch (xbException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbException(xbUtil::errorMessage(__METHOD__, $e->getMessage()));
        }
    }

    /**
     * close($fp)
     * close file
     * @param @$fp   
     */
    public function close() {
        @fclose($this->fp);
        $this->fp = null;
    }

    /**
     *  contentsWrite()
     */
    private function contentsWrite($str, $mode) {
        try {
            if (!$this->fp) {
                $this->fp = $this->open($mode);
            }
            if (!fwrite($this->fp, $str)) {
                throw new xbException(xbUtil::errorMessage(__METHOD__, sprintf(E_FL_02,$this->file)));
            }
            $this->close();
        }
        catch (xbException $e) {
            throw $e;
        }
        catch (Exception $e) {
            throw new xbException(xbUtil::errorMessage(__METHOD__, $e->getMessage()));
        }
    }
}
?>
