<?php
/**
 *
 * @author   Shiro Tajima <tajima@exbridge.jp>
 * @since    PHP 5.0
 */
class xbUtil {

    const INTIME  = 'InTime'; //勤怠用
    const OUTTIME = 'OutTime';//勤怠用

    /**
     * 概要 アップロード用絶対パス取得
     *
     * @return string
     * @access public
     */
    public static function getUploadDir() {
        if(self::isNULL(xbIDs::UPLOADS_DIR)){
            throw new xbException(xbUtil::errorMessage(__METHOD__, 'NULL Exception'));
        }
        return AURORA_WEB_DIR . xbIDs::UPLOADS_DIR;
    }

    /**
     * 概要 ダウンロード用絶対パス取得
     *
     * @return string
     * @access public
     */
    public static function getDownloadDir() {
        if(self::isNULL(xbIDs::DOWNLOADS_DIR)){
            throw new xbException(xbUtil::errorMessage(__METHOD__, 'NULL Exception'));
        }
        return AURORA_WEB_DIR . xbIDs::DOWNLOADS_DIR;
    }

    /**
     * 概要 納品書ファイル名生成
     *
     * @return string
     * @access public
     */
    public static function createEssCsvPath($id, &$file, &$csvPath, &$csvPathLocal) {
        $file         = date("Ymdhis") . '_' . self::rand().'_'.$id;
        $csvPath      = self::getRedirectURL('downloads/ess/' . $file);
        $csvPathLocal = auroraConfig::getDownloadPath() . '/ess/' . $file;
    }

    /**
     * 概要 リポジトリ絶対パス取得
     *
     * @return string
     * @access public
     */
    public static function getRepositoryDir() {
        if(self::isNULL(xbIDs::REPOSITORY_DIR)){
            throw new xbException(xbUtil::errorMessage(__METHOD__, 'NULL Exception'));
        }
        return AURORA_WEB_DIR . xbIDs::REPOSITORY_DIR;
    }

    /**
     * $flg=1 第１引数にURIを指定
     * $      その他、エイリアス移行のURLを指定
     */
    public static function getRedirectURL($value, $flg=null) {
        if(preg_match("/^http/i", $value)){
            return $value;
        }
        //RequestURIが指定された（RequestURIなら先頭に「/」つき）
        if($flg == 1){
            if(PORT=='80'){
                return 'http://'.$_SERVER['SERVER_NAME'].$value;
            }
            else{
                return 'http://'.$_SERVER['SERVER_NAME'].':'.PORT.$value;
            }
        }
        //その他の指定
        else{
            if(PORT=='80'){
                return 'http://'.$_SERVER['SERVER_NAME'].'/'.ALIAS.'/'.$value;
            }
            else{
                return 'http://'.$_SERVER['SERVER_NAME'].':'.PORT.'/'.ALIAS.'/'.$value;
            }
        }
    }

    /**
     * 概要 絶対パスＵＲＬ取得
     *
     * 説明 ルーティングを引数に、絶対パスＵＲＬを取得し、返す
     *
     * @return object
     * @access public
     */
    public static function generateURL($module, $action=null) {
        if (is_null($action)) {
            return self::getRedirectURL($module);
        }
        else {
            return self::getRedirectURL($module.'/'.$action);
        }
    }

    /**
     * 概要 ダウンロード
     *
     * @return object
     * @access public
     */
    public static function download($file) {
        //ダウンロード用のHTTPヘッダ送信
        header("Content-Disposition: inline; filename=\"".basename($file)."\"");
        header("Content-Length: ".filesize($file));
        header("Content-Type: application/octet-stream");

        //ファイルを読んで出力
        $fp = fopen($file, "r");
        while (!feof($fp)) {
            echo fgets($fp, 4096);
        }
        fclose($fp);

        unlink($file);
        return sfView::NONE;
    }

    /**
     * 共通登録処理のチェック戻値用関数
     *
     * @return: true:false
     * @access: private.
     */
    public static function result(/*$obj,*/ $value ){
        //$obj->getResponse()->addHttpMeta('xbStatus:'.$value, '*');
        if($value === '0'){
            return sfView::SUCCESS;
        }
        else{
            return sfView::NONE;
        }
    }

    /**
     * 共通登録処理のモーダルウィンドウ戻値用関数
     *
     * @return: true:false
     * @access: private.
     */
    public static function closeModal(){
        echo "<script language='JavaScript'>";
        echo "window.close();";
        echo "</script>";
        return sfView::NONE;
    }

    /**
     * 概要 パラメータの同期（クラス⇔クラス）
     *
     * @param param1 同期先クラス
     * @param param2 同期元クラス
     * @access public
     */
    public static function syncronize( &$param1, &$param2 ) {
        $methodList = get_class_methods($param1);
        foreach($methodList as $method){
            //setterのメソッド名を取得
            if(preg_match('/^set(.+)$/', $method, $param)){
                $getter = 'get'.$param[1];
                if(method_exists($param2, $getter)){
                    $param1->$method($param2->$getter());
                }
            }
        }
    }

    /**
     * 概要 エラーメッセージ出力フォーマッター
     *
     * @param param1 同期先クラス
     * @param param2 同期元クラス
     * @access public
     */
    public static function errorMessage( $method, $message ) {
        return sprintf('[%s][%s]', $method, $message);
    }

    /**
     * 概要 パラメータの同期（クラス⇔Symfonyリクエスト）
     *
     * @param param1 同期先クラス
     * @param param2 リクエスト（Actionsクラス）
     * @param boolean :$asyncronize
     *                true  =>非同期通信（Ajax）
     *                false =>同期通信
     * @access public
     */
/*
    public static function syncronizeSFRequest( &$param1, &$param2, $asyncronize=false ) {
        $methodList = get_class_methods($param1);
        foreach($methodList as $method){
            //setterのメソッド名を取得
            if(preg_match('/^set(.+)$/', $method, $param)){
                $requestList = $param2->getRequest()->getParameterHolder()->getAll();
                //xbLog :: logger(xbLog :: DEBUG, __CLASS__, $param[1].':'.$requestList[$param[1]]);
                if(!isset($requestList[$param[1]])){
                    continue;
                }
                if($asyncronize){
                    $param1->$method(xbUtil::decoding($requestList[$param[1]]));
                }else{
                    $param1->$method($requestList[$param[1]]);
                }
            }
        }
    }
*/

    /**
     * 概要 パスワード変換
     *
     * @return string
     * @access public
     */
    public static function cnvPassword($password) {
        if (AUTH_MAGIC_ENABLED) {
            $password = sha1($password . ':' . AUTH_MAGIC);
        }
        return $password;
    }

    /**
     * 概要 空白チェック
     *
     * @return string
     * @access public
     */
    public static function isNULL($val){
        if(isset($val) && $val===0){
            return false;
        }
        if(!isset($val) || is_null($val) || $val===''){
            return true;
        }
        return false;
    }


    /**
     * 概要 NULL値の置換
     *
     * 説明
     *  引数２がNULL値の場合、引数１を返します。
     *
     * @return string
     * @access public
     */
    public static function NVL($value1, $value2){
        if( self::isNULL($value2) ){
            return $value1;
        }
        return $value2;
    }

    /**
     * 概要 左詰め処理
     *
     * 説明
     *  引数１を引数２で指定された桁数の０埋めを行います。
     *
     * @return string
     * @access public
     */
    public static function LPAD($value1, $value2){
        return str_pad($value1, $value2, '0', STR_PAD_LEFT);
    }

    /**
     * 概要
     *  文字数字置換
     *
     * 説明
     *  「1,000,000」等の文字列を「1000000」という文字列で返します。
     *
     * @return string
     * @access public
     */
    public static function toNum($value){
        return ereg_replace(',', '', $value);
    }

    /**
     * 概要
     *  曜日リスト作成
     *
     * 説明
     *  曜日リストを返します。
     *
     * @return array
     * @access public
     */
    public static function getWeek(){
        return array('1'=>'月', '2'=>'火', '3'=>'水', '4'=>'木', '5'=>'金', '6'=>'土', '7'=>'日');
    }

    /**
     * 概要
     *  指定年月の日リスト作成
     *
     * 説明
     *  指定された年月の日付けリストを返します。
     *
     * @return array
     * @access public
     */
    public static function dayList($year, $month){
        //翌月の年を取得
        $year = date(Y, strtotime ("+1 month", mktime (0,0,0,$month,1,$year)));
        //翌月の月を取得
        $month = date(m, strtotime ("+1 month", mktime (0,0,0,$month,1,$year)));
        //今月の最終日を取得
        $day = date(d,strtotime ("-1 day", mktime (0,0,0,$month,1,$year)));

        $dayList = array();
        for ($i=1; $i<=$day; $i++){
            $dayList[] = $i;
        }
        return $dayList;
    }

    /**
     * getTimestamp:タイムスタンプ取得
     *
     * @return: true:false
     * @access: private.
     */
    public static function getTimestamp($value=null){
        if(is_null($value)){
            $value = time();
        }
        return date("Y-m-d H:i:s", $value);
    }

    /**
     * makeTime:時間作成
     *
     * @param : $mode = 0 : ymd形式 (00:00:00)月の初日を取得
     *                = 1 : ymd形式 (24:59:59)月の最終日を取得
     * @return: true:false
     * @access: private.
     */
    public static function makeTime($value, $mode=0){
        if($mode==0){
            $year  = substr($value, 0, 4);
            $month = substr($value, 4, 2);
            //yyyymm
            if(mb_strlen($value)==6){
                $day   = '01';
            }else{
                $day   = substr($value, 6, 2);
            }
            return date("Y-m-d H:i:s", mktime(0, 0, 0, $month, $day, $year));
        }
        if($mode==1){
            $year  = substr($value, 0, 4);
            $month = substr($value, 4, 2);
            if(mb_strlen($value)==6){
                $day   = self::getLastDay($year, $month);
            }else{
                $day   = substr($value, 6, 2);
            }
            return date("Y-m-d H:i:s", mktime(23, 59, 59, $month, $day, $year));
        }
        return $value;
    }

    /**
     * makeTime:日付作成戻り値は文字列（yyymmdd）
     *
     * @param : $value = yyyymmdd or yyyymm (文字列)
     * @param : $mode = 0　月の初日を取得
     *                = 1　月の最終日を取得
     * @return: true:false
     * @access: private.
     */
    public static function makeDateStr($value, $mode=0){
        $year  = substr($value, 0, 4);
        $month = substr($value, 4, 2);
        if($mode==0){
            //yyyymm
            if(mb_strlen($value)==6){
                $day   = '01';
                //ymd
                $value   = $value.$day;
            }
        }
        if($mode==1){
            if(mb_strlen($value)==6){
                $day   = self::getLastDay($year, $month);
                //ymd
                $value   = $value.$day;
            }
        }
        return $value;
    }

    /**
     * isLastDay:末日判定
     *
     * @param : $year
     *          $month
     *          $day
     * @return: true:false
     * @access: private.
     */
    public static function isLastDay($year, $month, $day){
        if($month == 12){
            $year  = $year + 1;
            $month = 1;
        }
        else{
            $month = $month + 1;
        }
        //指定した月の'前月の末日'を取得するには、日に'0'を指定する
        $lastday = mktime(0, 0, 0, $month, 0, $year);
        $dd = date("d", $lastday);
        if($dd == $day){
            return true;
        }
        return false;
    }

    /**
     * getLastDay:末日を取得
     *
     * @param : $year
     *          $month
     * @return: $dd
     * @access: private.
     */
    public static function getLastDay($year, $month){
        if($month == 12){
            $year  = $year + 1;
            $month = 1;
        }
        else{
            $month = $month + 1;
        }
        //指定した月の'前月の末日'を取得するには、日に'0'を指定する
        $lastday = mktime(0, 0, 0, $month, 0, $year);
        $dd = date("d", $lastday);
        return $dd;
    }

    /**
     * rand:乱数発生
     *
     * @return: true:false
     * @access: private.
     */
    public static function rand(){
        mt_srand((double) microtime() * 1000000);
        return substr( mt_rand(), 0, 8 );
    }

    /**
     * fileWriteCheck:ファイル書込み権限チェック
     *
     * @return: true:false
     * @access: private.
     */
    public static function fileWriteCheck($file){
        if(!is_dir($file)){
            if(file_exists($file)){
                @chmod($file, 0666);
                if (!is_writable($file)){
                    return false;
                }
                else{
                    return true;
                }
            }
        }
        return false;
    }

    /**
     * dirWriteCheck:フォルダ書込み権限チェック
     *
     * @return: true:false
     * @access: private.
     */
    public static function dirWriteCheck($dir){
        if(is_dir($dir)){
            @chmod($dir, 0777);
            if (!is_writable($dir)){
                return false;
            }
            else{
                return true;
            }
        }
    }

    /**
     * フォルダーの削除
     * 概要: 指定したフォルダーの中身を削除します
     *
     * 注釈: scandirの戻り値はArray
     *      Outputs something like:
     *      Array
     *      (
     *          [0] => .
     *          [1] => ..
     *          [2] => bar.php
     *          [3] => foo.txt
     *          [4] => somedir
     *      )
    */
    public static function removeFolder($folderPath){
        $fileArray = scandir($folderPath);
        //$folderPathがフォルダーでない場合はFALSEを返します
        if( $fileArray != FALSE ){
            foreach( $fileArray as $key => $fileName ){
                if( '.' == $fileName || '..' == $fileName ){
                    continue;
                }
                $fileName = $folderPath.'/'.$fileName;
                //ファイルなら削除
                if(is_file($fileName)){
                    unlink($fileName);
                }
                //フォルダーなら再帰処理
                else{
                    self::removeFolder($fileName);
                    rmdir($fileName);
                }
            }
            rmdir($folderPath);
        }
    }

    /**
     * 概要 メタヘッダー文字列出力（AURORA - layout.php専用）
     *
     * @return string
     * @access public
     */
    public static function setDefaultMetaHeader(){
        echo "<meta http-equiv='Pragma' content='no-cache'>\n";
        echo "<meta http-equiv='Cache-Control' content='no-cache'>\n";
        echo "<meta http-equiv='Expires' content='0'>\n";
    }

    /**
     * 概要 javascriptヘッダー文字列出力（AURORA - layout.php専用）
     *
     * @return string
     * @access public
     */
    public static function setDefaultJsHeader(){
//        echo "<script type='text/javascript' src='/" .ALIAS. "/js/jquery/jquery.js'></script>\n";
        echo "<script type='text/javascript' src='/" .ALIAS. "/js/jquery/jquery-1.2.3.js'></script>\n";
        echo "<script type='text/javascript' src='/" .ALIAS. "/js/jquery/jquery.tooltip.js'></script>\n";
        echo "<script type='text/javascript' src='/" .ALIAS. "/js/jquery/jquery.bgiframe.js'></script>\n";
        echo "<script type='text/javascript' src='/" .ALIAS. "/js/jquery/jquery.dimensions.js'></script>\n";
        echo "<script type='text/javascript' src='/" .ALIAS. "/js/jquery/ui/ui.mouse.js'></script>\n";
        echo "<script type='text/javascript' src='/" .ALIAS. "/js/jquery/ui/ui.draggable.js'></script>\n";
        echo "<script type='text/javascript' src='/" .ALIAS. "/js/jquery/ui/ui.draggable.ext.js'></script>\n";
/*
        //jquery_interface_effect_slider-------->
        echo "<script type='text/javascript' src='/" .ALIAS. "/js/jquery/iutil.js'></script>\n";
        echo "<script type='text/javascript' src='/" .ALIAS. "/js/jquery/ifx.js'></script>\n";
        echo "<script type='text/javascript' src='/" .ALIAS. "/js/jquery/ifxslide.js'></script>\n";
        //<--------jquery_interface_effect_slider
*/
        echo "<script type='text/javascript' src='/" .ALIAS. "/js/grid/js/ext-base.js'></script>\n";
        echo "<script type='text/javascript' src='/" .ALIAS. "/js/grid/js/ext-all.js'></script>\n";
        echo "<script type='text/javascript' src='/" .ALIAS. "/js/xbJquery.js'></script>\n";
        //echo "<script type='text/javascript' src='/" .ALIAS. "/js/pwlib.js'></script>\n";
    }

    /**
     * 概要 cssヘッダー文字列出力（AURORA - layout.php専用）
     *
     * @return string
     * @access public
     */
    public static function setDefaultCssHeader(){
        echo "<link rel='stylesheet' type='text/css' media='screen' href='/" .ALIAS. "/css/main.css' />\n";
        echo "<link rel='stylesheet' type='text/css' media='screen' href='/" .ALIAS. "/css/ytheme-aero.css' />\n";
        echo "<link rel='stylesheet' type='text/css' media='screen' href='/" .ALIAS. "/css/ext-all.css' />\n";
        echo "<link rel='stylesheet' type='text/css' media='screen' href='/" .ALIAS. "/css/tooltip_win.css' />\n";
        echo "<link rel='stylesheet' type='text/css' media='screen' href='/" .ALIAS. "/css/tab/tabs.css' />\n";
        echo "<link rel='stylesheet' type='text/css' media='screen' href='/" .ALIAS. "/css/tab/tabs-ie.css' />\n";
        echo "<!--[if IE]><link rel='stylesheet' href='/" .ALIAS. "/css/blueprint/lib/ie.css' type='text/css' media='screen, projection'><![endif]-->\n";

    }

    /**
     * 概要
     *  UTF-8へのエンコード（AURORA専用）
     */
    public static function encoding($value){
        return mb_convert_encoding($value, "UTF-8", xbIDs::HTML_ENCODE);
    }

    /**
     * 概要
     *  WEB層の文字コードへのデコード（AURORA専用）
     */
    public static function decoding($value){
        return mb_convert_encoding($value, xbIDs::HTML_ENCODE, "UTF-8");
    }

    /**
     * 概要
     *  風神用CSVファイル作成（AURORA専用）
     */
    public static function createHZFCsvFile($csvPath, $csvData){
        mb_convert_variables('sjis-win', 'UTF-8', $csvData);
        $csvHandle = @fopen( $csvPath, "wb" );
        @fwrite( $csvHandle, $csvData );
    }

    /**
     * 概要
     *  HyperEstraier用にキーワードを作成
     */
    public static function createHEKeyWord($keys) {
        //キーワードの中から「"」を削除します。
        $keys = str_replace("\\\"", "", $keys);

        //trim and スペース変換
        $keys = self::strEmpRemove($keys);

        //キーワードの中から「|」を「BLANK_OR_BLANK」に変更しかつ、「!」を「BLANK_ANDNOT_BLANK」に変更します。
        $search = array (
            "/[ ]+\|[ ]+/",
            "/[ ]+\![ ]+/"
        );
        $replace = array (
            "BLANK_OR_BLANK",
            "BLANK_ANDNOT_BLANK"
        );
        $keys = preg_replace($search, $replace, $keys);

        //キーワードの中から「 」を「AND」に変更しかつ、「|」を「BLANK_OR_BLANK」に変更しかつ、「!」を「BLANK_ANDNOT_BLANK」に変更します。
        $search = array (
            "/[ ]+/",
            "/BLANK_OR_BLANK/",
            "/BLANK_ANDNOT_BLANK/"
        );
        $replace = array (
            " AND ",
            " OR ",
            " ANDNOT "
        );
        $keys = preg_replace($search, $replace, $keys);
        xbLog::logger(xbLog::DEBUG,__CLASS__,">>>>>createHEKeyWord[$keys]");
        return $keys;
    }

    /**
     * 概要
     *  SVNチェックアウト実行
     */
    public static function checkoutRepository($repositoryPath, $outputPath) {
        $svnstr = "env ";
        $outputList = array();
        $result;
        exec($svnstr, $outputList, $result);
        foreach($outputList as $output){
            xbLog::logger(xbLog::DEBUG,__CLASS__,">>>>>Env[$output]");
        }

        $svnstr = "whoami ";
        $outputList = array();
        $result;
        exec($svnstr, $outputList, $result);
        foreach($outputList as $output){
            xbLog::logger(xbLog::DEBUG,__CLASS__,">>>>>Who[$output]");
        }

        $svnstr = "svn checkout ".$repositoryPath." ".$outputPath;
        xbLog::logger(xbLog::DEBUG,__CLASS__,">>>>>command[$svnstr]");
        $outputList = array();
        $result;
        exec($svnstr, $outputList, $result);
        foreach($outputList as $output){
            xbLog::logger(xbLog::DEBUG,__CLASS__,">>>>>Output[$output]");
        }
        xbLog::logger(xbLog::DEBUG,__CLASS__,">>>>>Result[$result]");

        return $result;
    }

    /**
     * 概要
     *  SVNアップデート実行
     */
    public static function updateRepository($outputPath) {
        $svnstr = "svn update ".$outputPath;
        xbLog::logger(xbLog::DEBUG,__CLASS__,">>>>>command[$svnstr]");
        $outputList = array();
        $result;
        exec($svnstr, $outputList, $result);
        foreach($outputList as $output){
            xbLog::logger(xbLog::DEBUG,__CLASS__,">>>>>Output[$output]");
        }
        xbLog::logger(xbLog::DEBUG,__CLASS__,">>>>>Result[$result]");
        return $result;
    }

    /**
     * 概要
     *  配列の要素を出力
     */
    public static function debug($var){
        require_once (XBE_LIBS_DIR . '/vendors/debuglib.php');
        //show_vars(true, $var);
        print_a($var);
    }

    /**
     * 概要
     *  バックアップ処理
     *
     */
    public static function backup(){

        if(xbIDs::DBTYPE==0){
            self::myBackup();
        }
        else{
            self::pgBackup();
        }
    }

    /**
     * 概要
     *  MySQLバックアップ
     *
     * いまこのコメントを見た人が作ってくれます！！
     */
    private static function myBackup(){
    }

    /**
     * 概要
     *  PostgreSQLバックアップ
     *
     */
    private static function pgBackup(){

        $rootPath   = sfConfig::get('sf_root_dir');
        $cmd;
        $user       = xbIDs::DBUSER;
        $database   = xbIDs::DATABASE;
        $time       = date("YmdHis", time());
        $outputPath = "$rootPath/backup/process/backup_$time.txt";

        //Windows用コマンド
        //詳しくは、C:\svnroot\xbrg_aurora_src\trunk\aurora\batch\pg_backup.bat
        //の中を読んでください。
        if(isset($_ENV['OS']) && preg_match("/window/i", $_ENV['OS'])){
            $cmd    = $rootPath."/batch/pg_backup.bat %s %s %s";
            $exec       = sprintf($cmd, $user, $database ,$outputPath);
            $result = NULL;
            $output = array();
            xbLog::logger(xbLog::DEBUG,__CLASS__,">>>>>backup cmd[$exec]");
            exec($exec, $output, $result);
        }
        //その他用コマンド
        //外部ファイルは使っていません。わかる人は直してください。
        else{
            system("su - postgres");
            system("/usr/local/pgsql/bin/pg_dump -U $user $database > $rootPath/backup/process/backup_$time.sql");
        }

        //ファイルサイズ 0k の場合、エラー扱い
        if( file_exists($outputPath) ){
            if( filesize($outputPath)==0 ){
                return false;
            }
        }
        else{
            return false;
        }
        return true;
    }

    /**
     * 概要
     *  一般用   日付文字列変更
     *
     * 説明
     *  YYYYMMDDの文字列を渡し、Typeによって年月日の形式を変えたものを返す。
     *
     * @author Y.Shimizu
     * @param string $dateStr 形式としてはYYYYMMDD 8桁とする。
     * @param type $type default=null
     * @return 変換後の文字列
     * @access public
     */
    public static function formatDate($dateStr, $type=null){
        $rtn = $dateStr;

        //引数として正しくない場合は入力値そのものを返す。
        if(strlen($dateStr) != 8) return $rtn;

        switch($type){

            default;
                $rtn = substr($dateStr,0,4).'/'.substr($dateStr,4,2).'/'.substr($dateStr,6,2);
                break;
        }

        return $rtn;
    }

    /**
     * 概要
     *  一般用   時間文字列変更
     *
     * 説明
     *  hhmmの文字列を渡し、Typeによって時間の形式を変えたものを返す。
     *
     * @author Y.Shimizu
     * @param string $dateStr 形式としてはYYYYMMDD 8桁とする。
     * @param type $type default=null
     * @return 変換後の文字列
     * @access public
     */
    public static function formatTime($timeStr, $type=null){
        $rStr = '';
        //引数として正しくない場合は入力値そのものを返す。
        if(strlen($timeStr) != 4) return $timeStr;

        switch($type){
            //HH:MM
            default;
                $rStr = substr($timeStr,0,2).':'.substr($timeStr,2,2);
                break;
        }

        return $rStr;
    }

    /**
     * 概要  連続する空白（全角、半角）を１つの半角スペースへ変換後
     * 　　　その文字列の半角スペースを取り除いた文字列を返します。
     *
     *  メディアから拝借
     *
     * @author
     * @param  $str
     * @return array
     * @access public
     */
    public static function strEmpRemove($str){
        //連続するスペース(全角、半角)を半角スペースに変換し、前後をtrimする。
        //※下記の[]には全角空白と半角空白が入力してある。
        $str = mb_ereg_replace('　', ' ', $str);
        $str = trim(mb_ereg_replace('[ 　]{2,}', ' ', $str));
        //return preg_split("/[' ''　']+/", $str, -1, PREG_SPLIT_NO_EMPTY);
        return $str;
    }

    /**
     * 概要  文字列もしくは配列にて１以上存在するかをチェックする。
     * @author Y.Kato
     * @param  $mix
     * @return boolean ture:１以上存在した時 / false：それ以外
     * @access public
     */
    public static function isOneOrMore($mix){
        if(is_null($mix)){
            return false;
        }
        if(is_array($mix)){
            //配列である場合。
            if(count($mix) < 1){
                return false;
            }
        }else{
            //文字列である場合。
            if($mix==''){
                return false;
            }
        }
        return true;
    }

    /**
     * 概要  共通view内のgetter/setterメソッドで使用するセッションIDを作成します
     * @author Y.Shimizu
     * @param  $string
     * @return $string
     * @access public
     */
    public static function createSessionId($strig){
        $commonString = 'session';
        $patterns[0] = '/set/';
        $patterns[1] = '/get/';
        $replacements[0] = $commonString;
        $replacements[1] = $commonString;
        return preg_replace($patterns, $replacements, $strig);
    }

    //詳細一覧JSテキストファイル用
    public static function getTxtGridData($dataList){
        $rowInfo = array();
        foreach($dataList as $data){
            $colInfo = array();
            foreach($data as $column){
                $colInfo[] = "'" . $column . "'";
            }
            $rowInfo[] = preg_replace("/\\r\\n/", "<br>", "[".implode(",", $colInfo)."]");
        }
//xbLog::logger(xbLog::DEBUG,__CLASS__,"[" . implode(",\n", $rowInfo) . "]");
        return "[" . implode(",\n", $rowInfo) . "]";
    }

    /**
     * グリッド用データ作成
     *
     * param1：ビュー
     * param2：0 - デフォルト（checkbox+edit）
     *         1 - 検索ポップアップ
     *         2 - チェックボックスのみ
     * param3：文字列（検索ポップアップ用定形部分）
     * param4：可変部分の取得メソッド
     */
    public static function getGridData($viewList, $kbn = 0, $format, $method) {
        $dataList = array ();
        $j = 0;

        foreach ($viewList as $vList) {
            $data = array ();
            $i = 1;

            foreach ($vList->gridColList as $colList) {
                $data["column" . $i] = $vList-> $colList ();
                $i++;
            }
            $paramList = "\\'";
            $paramList .= implode("\\',\\'", $data);
            $paramList .= "\\'";

            $tmp = array ();
            if($kbn == 0){
                $tmp["column0"] = '<input type="checkbox" value="1" name="chk_'.$j.'" class="flag" id="chk_'.$j.'" /> <img alt="" src="' . xbUtil::generateURL('images/editpageyellow.gif') . '" class="editImg" onmouseover="ResistEdit(this)" onClick="update_record(' . $paramList . ')" />';
            }
            else if($kbn == 1){
                if(is_array($method)){
                    $evalStr = 'sprintf( $format ';
                    foreach($method as $m){
                        $evalStr.= ', $vList->' . $m . '()';
                    }
                    $evalStr.= '); ';
                    eval( '$tmp["column0"] = ' . $evalStr );
                }
                else{
                    $tmp["column0"] = sprintf( $format, $vList->$method() );
                }
            }
            else if($kbn == 2){
                $tmp["column0"] = '<input type="checkbox" value="1" name="chk_'.$j.'" class="flag" id="chk_'.$j.'" />';
            }

            $j++;
            $data = array_merge($tmp, $data);
            $dataList[] = $data;
            //print_r($data);
        }

        return $dataList;
    }

    /**
     * 概要
     *  パン屑リストの形成（AURORA専用）
     */
    public static function setBreadcrumb(& $view, $title, $url) {
        $view->setAryForBreadcrumb(array($title=>$url));
        return $view;
    }

    //**************
    //グリッド対応版
    //**************
    public static function pageInfomation( $view, $routing ){
        sfLoader::loadHelpers('Tag');
        sfLoader::loadHelpers('Asset');
        sfLoader::loadHelpers('Form');
        sfLoader::loadHelpers('Url');
        sfLoader::loadHelpers('Javascript');

        $pageSpan = 10;
        if($view->getCount() == 0){
            return "";
        }

        /**
         * Add Page Infomation hide
         */
//        if ( $view->getLimit() ) {
//            return "";
//        }

        //最終ページ算出
        $lastPage = ceil( $view->getCount() / $view->getLimit() );

        $buff = array();
        $buff[] = "<table border=0 align=right>";
        $buff[] = "<tr align=right>";

        //$tl = $view->getCount();
        //$st = ($view->getPagingId() - 1) * $view->getLimit() + 1;
        //$ed = $view->getPagingId() * $view->getLimit();

        $buff[] = "<td align=left>";
        $buff[] = $view->writePageInfomation();
        //$buff[] = $tl . ' '.xbMessages::CL_TOTAL.'　'.sprintf(xbMessages::CL_PAGE, $st, $ed).'　';;
        $buff[] = "<td width=5>";

        //先頭ページへのリンク
        $buff[] = "<td width=20 align=left>";
        $buff[] = link_to_remote(image_tag( "arrow_left_Page_fast.gif", array('alt'=>'','width'=>'8','height'=>'16') ),
                    array('url' => $routing.'?pageId=1',  'before' => 'gridLoadMark()', 'success' => 'gridReplace(request);gridUnLoadMark();')
                  );
        $buff[] = "</td>";

        //前ページヘのリンク
        $prePage = 1;
        if( $view->getPageId() > 1){
            $prePage = $view->getPageId() - 1;
        }
        $buff[] = "<td width=20 align=left>";
        $buff[] = link_to_remote(image_tag("arrow_left_Page.gif", array('alt'=>'','width'=>'8','height'=>'16')),
                    array('url' => $routing.'?pageId='.$prePage, 'before' => 'gridLoadMark()', 'success' => 'gridReplace(request);gridUnLoadMark();'));
        $buff[] = "</td>";

        //ページ番号の制御
        $spos = $view->getPageId() - floor( $pageSpan / 2 );
        $epos = $view->getPageId() + floor( $pageSpan / 2 );

        //開始位置の調整
        if($spos < 1){
            $epos = $epos + ( $spos * -1 + 1);
            $spos = 1;
            if($epos > $lastPage){
                $epos = $lastPage;
            }
        }

        //終了位置の調整
        if($epos > $lastPage){
            $spos = $spos - ( $epos - $lastPage );
            $epos = $lastPage;
            if($spos < 1){
                $spos = 1;
            }
        }

        //前ページが存在する
        if($spos > 1){
            $buff[] = "<td width=20>…　</td>";
        }

        //ページ番号のリンク
        for($i=$spos; $i<=$epos; $i++){
            if( $view->getPageId() == $i ){
                $buff[] = "<td  width=20 align=center>".$i."</td>";
            }
            else{
                $buff[] = "<td  width=20 align=center>";
                $buff[] = link_to_remote($i,
                            array('url' => $routing.'?pageId='.$i, 'before' => 'gridLoadMark()', 'success' => 'gridReplace(request);gridUnLoadMark();'));
                $buff[] = "</td>";
            }
        }

        //次ページが存在する
        if( $epos < $lastPage ){
            $buff[] = "<td width=20>…　</td>";
        }

        //次ページヘのリンク
        $nextPage = $lastPage;
        if( $view->getPageId() < $lastPage){
            $nextPage = $view->getPageId() + 1;
        }
        $buff[] = "<td width=20>";
        $buff[] = link_to_remote(image_tag("arrow_right_Page.gif", array('alt'=>'','width'=>'8','height'=>'16')),
                    array('url' => $routing.'?pageId='.$nextPage, 'before' => 'gridLoadMark()', 'success' => 'gridReplace(request);gridUnLoadMark();'));
        $buff[] = "</td>";

        //最終ページへのリンク
        $buff[] = "<td width=20>";
        $buff[] = link_to_remote(image_tag("arrow_right_Page_end.gif", array('alt'=>'','width'=>'8','height'=>'16')),
                    array('url' => $routing.'?pageId='.$lastPage, 'before' => 'gridLoadMark()', 'success' => 'gridReplace(request);gridUnLoadMark();'));
        $buff[] = "</td>";

        $buff[] = "</tr>";
        $buff[] = "</table>";
        return implode("\n", $buff);
    }

    //**************
    //通常版
    //**************
    public static function writePager( $view, $routing ){

        $separator = '&';

        if (class_exists('sfLoader', false)) {
            sfLoader::loadHelpers('Tag');
            sfLoader::loadHelpers('Asset');
            sfLoader::loadHelpers('Form');
            sfLoader::loadHelpers('Url');
            sfLoader::loadHelpers('Javascript');
            $separator = '?';
        }


        $pageSpan = 10;
        if($view->getCount() == 0){
            return "";
        }

        //最終ページ算出
        $lastPage = ceil( $view->getCount() / $view->getLimit() );

        $buff = array();
        $buff[] = "<table border=0 align=right>";
        $buff[] = "<tr align=right>";

        $buff[] = "<td align=left>";
        $buff[] = $view->writePageInfomation();
        $buff[] = "<td width=5>";

        //先頭ページへのリンク
        $buff[] = "<td width=20 align=left>";
        $buff[] = link_to(image_tag("arrow_left_Page_fast.gif", array('alt'=>'','width'=>'8','height'=>'16')), $routing . $separator . 'pageId=1');
        $buff[] = "</td>";

        //前ページヘのリンク
        $prePage = 1;
        if( $view->getPageId() > 1){
            $prePage = $view->getPageId() - 1;
        }
        $buff[] = "<td width=20 align=left>";
        $buff[] = link_to(image_tag("arrow_left_Page.gif", array('alt'=>'','width'=>'8','height'=>'16')), $routing . $separator . 'pageId='.$prePage);
        $buff[] = "</td>";

        //ページ番号の制御
        $spos = $view->getPageId() - floor( $pageSpan / 2 );
        $epos = $view->getPageId() + floor( $pageSpan / 2 );

        //開始位置の調整
        if($spos < 1){
            $epos = $epos + ( $spos * -1 + 1);
            $spos = 1;
            if($epos > $lastPage){
                $epos = $lastPage;
            }
        }

        //終了位置の調整
        if($epos > $lastPage){
            $spos = $spos - ( $epos - $lastPage );
            $epos = $lastPage;
            if($spos < 1){
                $spos = 1;
            }
        }

        //前ページが存在する
        if($spos > 1){
            $buff[] = "<td width=20>…　</td>";
        }

        //ページ番号のリンク
        for($i=$spos; $i<=$epos; $i++){
            if( $view->getPageId() == $i ){
                $buff[] = "<td  width=20 align=center>".$i."</td>";
            }
            else{
                $buff[] = "<td  width=20 align=center>";
                $buff[] = link_to($i,$routing . $separator . 'pageId='.$i);
                $buff[] = "</td>";
            }
        }

        //次ページが存在する
        if( $epos < $lastPage ){
            $buff[] = "<td width=20>…　</td>";
        }

        //次ページヘのリンク
        $nextPage = $lastPage;
        if( $view->getPageId() < $lastPage){
            $nextPage = $view->getPageId() + 1;
        }
        $buff[] = "<td width=20>";
        $buff[] = link_to(image_tag("arrow_right_Page.gif", array('alt'=>'','width'=>'8','height'=>'16')),$routing . $separator . 'pageId='.$nextPage);
        $buff[] = "</td>";

        //最終ページへのリンク
        $buff[] = "<td width=20>";
        $buff[] = link_to(image_tag("arrow_right_Page_end.gif", array('alt'=>'','width'=>'8','height'=>'16')),$routing . $separator . 'pageId='.$lastPage);
        $buff[] = "</td>";

        $buff[] = "</tr>";
        $buff[] = "</table>";
        return implode("\n", $buff);
    }

    /**
     * ページング情報の取得
     *
     * @access public
     * @param  $page_id     ページID
     * @param  $limit       1ページ表示件数
     * @param  $count       全件数
     * @return array('page_id', 'count', 'snum', 'enum', 'last_page', 'pre_page', 'next_page')
     */
    public static function getPageInfo($page_id = 1, $limit = -1, $count = 0) {
        $offset = $limit * ( $page_id - 1);

        $ret['page_id'] = $page_id;
        $ret['count'] = $count;
        $ret['limit'] = $limit;

        //表示件数の最初と最後の数字を取得
        $ret['snum'] = $offset + 1;
        if( $count == 0 ){
            $ret['snum'] = 0;
        }
        //現在ページの最後尾
        $epos = $offset + $limit;
        $ret['enum'] = ($count > $epos)?$epos:$count;

        //前のページ、次のページ、最後のページのページ番号を取得
        if($count != 0){

            $ret['last_page'] = ceil( $count / $limit );

            if( $page_id > 1){
                $ret['pre_page'] = $page_id - 1;
            }
            else {
                $ret['pre_page'] = 1;
            }

            if( $page_id < $ret['last_page']){
                $ret['next_page'] = $page_id + 1;
            }
            else {
                $ret['next_page'] = $ret['last_page'];
            }
        }

        //ページング情報を返す
        return $ret;
    }

    /**
     * 帳票用データ中のカンマを全角に変更し、
     * 改行は駆除します。
     */
    public static function changeCommaForFujin($str){
        $str = implode('', explode(chr(13), $str));//改行
        $str = implode("，", explode(chr(44),$str));//カンマ

        return $str;
    }

    /**
     * 入力文字列に含まれる数値実体参照を実体に変換する
     *
     * @param  string $str    入力文字列
     * @param  string $inEnc  入力文字列のエンコーディング
     * @param  string $outEnc 出力文字列のエンコーディング
     * @return string 出力文字列
     *
     */
    public static function ncr2chr($str, $inEnc = 'UTF-8', $outEnc = 'UTF-8'){
        $conf = array(
                      'show-body-only' => true,
                      'ncr' => true,
                      'quote-ampersand' => false,
                      'input-xml' => true,
                      'output-xml' => true
                      );
        $str_utf8 = mb_convert_encoding($str, 'UTF-8', $inEnc);
        $str_ent  = tidy_repair_string($str_utf8, $conf, 'utf8');
        return mb_convert_encoding($str_ent, $outEnc, 'UTF-8');
    }

    /**
     * 時間（分）をフォーマットする。
     *
     *
     * @access なし
     * @param  string $time 時間, $unit 単位, $type タイプ(ctmUtil::INTIME or ctmUtil::OUTTIME)
     * @return string 時間
     * @see    SyainListView
     */
    public static function roundTime($time, $unit, $type) {
        switch($type) {
            case self::INTIME :
                $fTime = self::roundInTime($time, $unit);
                break;
            case self::OUTTIME :
                $fTime = self::roundOutTime($time, $unit);
                break;
        }
        return $fTime;
    }

    /**
     * 時間（分）をフォーマットする（後優先）。
     *
     *
     * @access なし
     * @param  string $time 時間
     * @return string 時間
     * @see    SyainListView
     */
    public static function roundInTime($time, $unit) {
        //時間の単位が設定されていないときはその後の処理を無視。
        if ($unit == 0) {
            return $time;
        }

        $tmpMinute = (isset($time))?substr($time,2,2):null;
        // ( >= ) Greater than or Equal to
        $ge = 0;
        while (!isset($minute)) {
            if ($tmpMinute == 0) {
                $minute = sprintf("%02d", $ge);
            }
            else if (($tmpMinute > $ge) && ($tmpMinute <= ($ge + $unit)) && (($ge + $unit) < 60)) {
                $minute = sprintf("%02d", $ge + $unit);
            }
            elseif($ge + $unit >= 60) {
                $minute = '00';
                return sprintf("%02d", substr($time,0,2) + 1).$minute;
            }
            $ge = $ge + $unit;
        }
        return substr($time,0,2).$minute;
    }

    /**
     * 時間（分）をフォーマットする（先優先）。
     *
     *
     * @access なし
     * @param  string $time 時間
     * @return string 時間
     * @see    SyainListView
     */
    public static function roundOutTime($time, $unit) {
        //時間の単位が設定されていないときはその後の処理を無視。
        if ($unit == 0) {
            return $time;
        }

        $tmpMinute = (isset($time))?substr($time,2,2):null;
        // ( >= ) Greater than or Equal to
        $ge = 0;
        while(!isset($minute)) {
            if(($tmpMinute >= $ge && $tmpMinute < $ge + $unit) || ($ge >= 60)) {
                $minute = sprintf("%02d",$ge);
            }
            $ge = $ge + $unit;
        }
        return substr($time,0,2).$minute;
    }

    /**
     * 金額をフォーマットする。
     *
     *
     * @access なし
     * @param  string $kin 金額
     * @return string 時間
     * @see    SyainListView
     */
    public static function formatMoney($kin) {
        return number_format($kin);
    }

}
?>
